@@ -22,6 +22,7 @@
  */
 
 #include "glade-app.h"
+#include "glade-private.h"
 #include "gladeui-enum-types.h"
 #include "glade-adaptor-chooser-widget.h"
 #include "glade-dnd.h"
@@ -37,7 +38,8 @@ enum
   N_COLUMN
 };
 
-struct _GladeAdaptorChooserWidgetPrivate
+typedef struct __GladeAdaptorChooserWidgetPrivate _GladeAdaptorChooserWidgetPrivate;
+struct __GladeAdaptorChooserWidgetPrivate
 {
   GtkTreeView        *treeview;
   GtkListStore       *store;
@@ -169,7 +171,7 @@ normalize_name (const gchar *name)
 static inline void
 store_append_adaptor (GtkListStore *store, GladeWidgetAdaptor *adaptor)
 {
-  gchar *normalized_name = normalize_name (glade_widget_adaptor_get_name (adaptor));
+  gchar *normalized_name = normalize_name (glade_widget_adaptor_get_display_name (adaptor));
 
   gtk_list_store_insert_with_values (store, NULL, -1,
                                      COLUMN_ADAPTOR, adaptor,
@@ -382,7 +384,7 @@ adaptor_text_cell_data_func (GtkTreeViewColumn *tree_column,
   if (adaptor)
     g_object_set (cell,
                   "sensitive", TRUE,
-                  "text", glade_widget_adaptor_get_name (adaptor),
+                  "text", glade_widget_adaptor_get_display_name (adaptor),
                   "style", PANGO_STYLE_NORMAL,
                   NULL);
   else
@@ -411,7 +413,7 @@ glade_adaptor_chooser_widget_drag_begin (GtkWidget      *widget,
       gtk_tree_model_get (model, &iter, COLUMN_ADAPTOR, &adaptor, -1);
       _glade_dnd_set_icon_widget (context,
                                   glade_widget_adaptor_get_icon_name (adaptor),
-                                  glade_widget_adaptor_get_name (adaptor));
+                                  glade_widget_adaptor_get_display_name (adaptor));
     }
 }
 
@@ -460,7 +462,7 @@ _glade_adaptor_chooser_widget_constructed (GObject *object)
                                        chooser, NULL);
   /* Enable Drag & Drop */
   gtk_tree_view_enable_model_drag_source (priv->treeview, GDK_BUTTON1_MASK,
-                                          _glade_dnd_get_target (), 1, 0);
+                                          _glade_dnd_get_target (), 1, GDK_ACTION_MOVE | GDK_ACTION_COPY);
   g_signal_connect_after (priv->treeview, "drag-begin",
                           G_CALLBACK (glade_adaptor_chooser_widget_drag_begin),
                           NULL);
