@@ -273,6 +273,11 @@ glade_adaptor_chooser_class_init (GladeAdaptorChooserClass *klass)
 
 /* Public API */
 
+/**
+ * glade_adaptor_chooser_new:
+ *
+ * Returns: (transfer full): A new #GladeAdaptorChooser
+ */
 GtkWidget *
 glade_adaptor_chooser_new ()
 {
@@ -291,7 +296,7 @@ glade_adaptor_chooser_update_adaptor (GladeAdaptorChooser *chooser)
                                     glade_widget_adaptor_get_icon_name (adaptor),
                                     GTK_ICON_SIZE_BUTTON);
       gtk_label_set_label (priv->class_label,
-                           glade_widget_adaptor_get_name (adaptor));
+                           glade_widget_adaptor_get_display_name (adaptor));
     }
   else
     {
@@ -337,6 +342,12 @@ glade_adaptor_chooser_set_project (GladeAdaptorChooser *chooser,
   glade_adaptor_chooser_update_adaptor (chooser);
 }
 
+/**
+ * glade_adaptor_chooser_get_project:
+ * @chooser: a #GladeAdaptorChooser
+ *
+ * Returns: (transfer full): A #GladeProject
+ */
 GladeProject *
 glade_adaptor_chooser_get_project (GladeAdaptorChooser *chooser)
 {
