@@ -61,6 +61,7 @@ enum
   LAST_SIGNAL
 };
 
+typedef struct _GladeAppPrivate GladeAppPrivate;
 struct _GladeAppPrivate
 {
   GtkWidget *window;
@@ -121,7 +122,7 @@ glade_app_constructor (GType                  type,
 static void
 glade_app_dispose (GObject *app)
 {
-  GladeAppPrivate *priv = GLADE_APP (app)->priv;
+  GladeAppPrivate *priv = glade_app_get_instance_private ((GladeApp *) app);
 
   if (priv->clipboard)
     {
@@ -363,7 +364,7 @@ static void
 glade_app_init (GladeApp *app)
 {
   static gboolean initialized = FALSE;
-  GladeAppPrivate *priv = app->priv = glade_app_get_instance_private (app);
+  GladeAppPrivate *priv = glade_app_get_instance_private (app);
 
   singleton_app = app;
 
@@ -417,7 +418,7 @@ static void
 glade_app_class_init (GladeAppClass *klass)
 {
   GObjectClass *object_class;
-	
+
   object_class = G_OBJECT_CLASS (klass);
 
   object_class->constructor = glade_app_constructor;
@@ -462,7 +463,7 @@ glade_app_class_init (GladeAppClass *klass)
   /**
    * GladeApp::widget-adaptor-registered:
    * @gladeapp: the #GladeApp which received the signal.
-   * @adaptor: the newlly registered #GladeWidgetAdaptor.
+   * @adaptor: the newly registered #GladeWidgetAdaptor.
    *
    * Emitted when a new widget adaptor is registered.
    */
@@ -502,7 +503,7 @@ glade_app_do_event (GdkEvent *event)
   gdk_window_get_user_data (window, &widget);
 
   /* As a slight optimization we could replace gtk_widget_get_ancestor()
-   * with a custom function that only iterates trought parents with windows.
+   * with a custom function that only iterates trough parents with windows.
    */
   if (widget && IS_GLADE_WIDGET_EVENT (event->type) &&
       (layout = gtk_widget_get_ancestor (widget, GLADE_TYPE_DESIGN_LAYOUT)))
@@ -514,9 +515,9 @@ glade_app_do_event (GdkEvent *event)
 /**
  * glade_app_config_save
  *
- * Saves the GKeyFile to "g_get_user_config_dir()/GLADE_CONFIG_FILENAME"
+ * Saves the #GKeyFile to "g_get_user_config_dir()/GLADE_CONFIG_FILENAME"
  *
- * Return 0 on success.
+ * Returns: 0 on success.
  */
 gint
 glade_app_config_save ()
@@ -529,6 +530,7 @@ glade_app_config_save ()
   gsize size, written, bytes_written = 0;
   static gboolean error_shown = FALSE;
   GladeApp *app;
+  GladeAppPrivate *priv;
 
   /* If we had any errors; wait untill next session to retry.
    */
@@ -536,6 +538,7 @@ glade_app_config_save ()
     return -1;
 
   app = glade_app_get ();
+  priv = glade_app_get_instance_private (app);
 
   /* Just in case... try to create the config directory */
   if (g_file_test (config_dir, G_FILE_TEST_IS_DIR) == FALSE)
@@ -570,7 +573,7 @@ glade_app_config_save ()
   if ((channel = g_io_channel_new_file (filename, "w", &error)) != NULL)
     {
       if ((data =
-           g_key_file_to_data (app->priv->config, &size, &error)) != NULL)
+           g_key_file_to_data (priv->config, &size, &error)) != NULL)
         {
 
           /* Implement loop here */
@@ -626,6 +629,11 @@ glade_app_config_save ()
   return 0;
 }
 
+/**
+ * glade_app_get:
+ *
+ * Returns: (transfer none): the #GladeApp
+ */
 GladeApp *
 glade_app_get (void)
 {
@@ -637,24 +645,38 @@ glade_app_get (void)
   return singleton_app;
 }
 
+/**
+ * glade_app_set_window:
+ * @window: (transfer full): a #GtkWidget
+ *
+ * Set the window of the application
+ */
 void
 glade_app_set_window (GtkWidget *window)
 {
   GladeApp *app = glade_app_get ();
+  GladeAppPrivate *priv = glade_app_get_instance_private (app);
 
-  app->priv->window = window;
+  priv->window = window;
 }
 
+/**
+ * glade_app_get_catalog:
+ * @name: the name of the catalog
+ *
+ * Returns: (transfer none) (nullable): a #GladeCatalog or %NULL if none is found
+ */
 GladeCatalog *
 glade_app_get_catalog (const gchar *name)
 {
   GladeApp *app = glade_app_get ();
+  GladeAppPrivate *priv = glade_app_get_instance_private (app);
   GList *list;
   GladeCatalog *catalog;
 
   g_return_val_if_fail (name && name[0], NULL);
 
-  for (list = app->priv->catalogs; list; list = list->next)
+  for (list = priv->catalogs; list; list = list->next)
     {
       catalog = list->data;
       if (!strcmp (glade_catalog_get_name (catalog), name))
@@ -663,6 +685,16 @@ glade_app_get_catalog (const gchar *name)
   return NULL;
 }
 
+/**
+ * glade_app_get_catalog_version:
+ * @name: the name of the #GladeCatalog
+ * @major: (out) (optional): the major version
+ * @minor: (out) (optional): the minor version
+ *
+ * Returns: %TRUE if the catalog has been found. It is a programming error
+ * to call this function with an unexisting catalog, returns %FALSE in this
+ * case and throws a warning.
+ */
 gboolean
 glade_app_get_catalog_version (const gchar *name, gint *major, gint *minor)
 {
@@ -678,40 +710,67 @@ glade_app_get_catalog_version (const gchar *name, gint *major, gint *minor)
   return TRUE;
 }
 
+/**
+ * glade_app_get_catalogs:
+ *
+ * Returns: (transfer none) (element-type GladeCatalog): a list of #GladeCatalog
+ */
 GList *
 glade_app_get_catalogs (void)
 {
   GladeApp *app = glade_app_get ();
+  GladeAppPrivate *priv = glade_app_get_instance_private (app);
 
-  return app->priv->catalogs;
+  return priv->catalogs;
 }
 
-
+/**
+ * glade_app_get_window:
+ *
+ * Returns: (transfer none): a #GtkWidget
+ */
 GtkWidget *
 glade_app_get_window (void)
 {
   GladeApp *app = glade_app_get ();
-  return app->priv->window;
+  GladeAppPrivate *priv = glade_app_get_instance_private (app);
+
+  return priv->window;
 }
 
+/**
+ * glade_app_get_clipboard:
+ *
+ * Returns: (transfer none): a #GladeClipboard
+ */
 GladeClipboard *
 glade_app_get_clipboard (void)
 {
   GladeApp *app = glade_app_get ();
-  return app->priv->clipboard;
+  GladeAppPrivate *priv = glade_app_get_instance_private (app);
+
+  return priv->clipboard;
 }
+
 /**
- * glade_app_get_catalogs:
+ * glade_app_get_projects:
  *
- * Return value: (element-type GladeCatalog): catalogs
+ * Returns: (element-type GladeCatalog) (transfer none): a list of #GladeCatalog
  */
 GList *
 glade_app_get_projects (void)
 {
   GladeApp *app = glade_app_get ();
-  return app->priv->projects;
+  GladeAppPrivate *priv = glade_app_get_instance_private (app);
+
+  return priv->projects;
 }
 
+/**
+ * glade_app_get_config:
+ *
+ * Returns: (transfer full): a #GKeyFile
+ */
 GKeyFile *
 glade_app_get_config (void)
 {
@@ -733,6 +792,7 @@ gboolean
 glade_app_is_project_loaded (const gchar *project_path)
 {
   GladeApp *app;
+  GladeAppPrivate *priv;
   GList *list;
   gboolean loaded = FALSE;
 
@@ -740,8 +800,9 @@ glade_app_is_project_loaded (const gchar *project_path)
     return FALSE;
 
   app = glade_app_get ();
+  priv = glade_app_get_instance_private (app);
 
-  for (list = app->priv->projects; list; list = list->next)
+  for (list = priv->projects; list; list = list->next)
     {
       GladeProject *cur_project = GLADE_PROJECT (list->data);
 
@@ -759,12 +820,13 @@ glade_app_is_project_loaded (const gchar *project_path)
  *
  * Finds an open project with @path
  *
- * Returns: A #GladeProject, or NULL if no such open project was found
+ * Returns: (nullable) (transfer none): A #GladeProject, or NULL if no such open project was found
  */
 GladeProject *
 glade_app_get_project_by_path (const gchar *project_path)
 {
   GladeApp *app;
+  GladeAppPrivate *priv;
   GList *l;
   gchar *canonical_path;
 
@@ -772,10 +834,11 @@ glade_app_get_project_by_path (const gchar *project_path)
     return NULL;
 
   app = glade_app_get ();
+  priv = glade_app_get_instance_private (app);
 
   canonical_path = glade_util_canonical_path (project_path);
 
-  for (l = app->priv->projects; l; l = l->next)
+  for (l = priv->projects; l; l = l->next)
     {
       GladeProject *project = (GladeProject *) l->data;
 
@@ -792,32 +855,44 @@ glade_app_get_project_by_path (const gchar *project_path)
   return NULL;
 }
 
+/**
+ * glade_app_add_project:
+ * @project: the project to add to the #GladeApp
+ */
 void
 glade_app_add_project (GladeProject *project)
 {
   GladeApp *app;
+  GladeAppPrivate *priv;
 
   g_return_if_fail (GLADE_IS_PROJECT (project));
 
   app = glade_app_get ();
+  priv = glade_app_get_instance_private (app);
 
   /* If the project was previously loaded, don't re-load */
-  if (g_list_find (app->priv->projects, project) != NULL)
+  if (g_list_find (priv->projects, project) != NULL)
     return;
 
   /* Take a reference for GladeApp here... */
-  app->priv->projects = g_list_append (app->priv->projects, g_object_ref (project));
+  priv->projects = g_list_append (priv->projects, g_object_ref (project));
 }
 
+/**
+ * glade_app_remove_project:
+ * @project: the project to remove from the #GladeApp
+ */
 void
 glade_app_remove_project (GladeProject *project)
 {
   GladeApp *app;
+  GladeAppPrivate *priv;
   g_return_if_fail (GLADE_IS_PROJECT (project));
 
   app = glade_app_get ();
+  priv = glade_app_get_instance_private (app);
 
-  app->priv->projects = g_list_remove (app->priv->projects, project);
+  priv->projects = g_list_remove (priv->projects, project);
 
   /* Its safe to just release the project as the project emits a
    * "close" signal and everyone is responsable for cleaning up at
@@ -826,8 +901,9 @@ glade_app_remove_project (GladeProject *project)
   g_object_unref (project);
 }
 
-/*
+/**
  * glade_app_set_accel_group:
+ * @accel_group: (transfer full): a #GtkAccelGroup to set
  *
  * Sets @accel_group to app.
  * The acceleration group will made available for editor dialog windows
@@ -837,34 +913,58 @@ void
 glade_app_set_accel_group (GtkAccelGroup *accel_group)
 {
   GladeApp *app;
+  GladeAppPrivate *priv;
+
   g_return_if_fail (GTK_IS_ACCEL_GROUP (accel_group));
 
   app = glade_app_get ();
+  priv = glade_app_get_instance_private (app);
 
-  app->priv->accel_group = accel_group;
+  priv->accel_group = accel_group;
 }
 
+/**
+ * glade_app_get_accel_group:
+ *
+ * Returns: (transfer none): the #GtkAccelGroup
+ */
 GtkAccelGroup *
 glade_app_get_accel_group (void)
 {
-  return glade_app_get ()->priv->accel_group;
+  GladeApp *app = glade_app_get ();
+  GladeAppPrivate *priv = glade_app_get_instance_private (app);
+
+  return priv->accel_group;
 }
 
+/**
+ * glade_app_new:
+ *
+ * Returns: (transfer full): the #GladeApp
+ */
 GladeApp *
 glade_app_new (void)
 {
   return g_object_new (GLADE_TYPE_APP, NULL);
 }
 
+/**
+ * glade_app_search_docs:
+ * @book: the name of a book
+ * @page: the name of a page
+ * @search: the search query
+ *
+ * Searches for @book, @page and @search in the documentation.
+ */
 void
 glade_app_search_docs (const gchar *book,
-		       const gchar *page, 
-		       const gchar *search)
+                       const gchar *page, 
+                       const gchar *search)
 {
   GladeApp *app;
 
   app = glade_app_get ();
 
   g_signal_emit (G_OBJECT (app), glade_app_signals[DOC_SEARCH], 0, 
-		 book, page, search);
+                 book, page, search);
 }
