@@ -18,7 +18,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307,
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
  * USA.
  */
 
@@ -244,7 +244,7 @@ G_GNUC_END_IGNORE_DEPRECATIONS
   g_slist_free (gsi_list_list);
 
   stock_prefixs_done = TRUE;
-  g_slist_free (stock_list);
+  g_slist_free_full (stock_list, g_free);
 
   return values;
 }
@@ -303,8 +303,8 @@ G_GNUC_END_IGNORE_DEPRECATIONS
             {
               gchar *clean_name = clean_stock_name (item.label);
 
-	      if (!glade_get_displayable_value (etype, enum_values[i].value_nick))
-		glade_register_translated_value (etype, enum_values[i].value_nick, clean_name);
+              if (!glade_get_displayable_value (etype, enum_values[i].value_nick))
+                glade_register_translated_value (etype, enum_values[i].value_nick, clean_name);
               g_free (clean_name);
             }
         }
@@ -340,8 +340,8 @@ G_GNUC_END_IGNORE_DEPRECATIONS
               gchar *clean_name = clean_stock_name (item.label);
 
               /* These are translated, we just cut out the mnemonic underscores */
-	      if (!glade_get_displayable_value (etype, enum_values[i].value_nick))
-		glade_register_translated_value (etype, enum_values[i].value_nick, clean_name);
+              if (!glade_get_displayable_value (etype, enum_values[i].value_nick))
+                glade_register_translated_value (etype, enum_values[i].value_nick, clean_name);
               g_free (clean_name);
             }
         }
@@ -349,16 +349,21 @@ G_GNUC_END_IGNORE_DEPRECATIONS
       for (i = 0; i < G_N_ELEMENTS (builtin_stock_images); i++)
         {
           /* these ones are translated from glade */
-	  if (!glade_get_displayable_value (etype, builtin_stock_images[i]))
-	    glade_register_displayable_value (etype,
-					      builtin_stock_images[i],
-					      GETTEXT_PACKAGE,
-					      builtin_stock_displayables[i]);
+          if (!glade_get_displayable_value (etype, builtin_stock_images[i]))
+            glade_register_displayable_value (etype,
+                                              builtin_stock_images[i],
+                                              GETTEXT_PACKAGE,
+                                              builtin_stock_displayables[i]);
         }
     }
   return etype;
 }
 
+/**
+ * glade_standard_stock_spec:
+ *
+ * Returns: (transfer full): a #GParamSpec describing a list of builtin stock item
+ */
 GParamSpec *
 glade_standard_stock_spec (void)
 {
@@ -367,6 +372,11 @@ glade_standard_stock_spec (void)
                             GLADE_TYPE_STOCK, 0, G_PARAM_READWRITE);
 }
 
+/**
+ * glade_standard_stock_image_spec:
+ *
+ * Returns: (transfer full): a #GParamSpec describing a list of builtin stock image
+ */
 GParamSpec *
 glade_standard_stock_image_spec (void)
 {
@@ -393,7 +403,7 @@ glade_glist_get_type (void)
 
 /****************************************************************
  *  Built-in GladeParamSpecObjects for object list properties   *
- *  (Used as a pspec to desctibe an AtkRelationSet, but can     *
+ *  (Used as a pspec to describe an AtkRelationSet, but can     *
  *  for any object list property)                               *
  ****************************************************************/
 static void
@@ -427,7 +437,7 @@ param_objects_validate (GParamSpec * pspec, GValue * value)
       object = list->data;
 
       if (!(G_OBJECT_TYPE (object) == ospec->type ||
-	    g_type_is_a (G_OBJECT_TYPE (object), ospec->type)))
+            g_type_is_a (G_OBJECT_TYPE (object), ospec->type)))
         toremove = g_list_prepend (toremove, object);
     }
 
@@ -481,6 +491,11 @@ glade_param_objects_get_type (void)
   return objects_type;
 }
 
+/**
+ * glade_param_spec_objects:
+ *
+ * Returns: (transfer full): a #GParamSpec describing a list of #GObject
+ */
 GParamSpec *
 glade_param_spec_objects (const gchar * name,
                           const gchar * nick,
@@ -508,9 +523,14 @@ glade_param_spec_objects_get_type (GladeParamSpecObjects * pspec)
   return pspec->type;
 }
 
-/* This was developed for the purpose of holding a list
+/**
+ * glade_standard_objects_spec:
+ *
+ * This was developed for the purpose of holding a list
  * of 'targets' in an AtkRelation (we are setting it up
  * as a property)
+ *
+ * Returns: (transfer full): a #GParamSpec describing a list of #GObject
  */
 GParamSpec *
 glade_standard_objects_spec (void)
@@ -520,17 +540,25 @@ glade_standard_objects_spec (void)
                                    G_TYPE_OBJECT, G_PARAM_READWRITE);
 }
 
-/* Pixbuf Type */
+/**
+ * glade_standard_pixbuf_spec:
+ *
+ * Returns: (transfer full): a #GParamSpec describing a #GdkPixbuf
+ */
 GParamSpec *
 glade_standard_pixbuf_spec (void)
 {
   return g_param_spec_object ("pixbuf", _("Image File Name"),
                               _("Enter a filename, relative path or full path to "
-				"load the image"), GDK_TYPE_PIXBUF,
+                                "load the image"), GDK_TYPE_PIXBUF,
                               G_PARAM_READWRITE);
 }
 
-/* GdkColor */
+/**
+ * glade_standard_gdkcolor_spec:
+ *
+ * Returns: (transfer full): a #GParamSpec describing a #GdkColor
+ */
 GParamSpec *
 glade_standard_gdkcolor_spec (void)
 {
@@ -542,6 +570,12 @@ glade_standard_gdkcolor_spec (void)
 /****************************************************************
  *                    Basic types follow                        *
  ****************************************************************/
+
+/**
+ * glade_standard_int_spec:
+ *
+ * Returns: (transfer full): a #GParamSpec describing an int
+ */
 GParamSpec *
 glade_standard_int_spec (void)
 {
@@ -550,6 +584,11 @@ glade_standard_int_spec (void)
                            G_MININT, G_MAXINT, 0, G_PARAM_READWRITE);
 }
 
+/**
+ * glade_standard_uint_spec:
+ *
+ * Returns: (transfer full): a #GParamSpec describing an uint
+ */
 GParamSpec *
 glade_standard_uint_spec (void)
 {
@@ -558,6 +597,11 @@ glade_standard_uint_spec (void)
                             0, G_MAXUINT, 0, G_PARAM_READWRITE);
 }
 
+/**
+ * glade_standard_string_spec:
+ *
+ * Returns: (transfer full): a #GParamSpec describing a string
+ */
 GParamSpec *
 glade_standard_string_spec (void)
 {
@@ -565,6 +609,11 @@ glade_standard_string_spec (void)
                               _("An entry"), "", G_PARAM_READWRITE);
 }
 
+/**
+ * glade_standard_strv_spec:
+ *
+ * Returns: (transfer full): a #GParamSpec describing an array of strings
+ */
 GParamSpec *
 glade_standard_strv_spec (void)
 {
@@ -572,6 +621,11 @@ glade_standard_strv_spec (void)
                              "String array", G_TYPE_STRV, G_PARAM_READWRITE);
 }
 
+/**
+ * glade_standard_float_spec:
+ *
+ * Returns: (transfer full): a #GParamSpec describing a float
+ */
 GParamSpec *
 glade_standard_float_spec (void)
 {
@@ -580,6 +634,11 @@ glade_standard_float_spec (void)
                              0.0F, G_MAXFLOAT, 0.0F, G_PARAM_READWRITE);
 }
 
+/**
+ * glade_standard_boolean_spec:
+ *
+ * Returns: (transfer full): a #GParamSpec describing a boolean
+ */
 GParamSpec *
 glade_standard_boolean_spec (void)
 {
