@@ -45,6 +45,8 @@ struct _GladeCatalog
 
   gchar *name;                  /* Symbolic catalog name             */
 
+  gchar *prefix;                /* Catalog path prefix               */
+   
   gchar *dep_catalog;           /* Symbolic name of the catalog that
                                  * this catalog depends on           */
 
@@ -108,6 +110,7 @@ catalog_allocate (void)
 
   catalog->library = NULL;
   catalog->name = NULL;
+  catalog->prefix = NULL;
   catalog->dep_catalog = NULL;
   catalog->domain = NULL;
   catalog->book = NULL;
@@ -159,9 +162,7 @@ catalog_destroy (GladeCatalog *catalog)
       g_list_free (catalog->widget_groups);
     }
 
-  if (catalog->context)
-    glade_xml_context_free (catalog->context);
-
+  g_clear_pointer (&catalog->context, glade_xml_context_free);
   g_slice_free (GladeCatalog, catalog);
 }
 
@@ -201,6 +202,7 @@ catalog_open (const gchar *filename)
   catalog = catalog_allocate ();
   catalog->context = context;
   catalog->name = name;
+  catalog->prefix = g_path_get_dirname (filename);
 
   glade_xml_get_property_version (root, GLADE_TAG_VERSION,
                                   &catalog->major_version,
@@ -419,7 +421,7 @@ catalog_load (GladeCatalog *catalog)
     }
 
   catalog->widget_groups = g_list_reverse (catalog->widget_groups);
-  catalog->context = (glade_xml_context_free (catalog->context), NULL);
+  g_clear_pointer (&catalog->context, glade_xml_context_free);
 
   return;
 }
@@ -522,18 +524,18 @@ catalogs_from_path (GList *catalogs, const gchar *path)
           if (!g_str_has_suffix (filename, ".xml"))
             continue;
 
-	  /* Special case, ignore gresource files (which are present
-	   * while running tests)
-	   */
-	  if (g_str_has_suffix (filename, ".gresource.xml"))
-	    continue;
+          /* Special case, ignore gresource files (which are present
+           * while running tests)
+           */
+          if (g_str_has_suffix (filename, ".gresource.xml"))
+            continue;
 
-	  /* If we're running in the bundle, don't ever try to load
-	   * anything except the GTK+ catalog
-	   */
-	  if (g_getenv (GLADE_ENV_BUNDLED) != NULL &&
-	      strcmp (filename, "gtk+.xml") != 0)
-	    continue;
+          /* If we're running in the bundle, don't ever try to load
+           * anything except the GTK+ catalog
+           */
+          if (g_getenv (GLADE_ENV_BUNDLED) != NULL &&
+              strcmp (filename, "gtk+.xml") != 0)
+            continue;
 
           catalog_filename = g_build_filename (path, filename, NULL);
           catalog = catalog_open (catalog_filename);
@@ -564,7 +566,7 @@ catalogs_from_path (GList *catalogs, const gchar *path)
 
 /**
  * glade_catalog_add_path:
- * @path:
+ * @path: the new path containing catalogs
  * 
  * Adds a new path to the list of path to look catalogs for.
  */
@@ -574,15 +576,15 @@ glade_catalog_add_path (const gchar *path)
   g_return_if_fail (path != NULL);
 
   if (g_list_find_custom (catalog_paths, path, (GCompareFunc) g_strcmp0) == NULL)
-	catalog_paths = g_list_append (catalog_paths, g_strdup (path));
+    catalog_paths = g_list_append (catalog_paths, g_strdup (path));
 }
 
 /**
  * glade_catalog_remove_path:
- * @path:
+ * @path: (nullable): the new path containing catalogs or %NULL to remove all of them
  * 
  * Remove path from the list of path to look catalogs for.
- * NULL to remove all paths.
+ * %NULL to remove all paths.
  */
 void
 glade_catalog_remove_path (const gchar *path)
@@ -590,20 +592,20 @@ glade_catalog_remove_path (const gchar *path)
   GList *l;
   
   if (path == NULL)
-	{
-	  g_list_free_full (catalog_paths, g_free);
-	  catalog_paths = NULL;
-	}
+    {
+      g_list_free_full (catalog_paths, g_free);
+      catalog_paths = NULL;
+    }
   else if ((l = g_list_find_custom (catalog_paths, path, (GCompareFunc) g_strcmp0)))
-	{
-	  catalog_paths = g_list_remove_link (catalog_paths, l); 
-	}
+    {
+      catalog_paths = g_list_remove_link (catalog_paths, l); 
+    }
 }
 
 /**
  * glade_catalog_get_extra_paths:
  *
- * Returns a list paths added by glade_catalog_add_path()
+ * Returns: (element-type utf8) (transfer none): a list paths added by glade_catalog_add_path()
  */
 const GList *
 glade_catalog_get_extra_paths (void)
@@ -619,7 +621,7 @@ glade_catalog_get_extra_paths (void)
  * then from glade_app_get_catalogs_dir() and finally from paths specified with
  * glade_catalog_add_path()
  *
- * Returns: the list of loaded GladeCatalog *
+ * Returns: (element-type GladeCatalog) (transfer none): the list of loaded GladeCatalog *
  */
 const GList *
 glade_catalog_load_all (void)
@@ -656,7 +658,7 @@ glade_catalog_load_all (void)
   for (l = catalog_paths; l; l = g_list_next (l))
     catalogs = catalogs_from_path (catalogs, l->data);
   
-  /* Catalogs need dependancies, most catalogs depend on
+  /* Catalogs need dependencies, most catalogs depend on
    * the gtk+ catalog, but some custom toolkits may depend
    * on the gnome catalog for instance.
    */
@@ -685,17 +687,17 @@ glade_catalog_load_all (void)
 
       /* Dont print missing icons in unit tests */
       if (glade_widget_adaptor_get_missing_icon (adaptor) &&
-	  g_getenv (GLADE_ENV_TESTING) == NULL)
+          g_getenv (GLADE_ENV_TESTING) == NULL)
         {
           if (!icon_warning)
             icon_warning = g_string_new ("Glade needs artwork; "
                                          "a default icon will be used for "
                                          "the following classes:");
 
-	  g_string_append_printf (icon_warning,
-				  "\n\t%s\tneeds an icon named '%s'",
-				  glade_widget_adaptor_get_name (adaptor), 
-				  glade_widget_adaptor_get_missing_icon (adaptor));
+          g_string_append_printf (icon_warning,
+                                  "\n\t%s\tneeds an icon named '%s'",
+                                  glade_widget_adaptor_get_name (adaptor), 
+                                  glade_widget_adaptor_get_missing_icon (adaptor));
         }
     }
 
@@ -718,7 +720,7 @@ glade_catalog_load_all (void)
  * 
  * Returns: The symbolic catalog name.
  */
-G_CONST_RETURN gchar *
+const gchar *
 glade_catalog_get_name (GladeCatalog *catalog)
 {
   g_return_val_if_fail (GLADE_IS_CATALOG (catalog), NULL);
@@ -726,13 +728,27 @@ glade_catalog_get_name (GladeCatalog *catalog)
   return catalog->name;
 }
 
+/**
+ * glade_catalog_get_prefix:
+ * @catalog: a catalog object
+ * 
+ * Returns: The catalog path prefix.
+ */
+const gchar *
+glade_catalog_get_prefix (GladeCatalog *catalog)
+{
+  g_return_val_if_fail (GLADE_IS_CATALOG (catalog), NULL);
+
+  return catalog->prefix;
+}
+
 /**
  * glade_catalog_get_book:
  * @catalog: a catalog object
  * 
  * Returns: The Devhelp search domain.
  */
-G_CONST_RETURN gchar *
+const gchar *
 glade_catalog_get_book (GladeCatalog *catalog)
 {
   g_return_val_if_fail (GLADE_IS_CATALOG (catalog), NULL);
@@ -746,7 +762,7 @@ glade_catalog_get_book (GladeCatalog *catalog)
  * 
  * Returns: The domain to be used to translate strings from this catalog
  */
-G_CONST_RETURN gchar *
+const gchar *
 glade_catalog_get_domain (GladeCatalog *catalog)
 {
   g_return_val_if_fail (GLADE_IS_CATALOG (catalog), NULL);
@@ -760,7 +776,7 @@ glade_catalog_get_domain (GladeCatalog *catalog)
  * 
  * Returns: The prefix for icons.
  */
-G_CONST_RETURN gchar *
+const gchar *
 glade_catalog_get_icon_prefix (GladeCatalog *catalog)
 {
   g_return_val_if_fail (GLADE_IS_CATALOG (catalog), NULL);
@@ -800,7 +816,7 @@ glade_catalog_get_minor_version (GladeCatalog *catalog)
  * glade_catalog_get_targets:
  * @catalog: a catalog object
  * 
- * Returns: the list of suitable version targets.
+ * Returns: (transfer none) (element-type GladeTargetableVersion): the list of suitable version targets.
  */
 GList *
 glade_catalog_get_targets (GladeCatalog *catalog)
@@ -814,7 +830,7 @@ glade_catalog_get_targets (GladeCatalog *catalog)
  * glade_catalog_get_widget_groups:
  * @catalog: a catalog object
  * 
- * Returns: the list of widget groups (palette)
+ * Returns: (transfer none) (element-type GladeWidgetGroup): the list of widget groups (palette)
  */
 GList *
 glade_catalog_get_widget_groups (GladeCatalog *catalog)
@@ -828,7 +844,7 @@ glade_catalog_get_widget_groups (GladeCatalog *catalog)
  * glade_catalog_get_adaptors:
  * @catalog: a catalog object
  * 
- * Returns: the list of widget class adaptors
+ * Returns: (transfer none) (element-type GladeWidgetAdaptor): the list of widget class adaptors
  */
 GList *
 glade_catalog_get_adaptors (GladeCatalog *catalog)
@@ -924,7 +940,7 @@ glade_widget_group_get_expanded (GladeWidgetGroup *group)
  * glade_widget_group_get_adaptors:
  * @group: a widget group
  * 
- * Returns: a list of class adaptors in the palette
+ * Returns: (transfer none) (element-type GladeWidgetAdaptor): a list of class adaptors in the palette
  */
 const GList *
 glade_widget_group_get_adaptors (GladeWidgetGroup *group)
