@@ -18,7 +18,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307,
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
  * USA.
  */
 
@@ -40,11 +40,11 @@
 #include "glade-placeholder.h"
 #include "glade-project.h"
 
-struct _GladeClipboardPrivate
+typedef struct _GladeClipboardPrivate
 {
   GList     *widgets;       /* A list of GladeWidget's on the clipboard */
   gboolean   has_selection; /* TRUE if clipboard has selection */
-};
+} GladeClipboardPrivate;
 
 enum
 {
@@ -64,11 +64,12 @@ glade_project_get_property (GObject    *object,
                             GParamSpec *pspec)
 {
   GladeClipboard *clipboard = GLADE_CLIPBOARD (object);
+  GladeClipboardPrivate *priv = glade_clipboard_get_instance_private (clipboard);
 
   switch (prop_id)
     {
       case PROP_HAS_SELECTION:
-        g_value_set_boolean (value, clipboard->priv->has_selection);
+        g_value_set_boolean (value, priv->has_selection);
         break;
       default:
         G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
@@ -99,19 +100,21 @@ glade_clipboard_class_init (GladeClipboardClass * klass)
 static void
 glade_clipboard_init (GladeClipboard *clipboard)
 {
-  clipboard->priv = glade_clipboard_get_instance_private (clipboard);
+  GladeClipboardPrivate *priv = glade_clipboard_get_instance_private (clipboard);
 
-  clipboard->priv->widgets = NULL;
-  clipboard->priv->has_selection = FALSE;
+  priv->widgets = NULL;
+  priv->has_selection = FALSE;
 }
 
 static void
 glade_clipboard_set_has_selection (GladeClipboard *clipboard,
                                    gboolean        has_selection)
 {
-  if (clipboard->priv->has_selection != has_selection)
+  GladeClipboardPrivate *priv = glade_clipboard_get_instance_private (clipboard);
+
+  if (priv->has_selection != has_selection)
     {
-      clipboard->priv->has_selection = has_selection;
+      priv->has_selection = has_selection;
       g_object_notify_by_pspec (G_OBJECT (clipboard), properties[PROP_HAS_SELECTION]);
     }
 
@@ -126,18 +129,27 @@ glade_clipboard_set_has_selection (GladeClipboard *clipboard,
 gboolean
 glade_clipboard_get_has_selection (GladeClipboard *clipboard)
 {
+  GladeClipboardPrivate *priv = glade_clipboard_get_instance_private (clipboard);
+
   g_return_val_if_fail (GLADE_IS_CLIPBOARD (clipboard), FALSE);
 
-  return clipboard->priv->has_selection;
+  return priv->has_selection;
 }
 
+/**
+ * glade_clipboard_widgets:
+ * @clipboard: a #GladeClipboard
+ * 
+ * Returns: (element-type GladeWidget) (transfer none): a #GList of #GladeWidgets
+ */
 GList *
 glade_clipboard_widgets (GladeClipboard *clipboard)
 {
+  GladeClipboardPrivate *priv = glade_clipboard_get_instance_private (clipboard);
+
   g_return_val_if_fail (GLADE_IS_CLIPBOARD (clipboard), NULL);
 
-
-  return clipboard->priv->widgets;
+  return priv->widgets;
 }
 
 /**
@@ -154,7 +166,7 @@ glade_clipboard_new (void)
 /**
  * glade_clipboard_add:
  * @clipboard: a #GladeClipboard
- * @widgets: a #GList of #GladeWidgets
+ * @widgets: (element-type GladeWidget): a #GList of #GladeWidgets
  * 
  * Adds @widgets to @clipboard.
  * This increases the reference count of each #GladeWidget in @widgets.
@@ -162,6 +174,7 @@ glade_clipboard_new (void)
 void
 glade_clipboard_add (GladeClipboard *clipboard, GList *widgets)
 {
+  GladeClipboardPrivate *priv = glade_clipboard_get_instance_private (clipboard);
   GladeWidget *widget;
   GList *list;
 
@@ -175,8 +188,8 @@ glade_clipboard_add (GladeClipboard *clipboard, GList *widgets)
   for (list = widgets; list && list->data; list = list->next)
     {
       widget = list->data;
-      clipboard->priv->widgets =
-          g_list_prepend (clipboard->priv->widgets, g_object_ref_sink (G_OBJECT (widget)));
+      priv->widgets =
+          g_list_prepend (priv->widgets, g_object_ref_sink (G_OBJECT (widget)));
     }
 
   glade_clipboard_set_has_selection (clipboard, TRUE);
@@ -191,20 +204,21 @@ glade_clipboard_add (GladeClipboard *clipboard, GList *widgets)
 void
 glade_clipboard_clear (GladeClipboard *clipboard)
 {
+  GladeClipboardPrivate *priv = glade_clipboard_get_instance_private (clipboard);
   GladeWidget *widget;
   GList *list;
 
   g_return_if_fail (GLADE_IS_CLIPBOARD (clipboard));
 
-  for (list = clipboard->priv->widgets; list && list->data; list = list->next)
+  for (list = priv->widgets; list && list->data; list = list->next)
     {
       widget = list->data;
 
       g_object_unref (G_OBJECT (widget));
     }
 
-  clipboard->priv->widgets = 
-    (g_list_free (clipboard->priv->widgets), NULL);
+  priv->widgets = 
+    (g_list_free (priv->widgets), NULL);
 
   glade_clipboard_set_has_selection (clipboard, FALSE);
 }
