@@ -34,31 +34,33 @@
 /* GObjectClass */
 static void      glade_editor_skeleton_dispose        (GObject *object);
 
-/* GladeEditableIface */
-static void      glade_editor_skeleton_editable_init   (GladeEditableIface *iface);
+/* GladeEditableInterface */
+static void      glade_editor_skeleton_editable_init   (GladeEditableInterface *iface);
 
 /* GtkBuildableIface */
 static void      glade_editor_skeleton_buildable_init  (GtkBuildableIface *iface);
 
+typedef struct _GladeEditorSkeletonPrivate GladeEditorSkeletonPrivate;
+
 struct _GladeEditorSkeletonPrivate
 {
   GSList *editors;
 };
 
-static GladeEditableIface *parent_editable_iface;
+static GladeEditableInterface *parent_editable_iface;
 static GtkBuildableIface  *parent_buildable_iface;
 
 G_DEFINE_TYPE_WITH_CODE (GladeEditorSkeleton, glade_editor_skeleton, GTK_TYPE_BOX,
                          G_ADD_PRIVATE (GladeEditorSkeleton)
-			 G_IMPLEMENT_INTERFACE (GLADE_TYPE_EDITABLE,
+                         G_IMPLEMENT_INTERFACE (GLADE_TYPE_EDITABLE,
                                                 glade_editor_skeleton_editable_init)
-			 G_IMPLEMENT_INTERFACE (GTK_TYPE_BUILDABLE,
-						glade_editor_skeleton_buildable_init));
+                         G_IMPLEMENT_INTERFACE (GTK_TYPE_BUILDABLE,
+                                                glade_editor_skeleton_buildable_init));
 
 static void
 glade_editor_skeleton_init (GladeEditorSkeleton *skeleton)
 {
-  skeleton->priv = glade_editor_skeleton_get_instance_private (skeleton);
+  
 }
 
 static void
@@ -76,7 +78,7 @@ static void
 glade_editor_skeleton_dispose (GObject *object)
 {
   GladeEditorSkeleton *skeleton = GLADE_EDITOR_SKELETON (object);
-  GladeEditorSkeletonPrivate *priv = skeleton->priv;
+  GladeEditorSkeletonPrivate *priv = glade_editor_skeleton_get_instance_private (skeleton);
 
   if (priv->editors)
     {
@@ -88,14 +90,14 @@ glade_editor_skeleton_dispose (GObject *object)
 }
 
 /*******************************************************************************
- *                            GladeEditableIface                               *                               
+ *                          GladeEditableInterface                             *
  *******************************************************************************/
 static void
-glade_editor_skeleton_load (GladeEditable   *editable,
-			    GladeWidget     *widget)
+glade_editor_skeleton_load (GladeEditable *editable,
+                            GladeWidget   *widget)
 {
   GladeEditorSkeleton *skeleton = GLADE_EDITOR_SKELETON (editable);
-  GladeEditorSkeletonPrivate *priv = skeleton->priv;
+  GladeEditorSkeletonPrivate *priv = glade_editor_skeleton_get_instance_private (skeleton);
   GSList *l;
 
   /* Chain up to default implementation */
@@ -113,7 +115,7 @@ static void
 glade_editor_skeleton_set_show_name (GladeEditable *editable, gboolean show_name)
 {
   GladeEditorSkeleton *skeleton = GLADE_EDITOR_SKELETON (editable);
-  GladeEditorSkeletonPrivate *priv = skeleton->priv;
+  GladeEditorSkeletonPrivate *priv = glade_editor_skeleton_get_instance_private (skeleton);
   GSList *l;
 
   for (l = priv->editors; l; l = l->next)
@@ -125,7 +127,7 @@ glade_editor_skeleton_set_show_name (GladeEditable *editable, gboolean show_name
 }
 
 static void
-glade_editor_skeleton_editable_init (GladeEditableIface *iface)
+glade_editor_skeleton_editable_init (GladeEditableInterface *iface)
 {
   parent_editable_iface = g_type_default_interface_peek (GLADE_TYPE_EDITABLE);
 
@@ -143,11 +145,11 @@ typedef struct
 
 static void
 editor_start_element (GMarkupParseContext  *context,
-		      const gchar          *element_name,
-		      const gchar         **names,
-		      const gchar         **values,
-		      gpointer              user_data,
-		      GError              **error)
+                      const gchar          *element_name,
+                      const gchar         **names,
+                      const gchar         **values,
+                      gpointer              user_data,
+                      GError              **error)
 {
   EditorParserData *editor_data = (EditorParserData *)user_data;
   gchar *id;
@@ -177,11 +179,11 @@ static const GMarkupParser editor_parser =
 
 static gboolean
 glade_editor_skeleton_custom_tag_start (GtkBuildable  *buildable,
-					GtkBuilder    *builder,
-					GObject       *child,
-					const gchar   *tagname,
-					GMarkupParser *parser,
-					gpointer      *data)
+                                        GtkBuilder    *builder,
+                                        GObject       *child,
+                                        const gchar   *tagname,
+                                        GMarkupParser *parser,
+                                        gpointer      *data)
 {
   if (strcmp (tagname, "child-editors") == 0)
     {
@@ -194,15 +196,15 @@ glade_editor_skeleton_custom_tag_start (GtkBuildable  *buildable,
     }
 
   return parent_buildable_iface->custom_tag_start (buildable, builder, child,
-						   tagname, parser, data);
+                                                   tagname, parser, data);
 }
 
 static void
 glade_editor_skeleton_custom_finished (GtkBuildable *buildable,
-				       GtkBuilder   *builder,
-				       GObject      *child,
-				       const gchar  *tagname,
-				       gpointer      user_data)
+                                       GtkBuilder   *builder,
+                                       GObject      *child,
+                                       const gchar  *tagname,
+                                       gpointer      user_data)
 {
   EditorParserData *editor_data = (EditorParserData *)user_data;
   GSList *l;
@@ -210,7 +212,7 @@ glade_editor_skeleton_custom_finished (GtkBuildable *buildable,
   if (strcmp (tagname, "child-editors") != 0)
     {
       parent_buildable_iface->custom_finished (buildable, builder, child,
-					       tagname, user_data);
+                                               tagname, user_data);
       return;
     }
 
@@ -222,11 +224,11 @@ glade_editor_skeleton_custom_finished (GtkBuildable *buildable,
       object = gtk_builder_get_object (builder, id);
 
       if (!GLADE_EDITABLE (object))
-	g_warning ("Object '%s' is not a GladeEditable\n",
-		   object ? G_OBJECT_TYPE_NAME (object) : "(null)");
+        g_warning ("Object '%s' is not a GladeEditable\n",
+                   object ? G_OBJECT_TYPE_NAME (object) : "(null)");
       else
-	glade_editor_skeleton_add_editor (GLADE_EDITOR_SKELETON (buildable),
-					  GLADE_EDITABLE (object));
+        glade_editor_skeleton_add_editor (GLADE_EDITOR_SKELETON (buildable),
+                                          GLADE_EDITABLE (object));
     }
 
   g_slist_free_full (editor_data->editors, g_free);
@@ -252,15 +254,13 @@ glade_editor_skeleton_new (void)
 
 void
 glade_editor_skeleton_add_editor (GladeEditorSkeleton *skeleton,
-				  GladeEditable       *editor)
+                                  GladeEditable       *editor)
 {
-  GladeEditorSkeletonPrivate *priv;
+  GladeEditorSkeletonPrivate *priv = glade_editor_skeleton_get_instance_private (skeleton);
 
   g_return_if_fail (GLADE_IS_EDITOR_SKELETON (skeleton));
   g_return_if_fail (GLADE_IS_EDITABLE (editor));
 
-  priv = skeleton->priv;
-
   g_object_ref (editor);
   priv->editors = g_slist_prepend (priv->editors, editor);
 }
