@@ -44,7 +44,7 @@
 #include "glade-editor.h"
 #include "glade-signal-editor.h"
 #include "glade-property.h"
-#include "glade-property-class.h"
+#include "glade-property-def.h"
 #include "glade-command.h"
 #include "glade-debug.h"
 #include "glade-marshallers.h"
@@ -53,9 +53,9 @@
 #include "glade-editor-property.h"
 
 static void glade_editor_switch_page (GtkNotebook     *notebook,
-				      GtkWidget       *page,
-				      guint            page_num,
-				      GladeEditor     *editor);
+                                      GtkWidget       *page,
+                                      guint            page_num,
+                                      GladeEditor     *editor);
 
 enum
 {
@@ -65,35 +65,34 @@ enum
   PROP_SHOW_CLASS_FIELD,
   PROP_CLASS_FIELD,
   PROP_SHOW_BORDER,
+  PROP_SIGNAL_EDITOR,
   N_PROPERTIES
 };
 
-#define GLADE_EDITOR_PRIVATE(object) (((GladeEditor*)object)->priv)
-
-struct _GladeEditorPrivate
+typedef struct _GladeEditorPrivate
 {
 
   GtkWidget *notebook; /* The notebook widget */
 
   GladeWidget *loaded_widget; /* A handy pointer to the GladeWidget
-			       * that is loaded in the editor. NULL
-			       * if no widgets are selected
-			       */
+                               * that is loaded in the editor. NULL
+                               * if no widgets are selected
+                               */
 
   GladeWidgetAdaptor *loaded_adaptor; /* A pointer to the loaded
-				       * GladeWidgetAdaptor. Note that we can
-				       * have a class loaded without a
-				       * loaded_widget. For this reason we
-				       * can't use loaded_widget->adaptor.
-				       * When a widget is selected we load
-				       * this class in the editor first and
-				       * then fill the values of the inputs
-				       * with the GladeProperty items.
-				       * This is usefull for not having
-				       * to redraw/container_add the widgets
-				       * when we switch from widgets of the
-				       * same class
-				       */
+                                       * GladeWidgetAdaptor. Note that we can
+                                       * have a class loaded without a
+                                       * loaded_widget. For this reason we
+                                       * can't use loaded_widget->adaptor.
+                                       * When a widget is selected we load
+                                       * this class in the editor first and
+                                       * then fill the values of the inputs
+                                       * with the GladeProperty items.
+                                       * This is usefull for not having
+                                       * to redraw/container_add the widgets
+                                       * when we switch from widgets of the
+                                       * same class
+                                       */
 
   GtkWidget *page_widget;
   GtkWidget *page_packing;
@@ -101,24 +100,24 @@ struct _GladeEditorPrivate
   GtkWidget *page_atk;
 
   GladeSignalEditor *signal_editor; /* The signal editor packed into vbox_signals
-				     */
+                                     */
 
   GList *editables;     /* A list of GladeEditables. We have a widget
-			 * for each GladeWidgetAdaptor and we only load
-			 * them on demand
-			 */
-	
-  GtkWidget *packing_page; /* Packing pages are dynamicly created each
-			    * selection, this pointer is only to free
-			    * the last packing page.
-			    */
+                         * for each GladeWidgetAdaptor and we only load
+                         * them on demand
+                         */
+        
+  GtkWidget *packing_page; /* Packing pages are dynamically created each
+                            * selection, this pointer is only to free
+                            * the last packing page.
+                            */
   
   gboolean loading; /* Use when loading a GladeWidget into the editor
-		     * we set this flag so that we can ignore the
-		     * "changed" signal of the name entry text since
-		     * the name has not really changed, just a new name
-		     * was loaded.
-		     */
+                     * we set this flag so that we can ignore the
+                     * "changed" signal of the name entry text since
+                     * the name has not really changed, just a new name
+                     * was loaded.
+                     */
 
   gulong project_closed_signal_id; /* Unload widget when widget's project closes  */
   gulong project_removed_signal_id; /* Unload widget when its removed from the project. */
@@ -128,15 +127,15 @@ struct _GladeEditorPrivate
   GtkWidget *class_field; /* The class header */
 
   GtkWidget *warning;   /* A pointer to an icon we can show in the class
-			 * field to publish tooltips for class related
-			 * versioning errors.
-			 */
+                         * field to publish tooltips for class related
+                         * versioning errors.
+                         */
 
   GtkWidget *class_icon; /* An image with the current widget's class icon.  */
   GtkWidget *class_label; /* A label with the current class label. */
 
   gboolean show_class_field; /* Whether or not to show the class field at the top */
-};
+} GladeEditorPrivate;
 
 G_DEFINE_TYPE_WITH_PRIVATE (GladeEditor, glade_editor, GTK_TYPE_BOX);
 
@@ -149,6 +148,7 @@ glade_editor_set_property (GObject      *object,
                            GParamSpec   *pspec)
 {
   GladeEditor *editor = GLADE_EDITOR (object);
+  GladeEditorPrivate *priv = glade_editor_get_instance_private (editor);
 
   switch (prop_id)
     {
@@ -165,7 +165,7 @@ glade_editor_set_property (GObject      *object,
           glade_editor_hide_class_field (editor);
         break;
       case PROP_SHOW_BORDER:
-        gtk_notebook_set_show_border (GTK_NOTEBOOK (editor->priv->notebook),
+        gtk_notebook_set_show_border (GTK_NOTEBOOK (priv->notebook),
                                       g_value_get_boolean (value));
         break;
       default:
@@ -181,6 +181,7 @@ glade_editor_get_property (GObject    *object,
                            GParamSpec *pspec)
 {
   GladeEditor *editor = GLADE_EDITOR (object);
+  GladeEditorPrivate *priv = glade_editor_get_instance_private (editor);
 
   switch (prop_id)
     {
@@ -188,16 +189,19 @@ glade_editor_get_property (GObject    *object,
         g_value_set_boolean (value, FALSE);
         break;
       case PROP_WIDGET:
-        g_value_set_object (value, editor->priv->loaded_widget);
+        g_value_set_object (value, priv->loaded_widget);
         break;
       case PROP_SHOW_CLASS_FIELD:
-        g_value_set_boolean (value, editor->priv->show_class_field);
+        g_value_set_boolean (value, priv->show_class_field);
         break;
       case PROP_CLASS_FIELD:
-        g_value_set_static_string (value, gtk_label_get_label (GTK_LABEL (editor->priv->class_label)));
+        g_value_set_static_string (value, gtk_label_get_label (GTK_LABEL (priv->class_label)));
         break;
       case PROP_SHOW_BORDER:
-        g_value_set_boolean (value, gtk_notebook_get_show_border (GTK_NOTEBOOK (editor->priv->notebook)));
+        g_value_set_boolean (value, gtk_notebook_get_show_border (GTK_NOTEBOOK (priv->notebook)));
+        break;
+      case PROP_SIGNAL_EDITOR:
+        g_value_set_object (value, priv->signal_editor);
         break;
       default:
         G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
@@ -208,8 +212,8 @@ glade_editor_get_property (GObject    *object,
 static void
 glade_editor_dispose (GObject *object)
 {
-  GladeEditorPrivate *priv = GLADE_EDITOR_PRIVATE (object);
   GladeEditor *editor = GLADE_EDITOR (object);
+  GladeEditorPrivate *priv = glade_editor_get_instance_private (editor);
 
   glade_editor_load_widget (editor, NULL);
 
@@ -259,12 +263,20 @@ glade_editor_class_init (GladeEditorClass *klass)
                          _("The class field string"),
                          NULL,
                          G_PARAM_READABLE);
+
   properties[PROP_SHOW_BORDER] =
     g_param_spec_boolean ("show-boder",
                           _("Show Border"),
                           _("Whether the border should be shown"),
                           TRUE,
                           G_PARAM_READWRITE);
+
+  properties[PROP_SIGNAL_EDITOR] =
+    g_param_spec_object ("signal-editor",
+                         _("Signal Editor"),
+                         _("The signal editor used to edit signals"),
+                         GLADE_TYPE_SIGNAL_EDITOR,
+                         G_PARAM_READABLE);
   
   /* Install all properties */
   g_object_class_install_properties (object_class, N_PROPERTIES, properties);
@@ -291,7 +303,7 @@ glade_editor_update_class_warning_cb (GladeWidget *widget,
                                       GParamSpec  *pspec,
                                       GladeEditor *editor)
 {
-  GladeEditorPrivate *priv = GLADE_EDITOR_PRIVATE (editor);
+  GladeEditorPrivate *priv = glade_editor_get_instance_private (editor);
 
   if (glade_widget_support_warning (widget))
     gtk_widget_show (priv->warning);
@@ -305,7 +317,7 @@ glade_editor_update_class_warning_cb (GladeWidget *widget,
 static void
 glade_editor_update_class_field (GladeEditor *editor)
 {
-  GladeEditorPrivate *priv = GLADE_EDITOR_PRIVATE (editor);
+  GladeEditorPrivate *priv = glade_editor_get_instance_private (editor);
 
   if (priv->loaded_widget)
     {
@@ -324,8 +336,8 @@ glade_editor_update_class_field (GladeEditor *editor)
            */
           text = g_strdup_printf (_("%s Properties - %s [%s]"),
                                   glade_widget_adaptor_get_title (priv->loaded_adaptor),
-                                  glade_widget_adaptor_get_name (priv->loaded_adaptor), 
-		                  glade_widget_get_display_name (widget));
+                                  glade_widget_adaptor_get_display_name (priv->loaded_adaptor),
+                                  glade_widget_get_display_name (widget));
         }
       else
         {
@@ -334,9 +346,9 @@ glade_editor_update_class_field (GladeEditor *editor)
            */
           text = g_strdup_printf (_("%s Properties - %s"),
                                   glade_widget_adaptor_get_title (priv->loaded_adaptor),
-                                  glade_widget_adaptor_get_name (priv->loaded_adaptor));
-	}
-		 
+                                  glade_widget_adaptor_get_display_name (priv->loaded_adaptor));
+        }
+
       gtk_label_set_text (GTK_LABEL (priv->class_label), text);
       g_free (text);
 
@@ -361,12 +373,12 @@ glade_editor_update_widget_name_cb (GladeWidget *widget,
 }
 
 static void
-glade_editor_switch_page (GtkNotebook     *notebook,
-			  GtkWidget       *page,
-			  guint            page_num,
-			  GladeEditor     *editor)
+glade_editor_switch_page (GtkNotebook *notebook,
+                          GtkWidget   *page,
+                          guint        page_num,
+                          GladeEditor *editor)
 {
-  GladeEditorPrivate *priv = GLADE_EDITOR_PRIVATE (editor);
+  GladeEditorPrivate *priv = glade_editor_get_instance_private (editor);
 
   gtk_widget_hide (priv->page_widget);
   gtk_widget_hide (priv->page_packing);
@@ -393,11 +405,9 @@ glade_editor_switch_page (GtkNotebook     *notebook,
 static void
 glade_editor_init (GladeEditor *editor)
 {
-  GladeEditorPrivate *priv;
+  GladeEditorPrivate *priv = glade_editor_get_instance_private (editor);
   gint                icon_height;
 
-  editor->priv = priv = glade_editor_get_instance_private (editor);
-
   priv->show_class_field = TRUE;
 
   gtk_widget_init_template (GTK_WIDGET (editor));
@@ -413,7 +423,7 @@ glade_editor_get_editable_by_adaptor (GladeEditor        *editor,
                                       GladeWidgetAdaptor *adaptor,
                                       GladeEditorPageType type)
 {
-  GladeEditorPrivate *priv = GLADE_EDITOR_PRIVATE (editor);
+  GladeEditorPrivate *priv = glade_editor_get_instance_private (editor);
   GtkWidget *editable;
   GList *list;
 
@@ -458,14 +468,14 @@ hide_or_remove_visible_child (GtkContainer *container, gboolean remove)
       widget = l->data;
 
       if (gtk_widget_get_visible (widget))
-	{
-	  gtk_widget_hide (widget);
+        {
+          gtk_widget_hide (widget);
 
-	  if (remove)
-	    gtk_container_remove (container, widget);
+          if (remove)
+            gtk_container_remove (container, widget);
 
-	  break;
-	}
+          break;
+        }
     }
   g_list_free (children);
 }
@@ -475,7 +485,7 @@ glade_editor_load_editable_in_page (GladeEditor        *editor,
                                     GladeWidgetAdaptor *adaptor,
                                     GladeEditorPageType type)
 {
-  GladeEditorPrivate *priv = GLADE_EDITOR_PRIVATE (editor);
+  GladeEditorPrivate *priv = glade_editor_get_instance_private (editor);
   GtkContainer *container = NULL;
   GtkWidget *scrolled_window, *editable;
   GtkAdjustment *adj;
@@ -518,7 +528,7 @@ glade_editor_load_editable_in_page (GladeEditor        *editor,
 
   if ((scrolled_window = 
        gtk_widget_get_ancestor (GTK_WIDGET (container), 
-				GTK_TYPE_SCROLLED_WINDOW)) != NULL)
+                                GTK_TYPE_SCROLLED_WINDOW)) != NULL)
     {
       adj = gtk_scrolled_window_get_vadjustment (GTK_SCROLLED_WINDOW (scrolled_window));
       gtk_container_set_focus_vadjustment (GTK_CONTAINER (editable), adj);
@@ -534,20 +544,21 @@ static void
 glade_editor_load_widget_class (GladeEditor *editor,
                                 GladeWidgetAdaptor *adaptor)
 {
+  GladeEditorPrivate *priv = glade_editor_get_instance_private (editor);
 
   glade_editor_load_editable_in_page (editor, adaptor, GLADE_PAGE_GENERAL);
   glade_editor_load_editable_in_page (editor, adaptor, GLADE_PAGE_COMMON);
   glade_editor_load_editable_in_page (editor, adaptor, GLADE_PAGE_ATK);
   glade_editor_load_editable_in_page (editor, NULL, GLADE_PAGE_PACKING);
 
-  editor->priv->loaded_adaptor = adaptor;
+  priv->loaded_adaptor = adaptor;
 }
 
 static void
 glade_editor_close_cb (GladeProject *project, GladeEditor *editor)
 {
   /* project we are viewing was closed,
-   * detatch from editor.
+   * detouch from editor.
    */
   glade_editor_load_widget (editor, NULL);
 }
@@ -557,10 +568,12 @@ glade_editor_removed_cb (GladeProject *project,
                          GladeWidget *widget,
                          GladeEditor *editor)
 {
+  GladeEditorPrivate *priv = glade_editor_get_instance_private (editor);
+
   /* Widget we were viewing was removed from project,
-   * detatch from editor.
+   * detouch from editor.
    */
-  if (widget == editor->priv->loaded_widget)
+  if (widget == priv->loaded_widget)
     glade_editor_load_widget (editor, NULL);
 
 }
@@ -582,18 +595,18 @@ glade_editor_load_editable (GladeEditor        *editor,
       GladeWidgetAdaptor *adaptor;
 
       if (!parent)
-	return;
+        return;
 
       adaptor = glade_widget_get_adaptor (parent);
       editable =
-	glade_editor_load_editable_in_page (editor, adaptor,
-					    GLADE_PAGE_PACKING);
+        glade_editor_load_editable_in_page (editor, adaptor,
+                                            GLADE_PAGE_PACKING);
     }
   else
     editable = 
       glade_editor_get_editable_by_adaptor (editor, 
-					    glade_widget_get_adaptor (widget), 
-					    type);
+                                            glade_widget_get_adaptor (widget), 
+                                            type);
 
   g_assert (editable);
 
@@ -609,10 +622,11 @@ glade_editor_load_editable (GladeEditor        *editor,
 static void
 clear_editables (GladeEditor *editor)
 {
+  GladeEditorPrivate *priv = glade_editor_get_instance_private (editor);
   GladeEditable *editable;
   GList *l;
 
-  for (l = editor->priv->editables; l; l = l->next)
+  for (l = priv->editables; l; l = l->next)
     {
       editable = l->data;
       glade_editable_load (editable, NULL);
@@ -622,7 +636,7 @@ clear_editables (GladeEditor *editor)
 static void
 glade_editor_load_widget_real (GladeEditor *editor, GladeWidget *widget)
 {
-  GladeEditorPrivate *priv = GLADE_EDITOR_PRIVATE (editor);
+  GladeEditorPrivate *priv = glade_editor_get_instance_private (editor);
   GladeWidgetAdaptor *adaptor;
   GladeProject *project;
 
@@ -645,7 +659,7 @@ glade_editor_load_widget_real (GladeEditor *editor, GladeWidget *widget)
                                    priv->widget_name_id);
     }
 
-  /* Load the GladeWidgetClass */
+  /* Load the GladeWidgetAdaptor */
   adaptor = widget ? glade_widget_get_adaptor (widget) : NULL;
   if (priv->loaded_adaptor != adaptor || adaptor == NULL)
     glade_editor_load_widget_class (editor, adaptor);
@@ -725,10 +739,12 @@ glade_editor_new (void)
 void
 glade_editor_load_widget (GladeEditor *editor, GladeWidget *widget)
 {
+  GladeEditorPrivate *priv = glade_editor_get_instance_private (editor);
+
   g_return_if_fail (GLADE_IS_EDITOR (editor));
   g_return_if_fail (widget == NULL || GLADE_IS_WIDGET (widget));
 
-  if (editor->priv->loaded_widget == widget)
+  if (priv->loaded_widget == widget)
     return;
 
   glade_editor_load_widget_real (editor, widget);
@@ -751,8 +767,8 @@ query_dialog_style_set_cb (GtkWidget *dialog,
 
 static gboolean
 query_dialog_delete_event_cb (GtkDialog *dialog,
-			      GdkEvent  *event,
-			      gpointer   user_data)
+                              GdkEvent  *event,
+                              gpointer   user_data)
 {
   gtk_dialog_response (dialog, GTK_RESPONSE_CANCEL);
   return TRUE;
@@ -772,7 +788,7 @@ glade_editor_query_dialog (GladeWidget *widget)
   
   adaptor = glade_widget_get_adaptor (widget);
 
-  title = g_strdup_printf (_("Create a %s"), glade_widget_adaptor_get_name (adaptor));
+  title = g_strdup_printf (_("Create a %s"), glade_widget_adaptor_get_display_name (adaptor));
   dialog = gtk_dialog_new_with_buttons (title, NULL,
                                         GTK_DIALOG_MODAL |
                                         GTK_DIALOG_DESTROY_WITH_PARENT,
@@ -863,7 +879,7 @@ glade_editor_reset_view (void)
                                                G_TYPE_INT,      /* Parent node ?       */
                                                G_TYPE_BOOLEAN,  /* Child node ?        */
                                                G_TYPE_BOOLEAN,  /* Has default value   */
-                                               G_TYPE_BOOLEAN,  /* Doesn't have defaut */
+                                               G_TYPE_BOOLEAN,  /* Doesn't have default */
                                                G_TYPE_STRING);  /* Default string      */
 
   view_widget = gtk_tree_view_new_with_model (model);
@@ -923,7 +939,7 @@ glade_editor_populate_reset_view (GladeWidget *widget, GtkTreeView *tree_view)
   GtkTreeIter property_iter, general_iter, common_iter, atk_iter, *iter;
   GList *list;
   GladeProperty *property;
-  GladePropertyClass *pclass;
+  GladePropertyDef *pdef;
   gboolean def;
 
   g_return_if_fail (widget != NULL);
@@ -956,14 +972,14 @@ glade_editor_populate_reset_view (GladeWidget *widget, GtkTreeView *tree_view)
   for (list = glade_widget_get_properties (widget); list; list = list->next)
     {
       property = list->data;
-      pclass   = glade_property_get_class (property);
+      pdef     = glade_property_get_def (property);
 
-      if (glade_property_class_is_visible (pclass) == FALSE)
+      if (glade_property_def_is_visible (pdef) == FALSE)
         continue;
 
-      if (glade_property_class_atk (pclass))
+      if (glade_property_def_atk (pdef))
         iter = &atk_iter;
-      else if (glade_property_class_common (pclass))
+      else if (glade_property_def_common (pdef))
         iter = &common_iter;
       else
         iter = &general_iter;
@@ -973,7 +989,7 @@ glade_editor_populate_reset_view (GladeWidget *widget, GtkTreeView *tree_view)
       gtk_tree_store_append (model, &property_iter, iter);
       gtk_tree_store_set (model, &property_iter,
                           COLUMN_ENABLED, !def,
-                          COLUMN_PROP_NAME, glade_property_class_get_name (pclass),
+                          COLUMN_PROP_NAME, glade_property_def_get_name (pdef),
                           COLUMN_PROPERTY, property,
                           COLUMN_WEIGHT, PANGO_WEIGHT_NORMAL,
                           COLUMN_CHILD, TRUE,
@@ -991,7 +1007,7 @@ glade_editor_reset_selection_changed_cb (GtkTreeSelection *selection,
   GladeProperty *property = NULL;
   GtkTreeModel *model = NULL;
   GtkTextBuffer *text_buffer;
-  GladePropertyClass *pclass = NULL;
+  GladePropertyDef *pdef = NULL;
 
   const gchar *message =
       _("Select the properties that you want to reset to their default values");
@@ -1003,10 +1019,10 @@ glade_editor_reset_selection_changed_cb (GtkTreeSelection *selection,
       gtk_tree_model_get (model, &iter, COLUMN_PROPERTY, &property, -1);
 
       if (property)
-	pclass = glade_property_get_class (property);
+        pdef = glade_property_get_def (property);
 
       gtk_text_buffer_set_text (text_buffer,
-                                pclass ? glade_property_class_get_tooltip (pclass) : message,
+                                pdef ? glade_property_def_get_tooltip (pdef) : message,
                                 -1);
       if (property)
         g_object_unref (G_OBJECT (property));
@@ -1089,7 +1105,7 @@ static void
 glade_editor_reset_properties (GList *props)
 {
   GList *list, *sdata_list = NULL;
-  GCSetPropData *sdata;
+  GladeCommandSetPropData *sdata;
   GladeProperty *prop;
   GladeWidget   *widget;
   GladeProject *project = NULL;
@@ -1100,7 +1116,7 @@ glade_editor_reset_properties (GList *props)
       widget  = glade_property_get_widget (prop);
       project = glade_widget_get_project (widget);
 
-      sdata = g_new (GCSetPropData, 1);
+      sdata = g_new (GladeCommandSetPropData, 1);
       sdata->property = prop;
 
       sdata->old_value = g_new0 (GValue, 1);
@@ -1113,7 +1129,7 @@ glade_editor_reset_properties (GList *props)
     }
 
   if (project)
-    /* GladeCommand takes ownership of allocated list, ugly but practicle */
+    /* GladeCommand takes ownership of allocated list, ugly but practical */
     glade_command_set_properties_list (project, sdata_list);
 
 }
@@ -1252,12 +1268,10 @@ glade_editor_hide_info (GladeEditor *editor)
 void
 glade_editor_show_class_field (GladeEditor *editor)
 {
-  GladeEditorPrivate *priv;
+  GladeEditorPrivate *priv = glade_editor_get_instance_private (editor);
 
   g_return_if_fail (GLADE_IS_EDITOR (editor));
 
-  priv = GLADE_EDITOR_PRIVATE (editor);
-
   if (priv->show_class_field != TRUE)
     {
       priv->show_class_field = TRUE;
@@ -1270,12 +1284,10 @@ glade_editor_show_class_field (GladeEditor *editor)
 void
 glade_editor_hide_class_field (GladeEditor *editor)
 {
-  GladeEditorPrivate *priv;
+  GladeEditorPrivate *priv = glade_editor_get_instance_private (editor);
 
   g_return_if_fail (GLADE_IS_EDITOR (editor));
 
-  priv = GLADE_EDITOR_PRIVATE (editor);
-
   if (priv->show_class_field != FALSE)
     {
       priv->show_class_field = FALSE;
@@ -1287,8 +1299,8 @@ glade_editor_hide_class_field (GladeEditor *editor)
 
 static void
 editor_widget_name_changed (GladeWidget *widget,
-			    GParamSpec  *pspec,
-			    GtkWindow   *window)
+                            GParamSpec  *pspec,
+                            GtkWindow   *window)
 {
   gchar *title, *prj_name;
 
@@ -1308,7 +1320,7 @@ editor_widget_name_changed (GladeWidget *widget,
  * This convenience function creates a new dialog window to edit @widget
  * specifically.
  *
- * Returns: the newly created dialog window
+ * Returns: (transfer full): the newly created dialog window
  */
 GtkWidget *
 glade_editor_dialog_for_widget (GladeWidget *widget)
@@ -1324,7 +1336,7 @@ glade_editor_dialog_for_widget (GladeWidget *widget)
   /* Keep the title up to date */
   editor_widget_name_changed (widget, NULL, GTK_WINDOW (window));
   g_signal_connect_object (G_OBJECT (widget), "notify::name",
-			   G_CALLBACK (editor_widget_name_changed), window, 0);
+                           G_CALLBACK (editor_widget_name_changed), window, 0);
 
   if (glade_app_get_accel_group ())
     {
