@@ -53,20 +53,15 @@
 #include <gdk/gdkkeysyms.h>
 #endif
 
-#define GLADE_INSPECTOR_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object),\
-					    GLADE_TYPE_INSPECTOR,                 \
-			 		    GladeInspectorPrivate))
-
-
 static void     search_entry_text_inserted_cb (GtkEntry       *entry,
-					       const gchar    *text,
-					       gint            length,
-					       gint           *position,
-					       GladeInspector *inspector);
+                                               const gchar    *text,
+                                               gint            length,
+                                               gint           *position,
+                                               GladeInspector *inspector);
 static void     search_entry_text_deleted_cb  (GtkEditable    *editable,
-					       gint            start_pos,
-					       gint            end_pos,
-					       GladeInspector *inspector);
+                                               gint            start_pos,
+                                               gint            end_pos,
+                                               GladeInspector *inspector);
 
 enum
 {
@@ -82,7 +77,7 @@ enum
   LAST_SIGNAL
 };
 
-struct _GladeInspectorPrivate
+typedef struct _GladeInspectorPrivate
 {
   GtkWidget *view;
   GtkTreeModel *filter;
@@ -94,7 +89,7 @@ struct _GladeInspectorPrivate
   gboolean search_disabled;
   gchar *completion_text;
   gchar *completion_text_fold;
-};
+} GladeInspectorPrivate;
 
 static GParamSpec *properties[N_PROPERTIES];
 static guint glade_inspector_signals[LAST_SIGNAL] = { 0 };
@@ -117,8 +112,8 @@ G_DEFINE_TYPE_WITH_PRIVATE (GladeInspector, glade_inspector, GTK_TYPE_BOX)
 
 static void
 glade_inspector_set_property (GObject      *object,
-			      guint         property_id,
-			      const GValue *value,
+                              guint         property_id,
+                              const GValue *value,
                               GParamSpec   *pspec)
 {
   GladeInspector *inspector = GLADE_INSPECTOR (object);
@@ -208,7 +203,7 @@ glade_inspector_visible_func (GtkTreeModel *model,
                               gpointer      data)
 {
   GladeInspector *inspector = data;
-  GladeInspectorPrivate *priv = inspector->priv;
+  GladeInspectorPrivate *priv = glade_inspector_get_instance_private (inspector);
 
   GtkTreeIter iter;
 
@@ -247,7 +242,7 @@ glade_inspector_visible_func (GtkTreeModel *model,
 static void
 glade_inspector_refilter (GladeInspector *inspector)
 {
-  GladeInspectorPrivate *priv = inspector->priv;
+  GladeInspectorPrivate *priv = glade_inspector_get_instance_private (inspector);
 
   if (!priv->search_disabled)
     {
@@ -270,7 +265,7 @@ typedef struct {
 
 static void
 reduce_string (gchar *str1,
-	       const gchar *str2)
+               const gchar *str2)
 {
   gint str1len = strlen (str1);
   gint i;
@@ -279,10 +274,10 @@ reduce_string (gchar *str1,
     {
 
       if (str1[i] != str2[i] || i >= str1len)
-	{
-	  str1[i] = '\0';
-	  break;
-	}
+        {
+          str1[i] = '\0';
+          break;
+        }
     }
 
   if (str2[i] == '\0')
@@ -291,9 +286,9 @@ reduce_string (gchar *str1,
 
 static gboolean
 search_common_matches (GtkTreeModel    *model,
-		       GtkTreePath     *path,
-		       GtkTreeIter     *iter,
-		       CommonMatchData *data)
+                       GtkTreePath     *path,
+                       GtkTreeIter     *iter,
+                       CommonMatchData *data)
 {
   GladeWidget *gwidget;
   const gchar *name;
@@ -315,12 +310,12 @@ search_common_matches (GtkTreeModel    *model,
   if (match)
     {
       if (!data->first_match)
-	data->first_match = g_strdup (name);
+        data->first_match = g_strdup (name);
 
       if (data->common_text)
         reduce_string (data->common_text, name);
       else
-	data->common_text = g_strdup (name);
+        data->common_text = g_strdup (name);
     }
 
   g_object_unref (obj);
@@ -335,10 +330,11 @@ search_common_matches (GtkTreeModel    *model,
  */
 static gchar *
 get_partial_match (GladeInspector *inspector,
-		   const gchar    *search,
-		   gchar         **first_match)
+                   const gchar    *search,
+                   gchar         **first_match)
 {
-  GtkTreeModel     *model = GTK_TREE_MODEL (inspector->priv->project);
+  GladeInspectorPrivate *priv = glade_inspector_get_instance_private (inspector);
+  GtkTreeModel     *model = GTK_TREE_MODEL (priv->project);
   CommonMatchData   data;
 
   data.text        = search;
@@ -358,7 +354,7 @@ get_partial_match (GladeInspector *inspector,
 static void
 inspector_set_completion_text (GladeInspector *inspector, const gchar *text)
 {
-  GladeInspectorPrivate *priv = inspector->priv;
+  GladeInspectorPrivate *priv = glade_inspector_get_instance_private (inspector);
 
   g_free (priv->completion_text);
   priv->completion_text = g_strdup (text);
@@ -369,7 +365,7 @@ inspector_set_completion_text (GladeInspector *inspector, const gchar *text)
 static gboolean
 search_complete_idle (GladeInspector *inspector)
 {
-  GladeInspectorPrivate *priv = inspector->priv;
+  GladeInspectorPrivate *priv = glade_inspector_get_instance_private (inspector);
   gchar *completed;
   const gchar *str;
   gsize length;
@@ -409,7 +405,7 @@ search_entry_text_inserted_cb (GtkEntry       *entry,
                                gint           *position,
                                GladeInspector *inspector)
 {
-  GladeInspectorPrivate *priv = inspector->priv;
+  GladeInspectorPrivate *priv = glade_inspector_get_instance_private (inspector);
 
   if (!priv->search_disabled && !priv->idle_complete)
     {
@@ -420,11 +416,11 @@ search_entry_text_inserted_cb (GtkEntry       *entry,
 
 static void
 search_entry_text_deleted_cb (GtkEditable    *editable,
-			      gint            start_pos,
-			      gint            end_pos,
-			      GladeInspector *inspector)
+                              gint            start_pos,
+                              gint            end_pos,
+                              GladeInspector *inspector)
 {
-  GladeInspectorPrivate *priv = inspector->priv;
+  GladeInspectorPrivate *priv = glade_inspector_get_instance_private (inspector);
 
   if (!priv->search_disabled)
     {
@@ -438,7 +434,7 @@ search_entry_key_press_event_cb (GtkEntry       *entry,
                                  GdkEventKey    *event,
                                  GladeInspector *inspector)
 {
-  GladeInspectorPrivate *priv = inspector->priv;
+  GladeInspectorPrivate *priv = glade_inspector_get_instance_private (inspector);
   const gchar *str;
 
   str = gtk_entry_get_text (GTK_ENTRY (priv->entry));
@@ -457,7 +453,7 @@ search_entry_key_press_event_cb (GtkEntry       *entry,
           gtk_editable_set_position (GTK_EDITABLE (entry), -1);
           gtk_editable_select_region (GTK_EDITABLE (entry), -1, -1);
 
-	  glade_inspector_refilter (inspector);
+          glade_inspector_refilter (inspector);
         }
       return TRUE;
     }
@@ -469,27 +465,27 @@ search_entry_key_press_event_cb (GtkEntry       *entry,
 
       if (str && (name = get_partial_match (inspector, str, &full_match)))
         {
-	  GladeWidget *widget;
+          GladeWidget *widget;
 
           inspector_set_completion_text (inspector, full_match);
-	  g_free (name);
+          g_free (name);
 
-	  g_signal_handlers_block_by_func (priv->entry, search_entry_text_inserted_cb, inspector);
-	  g_signal_handlers_block_by_func (priv->entry, search_entry_text_deleted_cb, inspector);
+          g_signal_handlers_block_by_func (priv->entry, search_entry_text_inserted_cb, inspector);
+          g_signal_handlers_block_by_func (priv->entry, search_entry_text_deleted_cb, inspector);
 
           gtk_entry_set_text (GTK_ENTRY (entry), priv->completion_text);
 
-	  g_signal_handlers_unblock_by_func (priv->entry, search_entry_text_inserted_cb, inspector);
-	  g_signal_handlers_unblock_by_func (priv->entry, search_entry_text_deleted_cb, inspector);
+          g_signal_handlers_unblock_by_func (priv->entry, search_entry_text_inserted_cb, inspector);
+          g_signal_handlers_unblock_by_func (priv->entry, search_entry_text_deleted_cb, inspector);
 
           gtk_editable_set_position (GTK_EDITABLE (entry), -1);
           gtk_editable_select_region (GTK_EDITABLE (entry), -1, -1);
 
-	  glade_inspector_refilter (inspector);
+          glade_inspector_refilter (inspector);
 
-	  widget = glade_project_get_widget_by_name (priv->project, priv->completion_text);
-	  if (widget)
-	    glade_project_selection_set (priv->project, glade_widget_get_object (widget), TRUE);
+          widget = glade_project_get_widget_by_name (priv->project, priv->completion_text);
+          if (widget)
+            glade_project_selection_set (priv->project, glade_widget_get_object (widget), TRUE);
         }
       return TRUE;
     }
@@ -498,31 +494,31 @@ search_entry_key_press_event_cb (GtkEntry       *entry,
   if (event->keyval == GDK_KEY_BackSpace)
     {
       if (!priv->search_disabled && !priv->idle_complete && str && str[0])
-	{
-	  /* Now, set the text to the current completion text -1 char, and recomplete */
-	  if (priv->completion_text && priv->completion_text[0])
-	    {
-	      /* If we're not at the position of the length of the completion text, just carry on */
-	      if (!gtk_editable_get_selection_bounds (GTK_EDITABLE (priv->entry), NULL, NULL))
-		return FALSE;
+        {
+          /* Now, set the text to the current completion text -1 char, and recomplete */
+          if (priv->completion_text && priv->completion_text[0])
+            {
+              /* If we're not at the position of the length of the completion text, just carry on */
+              if (!gtk_editable_get_selection_bounds (GTK_EDITABLE (priv->entry), NULL, NULL))
+                return FALSE;
 
-	      priv->completion_text[strlen (priv->completion_text) -1] = '\0';
+              priv->completion_text[strlen (priv->completion_text) -1] = '\0';
 
-	      g_signal_handlers_block_by_func (priv->entry, search_entry_text_inserted_cb, inspector);
-	      g_signal_handlers_block_by_func (priv->entry, search_entry_text_deleted_cb, inspector);
+              g_signal_handlers_block_by_func (priv->entry, search_entry_text_inserted_cb, inspector);
+              g_signal_handlers_block_by_func (priv->entry, search_entry_text_deleted_cb, inspector);
 
-	      gtk_entry_set_text (GTK_ENTRY (priv->entry), priv->completion_text);
-	      gtk_editable_set_position (GTK_EDITABLE (priv->entry), -1);
+              gtk_entry_set_text (GTK_ENTRY (priv->entry), priv->completion_text);
+              gtk_editable_set_position (GTK_EDITABLE (priv->entry), -1);
 
-	      g_signal_handlers_unblock_by_func (priv->entry, search_entry_text_inserted_cb, inspector);
-	      g_signal_handlers_unblock_by_func (priv->entry, search_entry_text_deleted_cb, inspector);
+              g_signal_handlers_unblock_by_func (priv->entry, search_entry_text_inserted_cb, inspector);
+              g_signal_handlers_unblock_by_func (priv->entry, search_entry_text_deleted_cb, inspector);
 
-	      priv->idle_complete =
-		g_idle_add ((GSourceFunc) search_complete_idle, inspector);
+              priv->idle_complete =
+                g_idle_add ((GSourceFunc) search_complete_idle, inspector);
 
-	      return TRUE;
-	    }
-	}
+              return TRUE;
+            }
+        }
     }
 
   return FALSE;
@@ -533,7 +529,7 @@ search_entry_focus_in_cb (GtkWidget      *entry,
                           GdkEventFocus  *event,
                           GladeInspector *inspector)
 {
-  GladeInspectorPrivate *priv = inspector->priv;
+  GladeInspectorPrivate *priv = glade_inspector_get_instance_private (inspector);
 
   if (priv->search_disabled)
     priv->search_disabled = FALSE;
@@ -546,7 +542,7 @@ search_entry_focus_out_cb (GtkWidget      *entry,
                            GdkEventFocus  *event,
                            GladeInspector *inspector)
 {
-  GladeInspectorPrivate *priv = inspector->priv;
+  GladeInspectorPrivate *priv = glade_inspector_get_instance_private (inspector);
 
   priv->search_disabled = TRUE;
 
@@ -562,14 +558,12 @@ search_entry_focus_out_cb (GtkWidget      *entry,
 static void
 glade_inspector_init (GladeInspector *inspector)
 {
-  GladeInspectorPrivate *priv;
+  GladeInspectorPrivate *priv = glade_inspector_get_instance_private (inspector);
   GtkWidget *sw;
   GtkTreeSelection *selection;
 
-  inspector->priv = priv = glade_inspector_get_instance_private (inspector);
-
   gtk_orientable_set_orientation (GTK_ORIENTABLE (inspector),
-				  GTK_ORIENTATION_VERTICAL);
+                                  GTK_ORIENTATION_VERTICAL);
 
   priv->project = NULL;
 
@@ -602,7 +596,7 @@ glade_inspector_init (GladeInspector *inspector)
   /* Set it as a drag source */
   gtk_tree_view_enable_model_drag_source (GTK_TREE_VIEW (priv->view),
                                           GDK_BUTTON1_MASK,
-                                          _glade_dnd_get_target (), 1, 0);
+                                          _glade_dnd_get_target (), 1, GDK_ACTION_MOVE | GDK_ACTION_COPY);
 
   g_signal_connect (G_OBJECT (priv->view), "row-activated",
                     G_CALLBACK (item_activated_cb), inspector);
@@ -636,13 +630,14 @@ static void
 glade_inspector_dispose (GObject *object)
 {
   GladeInspector *inspector = GLADE_INSPECTOR (object);
+  GladeInspectorPrivate *priv = glade_inspector_get_instance_private (inspector);
 
   glade_inspector_set_project (inspector, NULL);
 
-  if (inspector->priv->idle_complete)
+  if (priv->idle_complete)
     {
-      g_source_remove (inspector->priv->idle_complete);
-      inspector->priv->idle_complete = 0;
+      g_source_remove (priv->idle_complete);
+      priv->idle_complete = 0;
     }
 
   G_OBJECT_CLASS (glade_inspector_parent_class)->dispose (object);
@@ -652,7 +647,7 @@ static void
 glade_inspector_finalize (GObject *object)
 {
   GladeInspector *inspector = GLADE_INSPECTOR (object);
-  GladeInspectorPrivate *priv = inspector->priv;
+  GladeInspectorPrivate *priv = glade_inspector_get_instance_private (inspector);
 
   g_free (priv->completion_text);
   g_free (priv->completion_text_fold);
@@ -664,6 +659,7 @@ static void
 project_selection_changed_cb (GladeProject   *project,
                               GladeInspector *inspector)
 {
+  GladeInspectorPrivate *priv = glade_inspector_get_instance_private (inspector);
   GladeWidget *widget;
   GtkTreeSelection *selection;
   GtkTreeModel *model;
@@ -673,18 +669,18 @@ project_selection_changed_cb (GladeProject   *project,
 
   g_return_if_fail (GLADE_IS_INSPECTOR (inspector));
   g_return_if_fail (GLADE_IS_PROJECT (project));
-  g_return_if_fail (inspector->priv->project == project);
+  g_return_if_fail (priv->project == project);
 
   g_signal_handlers_block_by_func (gtk_tree_view_get_selection
-                                   (GTK_TREE_VIEW (inspector->priv->view)),
+                                   (GTK_TREE_VIEW (priv->view)),
                                    G_CALLBACK (selection_changed_cb),
                                    inspector);
 
   selection =
-      gtk_tree_view_get_selection (GTK_TREE_VIEW (inspector->priv->view));
+      gtk_tree_view_get_selection (GTK_TREE_VIEW (priv->view));
   g_return_if_fail (selection != NULL);
 
-  model = inspector->priv->filter;
+  model = priv->filter;
 
   gtk_tree_selection_unselect_all (selection);
 
@@ -705,10 +701,10 @@ project_selection_changed_cb (GladeProject   *project,
               /* expand parent node */
               if (gtk_tree_path_up (ancestor_path))
                 gtk_tree_view_expand_to_path
-                    (GTK_TREE_VIEW (inspector->priv->view), ancestor_path);
+                    (GTK_TREE_VIEW (priv->view), ancestor_path);
 
               gtk_tree_view_scroll_to_cell (GTK_TREE_VIEW
-                                            (inspector->priv->view), path, NULL,
+                                            (priv->view), path, NULL,
                                             TRUE, 0.5, 0);
 
               gtk_tree_selection_select_iter (selection, iter);
@@ -721,7 +717,7 @@ project_selection_changed_cb (GladeProject   *project,
     }
 
   g_signal_handlers_unblock_by_func (gtk_tree_view_get_selection
-                                     (GTK_TREE_VIEW (inspector->priv->view)),
+                                     (GTK_TREE_VIEW (priv->view)),
                                      G_CALLBACK (selection_changed_cb),
                                      inspector);
 }
@@ -747,6 +743,7 @@ selection_foreach_func (GtkTreeModel *model,
 static void
 selection_changed_cb (GtkTreeSelection *selection, GladeInspector *inspector)
 {
+  GladeInspectorPrivate *priv = glade_inspector_get_instance_private (inspector);
   GList *sel = NULL, *l;
 
   gtk_tree_selection_selected_foreach (selection,
@@ -765,17 +762,17 @@ selection_changed_cb (GtkTreeSelection *selection, GladeInspector *inspector)
   if (!sel)
     return;
 
-  g_signal_handlers_block_by_func (inspector->priv->project,
+  g_signal_handlers_block_by_func (priv->project,
                                    G_CALLBACK (project_selection_changed_cb),
                                    inspector);
 
-  glade_project_selection_clear (inspector->priv->project, FALSE);
+  glade_project_selection_clear (priv->project, FALSE);
   for (l = sel; l; l = l->next)
-    glade_project_selection_add (inspector->priv->project, G_OBJECT (l->data), FALSE);
-  glade_project_selection_changed (inspector->priv->project);
+    glade_project_selection_add (priv->project, G_OBJECT (l->data), FALSE);
+  glade_project_selection_changed (priv->project);
   g_list_free (sel);
 
-  g_signal_handlers_unblock_by_func (inspector->priv->project,
+  g_signal_handlers_unblock_by_func (priv->project,
                                      G_CALLBACK (project_selection_changed_cb),
                                      inspector);
 
@@ -797,7 +794,7 @@ button_press_cb (GtkWidget      *widget,
                  GladeInspector *inspector)
 {
   GtkTreeView *view = GTK_TREE_VIEW (widget);
-  GladeInspectorPrivate *priv = inspector->priv;
+  GladeInspectorPrivate *priv = glade_inspector_get_instance_private (inspector);
   GtkTreePath *path = NULL;
   gboolean handled = FALSE;
 
@@ -842,16 +839,16 @@ button_press_cb (GtkWidget      *widget,
 
 static void
 glade_inspector_warning_cell_data_func (GtkTreeViewColumn *column,
-					GtkCellRenderer   *renderer,
-					GtkTreeModel      *model,
-					GtkTreeIter       *iter,
-					gpointer           data)
+                                        GtkCellRenderer   *renderer,
+                                        GtkTreeModel      *model,
+                                        GtkTreeIter       *iter,
+                                        gpointer           data)
 {
   gchar *warning = NULL;
 
   gtk_tree_model_get (model, iter,
-		      GLADE_PROJECT_MODEL_COLUMN_WARNING, &warning,
-		      -1);
+                      GLADE_PROJECT_MODEL_COLUMN_WARNING, &warning,
+                      -1);
 
   g_object_set (renderer, "visible", warning != NULL, NULL);
 
@@ -860,24 +857,24 @@ glade_inspector_warning_cell_data_func (GtkTreeViewColumn *column,
 
 static void
 glade_inspector_name_cell_data_func (GtkTreeViewColumn *column,
-				     GtkCellRenderer   *renderer,
-				     GtkTreeModel      *model,
-				     GtkTreeIter       *iter,
-				     gpointer           data)
+                                     GtkCellRenderer   *renderer,
+                                     GtkTreeModel      *model,
+                                     GtkTreeIter       *iter,
+                                     gpointer           data)
 {
   GladeWidget *gwidget;
   GObject *obj;
 
   gtk_tree_model_get (model, iter,
-		      GLADE_PROJECT_MODEL_COLUMN_OBJECT, &obj,
-		      -1);
+                      GLADE_PROJECT_MODEL_COLUMN_OBJECT, &obj,
+                      -1);
 
   gwidget = glade_widget_get_from_gobject (obj);
 
   g_object_set (renderer, "text", 
-		(glade_widget_has_name (gwidget)) ? 
-		  glade_widget_get_display_name (gwidget) : NULL,
-		NULL);
+                (glade_widget_has_name (gwidget)) ? 
+                  glade_widget_get_display_name (gwidget) : NULL,
+                NULL);
 
   g_object_unref (obj);
 }
@@ -885,17 +882,17 @@ glade_inspector_name_cell_data_func (GtkTreeViewColumn *column,
 
 static void
 glade_inspector_detail_cell_data_func (GtkTreeViewColumn *column,
-				       GtkCellRenderer   *renderer,
-				       GtkTreeModel      *model,
-				       GtkTreeIter       *iter,
-				       gpointer           data)
+                                       GtkCellRenderer   *renderer,
+                                       GtkTreeModel      *model,
+                                       GtkTreeIter       *iter,
+                                       gpointer           data)
 {
   gchar *type_name = NULL, *detail = NULL;
 
   gtk_tree_model_get (model, iter,
-		      GLADE_PROJECT_MODEL_COLUMN_TYPE_NAME, &type_name,
-		      GLADE_PROJECT_MODEL_COLUMN_MISC, &detail,
-		      -1);
+                      GLADE_PROJECT_MODEL_COLUMN_TYPE_NAME, &type_name,
+                      GLADE_PROJECT_MODEL_COLUMN_MISC, &detail,
+                      -1);
 
   if (detail)
     {
@@ -939,19 +936,19 @@ add_columns (GtkTreeView *view)
   /* Warning cell */
   renderer = gtk_cell_renderer_pixbuf_new ();
   g_object_set (renderer,
-		"stock-id", "gtk-dialog-warning",
-		"xpad", 2,
-		NULL);
+                "stock-id", "gtk-dialog-warning",
+                "xpad", 2,
+                NULL);
   gtk_cell_area_box_pack_start (box, renderer, FALSE, FALSE, FALSE);
   gtk_tree_view_column_set_cell_data_func (column, renderer,
-					   glade_inspector_warning_cell_data_func,
-					   NULL, NULL);
+                                           glade_inspector_warning_cell_data_func,
+                                           NULL, NULL);
 
   /* Class Icon */
   renderer = gtk_cell_renderer_pixbuf_new ();
   g_object_set (renderer,
-		"xpad", 2,
-		NULL);
+                "xpad", 2,
+                NULL);
   gtk_cell_area_box_pack_start (box, renderer, FALSE, FALSE, FALSE);
   gtk_tree_view_column_set_attributes (column,
                                        renderer,
@@ -967,8 +964,8 @@ add_columns (GtkTreeView *view)
                                        "text", GLADE_PROJECT_MODEL_COLUMN_NAME,
                                        NULL);
   gtk_tree_view_column_set_cell_data_func (column, renderer,
-					   glade_inspector_name_cell_data_func,
-					   NULL, NULL);
+                                           glade_inspector_name_cell_data_func,
+                                           NULL, NULL);
 
   /* Padding */
   renderer = gtk_cell_renderer_text_new ();
@@ -979,14 +976,14 @@ add_columns (GtkTreeView *view)
   renderer = gtk_cell_renderer_text_new ();
   g_object_set (G_OBJECT (renderer),
                 "style", PANGO_STYLE_ITALIC,
-		"foreground", "Gray",
-		"ellipsize", PANGO_ELLIPSIZE_END,
-		NULL);
+                "foreground", "Gray",
+                "ellipsize", PANGO_ELLIPSIZE_END,
+                NULL);
 
   gtk_cell_area_box_pack_start (box, renderer, FALSE, FALSE, FALSE);
   gtk_tree_view_column_set_cell_data_func (column, renderer,
-					   glade_inspector_detail_cell_data_func,
-					   NULL, NULL);
+                                           glade_inspector_detail_cell_data_func,
+                                           NULL, NULL);
 
   gtk_tree_view_append_column (view, column);
   gtk_tree_view_set_headers_visible (view, FALSE);
@@ -1022,14 +1019,14 @@ glade_inspector_set_project (GladeInspector *inspector, GladeProject *project)
   g_return_if_fail (GLADE_IS_INSPECTOR (inspector));
   g_return_if_fail (GLADE_IS_PROJECT (project) || project == NULL);
 
-  GladeInspectorPrivate *priv = inspector->priv;
+  GladeInspectorPrivate *priv = glade_inspector_get_instance_private (inspector);
 
-  if(priv->project == project)
+  if (priv->project == project)
     return;
 
-  if (inspector->priv->project)
+  if (priv->project)
     {
-      disconnect_project_signals (inspector, inspector->priv->project);
+      disconnect_project_signals (inspector, priv->project);
 
       /* Release our filter which releases the project */
       gtk_tree_view_set_model (GTK_TREE_VIEW (priv->view), NULL);
@@ -1064,16 +1061,18 @@ glade_inspector_set_project (GladeInspector *inspector, GladeProject *project)
  * glade_inspector_get_project:
  * @inspector: a #GladeInspector
  * 
- * Note that the method does not ref the returned #GladeProject. 
+ * Note that the method does not ref the returned #GladeProject.
  *
- * Returns: A #GladeProject
+ * Returns: (transfer none): A #GladeProject
  */
 GladeProject *
 glade_inspector_get_project (GladeInspector *inspector)
 {
+  GladeInspectorPrivate *priv = glade_inspector_get_instance_private (inspector);
+
   g_return_val_if_fail (GLADE_IS_INSPECTOR (inspector), NULL);
 
-  return inspector->priv->project;
+  return priv->project;
 }
 
 /**
@@ -1082,14 +1081,14 @@ glade_inspector_get_project (GladeInspector *inspector)
  * 
  * Returns the selected items in the inspector. 
  *
- * Returns: A #GList
+ * Returns: (transfer container) (element-type GladeWidget): A #GList of #GladeWidget
  */
 GList *
 glade_inspector_get_selected_items (GladeInspector *inspector)
 {
   GtkTreeSelection *selection;
   GList *items = NULL, *paths;
-  GladeInspectorPrivate *priv = inspector->priv;
+  GladeInspectorPrivate *priv = glade_inspector_get_instance_private (inspector);
 
   selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (priv->view));
 
@@ -1123,7 +1122,7 @@ glade_inspector_get_selected_items (GladeInspector *inspector)
  * 
  * Creates a new #GladeInspector
  * 
- * Returns: a new #GladeInspector
+ * Returns: (transfer full): a new #GladeInspector
  */
 GtkWidget *
 glade_inspector_new (void)
@@ -1137,7 +1136,7 @@ glade_inspector_new (void)
  *
  * Creates a new #GladeInspector with @project
  * 
- * Returns: a new #GladeInspector
+ * Returns: (transfer full): a new #GladeInspector
  */
 GtkWidget *
 glade_inspector_new_with_project (GladeProject *project)
