@@ -42,7 +42,7 @@ glade_popup_docs_cb (GtkMenuItem *item, GladeWidgetAdaptor *adaptor)
   g_return_if_fail (GLADE_IS_WIDGET_ADAPTOR (adaptor));
 
   glade_app_search_docs (glade_widget_adaptor_get_book (adaptor),
-                         glade_widget_adaptor_get_name (adaptor),
+                         glade_widget_adaptor_get_display_name (adaptor),
                          NULL);
 }
 
@@ -53,7 +53,7 @@ static void
 glade_popup_select_cb (GtkMenuItem *item, GladeWidget *widget)
 {
   glade_project_selection_set (glade_widget_get_project (widget),
-			       glade_widget_get_object (widget), TRUE);
+                               glade_widget_get_object (widget), TRUE);
 }
 
 typedef struct {
@@ -77,7 +77,8 @@ glade_popup_widget_add_cb (GtkMenuItem *item, RootAddData *data)
 static void
 glade_popup_root_add_cb (GtkMenuItem *item, RootAddData *data)
 {
-  glade_command_create (data->adaptor, NULL, NULL, data->project);
+  if (glade_command_create (data->adaptor, NULL, NULL, data->project))
+    glade_project_set_add_item (data->project, NULL);
 }
 
 static void
@@ -203,8 +204,8 @@ glade_popup_menuitem_packing_activated (GtkMenuItem *item,
     {
       parent = glade_widget_get_parent (widget);
       glade_widget_adaptor_child_action_activate (glade_widget_get_adaptor (parent),
-						  glade_widget_get_object (parent),
-						  glade_widget_get_object (widget), action_path);
+                                                  glade_widget_get_object (parent),
+                                                  glade_widget_get_object (widget), action_path);
     }
 }
 
@@ -237,13 +238,13 @@ glade_popup_action_populate_menu_real (GtkWidget   *menu,
 
   for (list = actions; list; list = g_list_next (list))
     {
-      GladeWidgetAction *action = list->data;
-      GWActionClass     *aclass = glade_widget_action_get_class (action);
-      GList             *children = glade_widget_action_get_children (action);
-      GtkWidget         *submenu = NULL;
+      GladeWidgetAction    *action = list->data;
+      GladeWidgetActionDef *adef = glade_widget_action_get_def (action);
+      GList                *children = glade_widget_action_get_children (action);
+      GtkWidget            *submenu = NULL;
 
       if (!glade_widget_action_get_visible (action))
-	continue;
+        continue;
 
       if (children)
         {
@@ -256,12 +257,12 @@ glade_popup_action_populate_menu_real (GtkWidget   *menu,
       else
         submenu = glade_widget_adaptor_action_submenu (glade_widget_get_adaptor (gwidget),
                                                        glade_widget_get_object (gwidget),
-                                                       aclass->path);
+                                                       adef->path);
 
 
-      item = glade_popup_append_item (menu, aclass->label, TRUE,
+      item = glade_popup_append_item (menu, adef->label, TRUE,
                                       (children) ? NULL : callback,
-                                      (children) ? NULL : aclass->path);
+                                      (children) ? NULL : adef->path);
 
       g_object_set_data (G_OBJECT (item), "gwa-data", data);
 
@@ -302,11 +303,11 @@ glade_popup_action_populate_menu (GtkWidget         *menu,
 
   if (action)
     {
-      GWActionClass *aclass = glade_widget_action_get_class (action);
-      GList         *children = glade_widget_action_get_children (action);
+      GladeWidgetActionDef *adef = glade_widget_action_get_def (action);
+      GList                *children = glade_widget_action_get_children (action);
       
-      if (glade_widget_get_action (widget, aclass->path) &&
-	  glade_widget_action_get_visible (action))
+      if (glade_widget_get_action (widget, adef->path) &&
+          glade_widget_action_get_visible (action))
         return glade_popup_action_populate_menu_real (menu,
                                                       widget,
                                                       children,
@@ -314,8 +315,8 @@ glade_popup_action_populate_menu (GtkWidget         *menu,
                                                       (glade_popup_menuitem_activated),
                                                       widget);
 
-      if (glade_widget_get_pack_action (widget, aclass->path) &&
-	  glade_widget_action_get_visible (action))
+      if (glade_widget_get_pack_action (widget, adef->path) &&
+          glade_widget_action_get_visible (action))
         return glade_popup_action_populate_menu_real (menu,
                                                       glade_widget_get_parent
                                                       (widget), children,
@@ -343,9 +344,9 @@ glade_popup_action_populate_menu (GtkWidget         *menu,
         }
 
       n += glade_popup_action_populate_menu_real 
-	(menu, glade_widget_get_parent (widget),
-	 glade_widget_get_pack_actions (widget),
-	 G_CALLBACK (glade_popup_menuitem_packing_activated), widget);
+        (menu, glade_widget_get_parent (widget),
+         glade_widget_get_pack_actions (widget),
+         G_CALLBACK (glade_popup_menuitem_packing_activated), widget);
     }
 
   return n;
@@ -354,8 +355,8 @@ glade_popup_action_populate_menu (GtkWidget         *menu,
 static GtkWidget *
 glade_popup_create_menu (GladeWidget      *widget,
                          GladePlaceholder *placeholder, 
-			 GladeProject     *project,
-			 gboolean          packing)
+                         GladeProject     *project,
+                         gboolean          packing)
 {
   GtkWidget          *popup_menu;
   GtkWidget          *separator;
@@ -376,12 +377,12 @@ glade_popup_create_menu (GladeWidget      *widget,
       data->placeholder = placeholder;
       
       g_object_set_data_full (G_OBJECT (popup_menu), "root-data-destroy-me", 
-			      data, (GDestroyNotify)g_free);
+                              data, (GDestroyNotify)g_free);
 
       glade_popup_append_item (popup_menu, _("_Add widget here"),
                                data->parent != NULL,
-			       glade_popup_widget_add_cb,
-			       data);
+                               glade_popup_widget_add_cb,
+                               data);
 
       glade_popup_append_item (popup_menu, _("Add widget as _toplevel"), TRUE,
                                glade_popup_root_add_cb, data);
@@ -449,7 +450,7 @@ glade_popup_create_menu (GladeWidget      *widget,
         }
     }
   else if (widget && (glade_widget_get_actions (widget) || 
-		      (packing && glade_widget_get_pack_actions (widget))))
+                      (packing && glade_widget_get_pack_actions (widget))))
     {
       GtkWidget *separator = gtk_separator_menu_item_new ();
       gtk_menu_shell_append (GTK_MENU_SHELL (popup_menu), separator);
@@ -502,7 +503,7 @@ glade_popup_placeholder_pop (GladePlaceholder *placeholder,
   widget = glade_placeholder_get_parent (placeholder);
 
   popup_menu = glade_popup_create_menu (widget, placeholder, 
-					glade_widget_get_project (widget), TRUE);
+                                        glade_widget_get_project (widget), TRUE);
 
   if (event)
     {
@@ -521,8 +522,8 @@ glade_popup_placeholder_pop (GladePlaceholder *placeholder,
 
 void
 glade_popup_palette_pop (GladePalette       *palette, 
-			 GladeWidgetAdaptor *adaptor, 
-			 GdkEventButton     *event)
+                         GladeWidgetAdaptor *adaptor, 
+                         GdkEventButton     *event)
 {
   GladeProject *project;
   GtkWidget *popup_menu;
@@ -540,7 +541,7 @@ glade_popup_palette_pop (GladePalette       *palette,
   data->adaptor = adaptor;
   data->project = project;
   g_object_set_data_full (G_OBJECT (popup_menu), "root-data-destroy-me", 
-			  data, (GDestroyNotify)g_free);
+                          data, (GDestroyNotify)g_free);
 
   glade_popup_append_item (popup_menu, _("Add widget as _toplevel"), TRUE,
                            glade_popup_root_add_cb, data);
@@ -578,15 +579,15 @@ static void
 glade_popup_property_docs_cb (GtkMenuItem *item, GladeProperty *property)
 {
   GladeWidgetAdaptor *adaptor, *prop_adaptor;
-  GladePropertyClass *pclass;
+  GladePropertyDef   *pdef;
   GParamSpec         *pspec;
   gchar              *search;
 
-  pclass       = glade_property_get_class (property);
-  pspec        = glade_property_class_get_pspec (pclass);
-  prop_adaptor = glade_property_class_get_adaptor (pclass);
+  pdef         = glade_property_get_def (property);
+  pspec        = glade_property_def_get_pspec (pdef);
+  prop_adaptor = glade_property_def_get_adaptor (pdef);
   adaptor      = glade_widget_adaptor_from_pspec (prop_adaptor, pspec);
-  search       = g_strdup_printf ("The \"%s\" property", glade_property_class_id (pclass));
+  search       = g_strdup_printf ("The \"%s\" property", glade_property_def_id (pdef));
 
   glade_app_search_docs (glade_widget_adaptor_get_book (adaptor),
                          g_type_name (pspec->owner_type), search);
@@ -599,15 +600,15 @@ glade_popup_property_pop (GladeProperty *property, GdkEventButton *event)
 {
 
   GladeWidgetAdaptor *adaptor, *prop_adaptor;
-  GladePropertyClass *pclass;
+  GladePropertyDef   *pdef;
   GParamSpec         *pspec;
   GtkWidget *popup_menu;
   gint button;
   gint event_time;
 
-  pclass       = glade_property_get_class (property);
-  pspec        = glade_property_class_get_pspec (pclass);
-  prop_adaptor = glade_property_class_get_adaptor (pclass);
+  pdef         = glade_property_get_def (property);
+  pspec        = glade_property_def_get_pspec (pdef);
+  prop_adaptor = glade_property_def_get_adaptor (pdef);
   adaptor      = glade_widget_adaptor_from_pspec (prop_adaptor, pspec);
 
   g_return_if_fail (GLADE_IS_WIDGET_ADAPTOR (adaptor));
@@ -617,7 +618,7 @@ glade_popup_property_pop (GladeProperty *property, GdkEventButton *event)
   glade_popup_append_item (popup_menu, _("Set default value"), TRUE,
                            glade_popup_clear_property_cb, property);
 
-  if (!glade_property_class_get_virtual (pclass) &&
+  if (!glade_property_def_get_virtual (pdef) &&
       glade_widget_adaptor_get_book (adaptor) &&
       glade_util_have_devhelp ())
     {
