@@ -32,7 +32,7 @@
 
 struct _GladeSignalPrivate
 {
-  const GladeSignalClass *class;   /* Pointer to the signal class */
+  const GladeSignalDef *def;   /* Pointer to the signal definition */
   gchar    *detail;       /* Signal detail */
   gchar    *handler;      /* Handler function eg "gtk_main_quit" */
   gchar    *userdata;     /* User data signal handler argument   */
@@ -55,17 +55,8 @@ enum {
   N_PROPERTIES
 };
 
-/* We need these defines because GladeSignalClass is another object type!
- * So we use GladeSignalKlass as the class name for GladeSignal
- */
-#define GladeSignalClass GladeSignalKlass
-#define glade_signal_class_init glade_signal_klass_init
-
 G_DEFINE_TYPE_WITH_PRIVATE (GladeSignal, glade_signal, G_TYPE_OBJECT)
 
-#undef GladeSignalClass
-#undef glade_signal_class_init
-
 static GParamSpec *properties[N_PROPERTIES];
 
 static void
@@ -82,16 +73,17 @@ glade_signal_finalize (GObject *object)
 }
 
 static void
-glade_signal_get_property (GObject *object,
-			   guint prop_id,
-			   GValue *value, GParamSpec *pspec)
+glade_signal_get_property (GObject    *object,
+                           guint       prop_id,
+                           GValue     *value,
+                           GParamSpec *pspec)
 {
   GladeSignal *signal = GLADE_SIGNAL (object);
 
   switch (prop_id)
     {
       case PROP_CLASS:
-        g_value_set_pointer (value, (gpointer) signal->priv->class);
+        g_value_set_pointer (value, (gpointer) signal->priv->def);
         break;
       case PROP_DETAIL:
         g_value_set_string (value, signal->priv->detail);
@@ -118,34 +110,35 @@ glade_signal_get_property (GObject *object,
 }
 
 static void
-glade_signal_set_property (GObject *object,
-			   guint prop_id,
-			   const GValue *value, GParamSpec *pspec)
+glade_signal_set_property (GObject      *object,
+                           guint         prop_id,
+                           const GValue *value,
+                           GParamSpec   *pspec)
 {
   GladeSignal *signal = GLADE_SIGNAL (object);
 
   switch (prop_id)
     {
       case PROP_CLASS:
-	signal->priv->class = g_value_get_pointer (value);
+        signal->priv->def = g_value_get_pointer (value);
         break;
       case PROP_DETAIL:
-	glade_signal_set_detail (signal, g_value_get_string (value));
+        glade_signal_set_detail (signal, g_value_get_string (value));
         break;
       case PROP_HANDLER:
-	glade_signal_set_handler (signal, g_value_get_string (value));
+        glade_signal_set_handler (signal, g_value_get_string (value));
         break;
       case PROP_USERDATA:
-	glade_signal_set_userdata (signal, g_value_get_string (value));
+        glade_signal_set_userdata (signal, g_value_get_string (value));
         break; 
       case PROP_SUPPORT_WARNING:
-	glade_signal_set_support_warning (signal, g_value_get_string (value));
+        glade_signal_set_support_warning (signal, g_value_get_string (value));
         break; 
       case PROP_AFTER:
-	glade_signal_set_after (signal, g_value_get_boolean (value));
+        glade_signal_set_after (signal, g_value_get_boolean (value));
         break; 
       case PROP_SWAPPED:
-	glade_signal_set_swapped (signal, g_value_get_boolean (value));
+        glade_signal_set_swapped (signal, g_value_get_boolean (value));
         break; 
       default:
         G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
@@ -160,12 +153,9 @@ glade_signal_init (GladeSignal *signal)
 }
 
 static void
-glade_signal_klass_init (GladeSignalKlass *klass)
+glade_signal_class_init (GladeSignalClass *klass)
 {
-  GObjectClass *object_class;
-
-  object_class = G_OBJECT_CLASS (klass);
-  glade_signal_parent_class = g_type_class_peek_parent (klass);
+  GObjectClass *object_class = G_OBJECT_CLASS (klass);
 
   object_class->set_property = glade_signal_set_property;
   object_class->get_property = glade_signal_get_property;
@@ -220,7 +210,7 @@ glade_signal_klass_init (GladeSignalKlass *klass)
 
 /**
  * glade_signal_new:
- * @name: a name for the signal
+ * @sig_def: a #GladeSignalDef
  * @handler: a handler function for the signal
  * @userdata: the userdata for this signal
  * @after: whether this handler should be called after the default emission phase
@@ -231,16 +221,16 @@ glade_signal_klass_init (GladeSignalKlass *klass)
  * Returns: the new #GladeSignal
  */
 GladeSignal *
-glade_signal_new (const GladeSignalClass *sig_class,
-                  const gchar            *handler,
-                  const gchar            *userdata, 
-		  gboolean                after, 
-		  gboolean                swapped)
+glade_signal_new (const GladeSignalDef *sig_def,
+                  const gchar          *handler,
+                  const gchar          *userdata, 
+                  gboolean              after, 
+                  gboolean              swapped)
 {
-  g_return_val_if_fail (sig_class != NULL, NULL);
+  g_return_val_if_fail (sig_def != NULL, NULL);
 
   return GLADE_SIGNAL (g_object_new (GLADE_TYPE_SIGNAL,
-                                     "class", sig_class,
+                                     "class", sig_def,
                                      "handler", handler,
                                      "userdata", userdata,
                                      "after", after,
@@ -282,7 +272,7 @@ glade_signal_equal (const GladeSignal *sig1, const GladeSignal *sig2)
  * glade_signal_clone:
  * @signal: a #GladeSignal
  *
- * Returns: a new #GladeSignal with the same attributes as @signal
+ * Returns: (transfer full): a new #GladeSignal with the same attributes as @signal
  */
 GladeSignal *
 glade_signal_clone (const GladeSignal *signal)
@@ -291,11 +281,11 @@ glade_signal_clone (const GladeSignal *signal)
 
   g_return_val_if_fail (GLADE_IS_SIGNAL (signal), NULL);
 
-  dup = glade_signal_new (signal->priv->class,
+  dup = glade_signal_new (signal->priv->def,
                           signal->priv->handler,
                           signal->priv->userdata, 
-			  signal->priv->after, 
-			  signal->priv->swapped);
+                          signal->priv->after, 
+                          signal->priv->swapped);
 
   glade_signal_set_detail (dup, signal->priv->detail);
   glade_signal_set_support_warning (dup, signal->priv->support_warning);
@@ -363,17 +353,17 @@ glade_signal_write (GladeSignal     *signal,
 /**
  * glade_signal_read:
  * @node: The #GladeXmlNode to read
- * @adaptor: The #GladeWidgetAdaptor for thw widget
+ * @adaptor: The #GladeWidgetAdaptor for the widget
  *
  * Reads and creates a ner #GladeSignal based on @node
  *
- * Returns: A newly created #GladeSignal
+ * Returns: (transfer full): A newly created #GladeSignal
  */
 GladeSignal *
 glade_signal_read (GladeXmlNode *node, GladeWidgetAdaptor *adaptor)
 {
   GladeSignal *signal = NULL;
-  GladeSignalClass *signal_class;
+  GladeSignalDef *signal_def;
   gchar *name, *handler, *userdata, *detail;
 
   g_return_val_if_fail (glade_xml_node_verify_silent
@@ -396,12 +386,12 @@ glade_signal_read (GladeXmlNode *node, GladeWidgetAdaptor *adaptor)
       return NULL;
     }
 
-  userdata     = glade_xml_get_property_string (node, GLADE_XML_TAG_OBJECT);
-  signal_class = glade_widget_adaptor_get_signal_class (adaptor, name);
+  userdata   = glade_xml_get_property_string (node, GLADE_XML_TAG_OBJECT);
+  signal_def = glade_widget_adaptor_get_signal_def (adaptor, name);
 
-  if (signal_class)
+  if (signal_def)
     {
-      signal = glade_signal_new (signal_class,
+      signal = glade_signal_new (signal_def,
                                  handler, userdata,
                                  glade_xml_get_property_boolean (node, GLADE_XML_TAG_AFTER, FALSE),
                                  glade_xml_get_property_boolean (node, GLADE_XML_TAG_SWAPPED,
@@ -413,9 +403,9 @@ glade_signal_read (GladeXmlNode *node, GladeWidgetAdaptor *adaptor)
     {
       /* XXX These errors should be collected and reported to the user */
       g_warning ("No signal %s was found for class %s, skipping\n", 
-		 name, glade_widget_adaptor_get_name (adaptor));
+                 name, glade_widget_adaptor_get_name (adaptor));
     }
-	
+
   g_free (name);
   g_free (handler);
   g_free (userdata);
@@ -423,26 +413,51 @@ glade_signal_read (GladeXmlNode *node, GladeWidgetAdaptor *adaptor)
   return signal;
 }
 
-G_CONST_RETURN gchar *
+/**
+ * glade_signal_get_name:
+ * @signal: a #GladeSignal
+ *
+ * Get the name of the signal from the signal definition.
+ *
+ * Returns: The name of the signal
+ */
+const gchar *
 glade_signal_get_name (const GladeSignal *signal)
 {
   g_return_val_if_fail (GLADE_IS_SIGNAL (signal), NULL);
 
-  return glade_signal_class_get_name (signal->priv->class);
+  return glade_signal_def_get_name (signal->priv->def);
 }
 
-G_CONST_RETURN GladeSignalClass *
-glade_signal_get_class (const GladeSignal *signal)
+/**
+ * glade_signal_get_def:
+ * @signal: a #GladeSignal
+ *
+ * Get the signal definition.
+ *
+ * Returns: (transfer none): the #GladeSignalDef
+ */
+const GladeSignalDef *
+glade_signal_get_def (const GladeSignal *signal)
 {
-	return signal->priv->class;
+  g_return_val_if_fail (GLADE_IS_SIGNAL (signal), NULL);
+
+  return signal->priv->def;
 }
 
+/**
+ * glade_signal_set_detail:
+ * @signal: a #GladeSignal
+ * @detail: the detail of the signal
+ *
+ * Set the detail of the signal.
+ */
 void
 glade_signal_set_detail (GladeSignal *signal, const gchar *detail)
 {
   g_return_if_fail (GLADE_IS_SIGNAL (signal));
   
-  if (glade_signal_class_get_flags (signal->priv->class) & G_SIGNAL_DETAILED &&
+  if (glade_signal_def_get_flags (signal->priv->def) & G_SIGNAL_DETAILED &&
       g_strcmp0 (signal->priv->detail, detail))
     {
       g_free (signal->priv->detail);
@@ -451,7 +466,15 @@ glade_signal_set_detail (GladeSignal *signal, const gchar *detail)
     }
 }
 
-G_CONST_RETURN gchar *
+/**
+ * glade_signal_get_detail:
+ * @signal: a #GladeSignal
+ *
+ * Get the signal detail.
+ *
+ * Returns: the detail of the signal
+ */
+const gchar *
 glade_signal_get_detail (const GladeSignal *signal)
 {
   g_return_val_if_fail (GLADE_IS_SIGNAL (signal), NULL);
@@ -459,6 +482,13 @@ glade_signal_get_detail (const GladeSignal *signal)
   return signal->priv->detail;
 }
 
+/**
+ * glade_signal_set_handler:
+ * @signal: a #GladeSignal
+ * @handler: the handler of the signal
+ *
+ * Set the handler of the signal.
+ */
 void
 glade_signal_set_handler (GladeSignal *signal, const gchar *handler)
 {
@@ -474,7 +504,15 @@ glade_signal_set_handler (GladeSignal *signal, const gchar *handler)
     }
 }
 
-G_CONST_RETURN gchar *
+/**
+ * glade_signal_get_handler:
+ * @signal: a #GladeSignal
+ *
+ * Get the signal handler.
+ *
+ * Returns: the handler of the signal
+ */
+const gchar *
 glade_signal_get_handler (const GladeSignal *signal)
 {
   g_return_val_if_fail (GLADE_IS_SIGNAL (signal), NULL);
@@ -482,6 +520,13 @@ glade_signal_get_handler (const GladeSignal *signal)
   return signal->priv->handler;
 }
 
+/**
+ * glade_signal_set_userdata:
+ * @signal: a #GladeSignal
+ * @userdata: the userdata of the signal
+ *
+ * Set the userdata of the signal.
+ */
 void
 glade_signal_set_userdata (GladeSignal *signal, const gchar *userdata)
 {
@@ -497,7 +542,15 @@ glade_signal_set_userdata (GladeSignal *signal, const gchar *userdata)
     }
 }
 
-G_CONST_RETURN gchar *
+/**
+ * glade_signal_get_userdata:
+ * @signal: a #GladeSignal
+ *
+ * Get the userdata handler.
+ *
+ * Returns: the userdata of the signal
+ */
+const gchar *
 glade_signal_get_userdata (const GladeSignal *signal)
 {
   g_return_val_if_fail (GLADE_IS_SIGNAL (signal), NULL);
@@ -505,6 +558,14 @@ glade_signal_get_userdata (const GladeSignal *signal)
   return signal->priv->userdata;
 }
 
+/**
+ * glade_signal_set_after:
+ * @signal: a #GladeSignal
+ * @after: if the signal handler should be called after the default handler
+ *
+ * Set whether the handler should be called before or after the default handler
+ * of the signal.
+ */
 void
 glade_signal_set_after (GladeSignal *signal, gboolean after)
 {
@@ -518,6 +579,15 @@ glade_signal_set_after (GladeSignal *signal, gboolean after)
     }
 }
 
+/**
+ * glade_signal_get_after:
+ * @signal: a #GladeSignal
+ *
+ * Get whether the handler should be called before or after the default handler
+ * of the signal.
+ *
+ * Returns: Whether the signal handler should be called after the default handler
+ */
 gboolean
 glade_signal_get_after (const GladeSignal *signal)
 {
@@ -526,6 +596,13 @@ glade_signal_get_after (const GladeSignal *signal)
   return signal->priv->after;
 }
 
+/**
+ * glade_signal_set_swapped:
+ * @signal: a #GladeSignal
+ * @swapped: if the instance and userdata arguments should be swapped
+ *
+ * Set whether the instance and userdata arguments should be swapped.
+ */
 void
 glade_signal_set_swapped (GladeSignal *signal, gboolean swapped)
 {
@@ -539,6 +616,14 @@ glade_signal_set_swapped (GladeSignal *signal, gboolean swapped)
     }
 }
 
+/**
+ * glade_signal_get_swapped:
+ * @signal: a #GladeSignal
+ *
+ * Get whether the instance and userdata arguments should be swapped.
+ *
+ * Returns: whether the instance and userdata arguments should be swapped
+ */
 gboolean
 glade_signal_get_swapped (const GladeSignal *signal)
 {
@@ -563,7 +648,7 @@ glade_signal_set_support_warning (GladeSignal *signal,
     }
 }
 
-G_CONST_RETURN gchar *
+const gchar *
 glade_signal_get_support_warning (const GladeSignal *signal)
 {
   g_return_val_if_fail (GLADE_IS_SIGNAL (signal), NULL);
