@@ -37,7 +37,7 @@
 #include "glade-widget.h"
 #include "glade-widget-adaptor.h"
 #include "glade-property.h"
-#include "glade-property-class.h"
+#include "glade-property-def.h"
 #include "glade-clipboard.h"
 #include "glade-private.h"
 
@@ -59,11 +59,11 @@
 
 /**
  * glade_util_compose_get_type_func:
- * @name:
+ * @name: the name of the #GType - like 'GtkWidget' or a "get-type" function.
  *
  * TODO: write me
  *
- * Returns:
+ * Returns: the type function getter
  */
 static gchar *
 glade_util_compose_get_type_func (const gchar *name)
@@ -137,7 +137,7 @@ glade_util_get_type_from_name (const gchar *name, gboolean have_func)
         }
 
       if (!have_func)
-	g_free (func_name);
+        g_free (func_name);
     }
 
   if (type == 0)
@@ -150,7 +150,7 @@ glade_util_get_type_from_name (const gchar *name, gboolean have_func)
  * glade_utils_get_pspec_from_funcname:
  * @funcname: the symbol name of a function to generate a #GParamSpec
  *
- * Returns: A #GParamSpec created by the delagate function
+ * Returns: (nullable) (transfer full): A #GParamSpec created by the delegate function
  *          specified by @funcname
  */
 GParamSpec *
@@ -200,7 +200,7 @@ _glade_util_dialog_set_hig (GtkDialog *dialog)
  *
  * Creates a new warning dialog window as a child of @parent containing
  * the text of @format, runs it, then destroys it on close. Depending
- * on @type, a cancel button may apear or the icon may change.
+ * on @type, a cancel button may appear or the icon may change.
  *
  * Returns: True if the @type was GLADE_UI_ARE_YOU_SURE and the user
  *          selected "OK", True if the @type was GLADE_UI_YES_OR_NO and
@@ -308,10 +308,10 @@ glade_util_check_and_warn_scrollable (GladeWidget *parent,
       glade_util_ui_message (parent_widget,
                              GLADE_UI_INFO, NULL,
                              _("Cannot add non scrollable %s widget to a %s directly.\n"
-			       "Add a %s first."), 
-			     glade_widget_adaptor_get_title (child_adaptor),
+                               "Add a %s first."), 
+                             glade_widget_adaptor_get_title (child_adaptor),
                              glade_widget_adaptor_get_title (parent_adaptor), 
-			     glade_widget_adaptor_get_title (vadaptor));
+                             glade_widget_adaptor_get_title (vadaptor));
       return TRUE;
     }
   return FALSE;
@@ -461,8 +461,8 @@ G_GNUC_END_IGNORE_DEPRECATIONS
  * @parent: a parent #GtkWindow for the dialog
  * @action: a #GladeUtilFileDialogType to say if the dialog will open or save
  *
- * Returns: a "glade file" file chooser dialog. The caller is responsible 
- *          for showing the dialog
+ * Returns: (transfer full): a "glade file" file chooser dialog. The caller is
+ *          responsible for showing the dialog
  */
 GtkWidget *
 glade_util_file_dialog_new (const gchar *title,
@@ -522,7 +522,7 @@ glade_util_file_dialog_new (const gchar *title,
  * @a: a #gchar
  * @b: a #gchar
  *
- * Replaces each occurance of the character @a in @str to @b.
+ * Replaces each occurrence of the character @a in @str to @b.
  */
 void
 glade_util_replace (gchar *str, gchar a, gchar b)
@@ -541,11 +541,11 @@ glade_util_replace (gchar *str, gchar a, gchar b)
 /**
  * _glade_util_strreplace:
  * @str: a string
- * @free_str: wheter to free str or not
+ * @free_str: whether to free str or not
  * @key: the key string to search for
  * @replacement: string to replace key
  *
- * Replaces each occurance of the string @key in @str to @replacement.
+ * Replaces each occurrence of the string @key in @str to @replacement.
  */
 gchar *
 _glade_util_strreplace (gchar *str,
@@ -564,7 +564,7 @@ _glade_util_strreplace (gchar *str,
 
   if (free_str)
     g_free (str);
-	
+
   return retval;
 }
 
@@ -645,10 +645,7 @@ gtk_container_children_callback (GtkWidget *widget, gpointer client_data)
  * as it used _forall() instead of _foreach() (and the GTK+ version
  * of this function is simply not exposed).
  *
- * Note that glade_widget_class_get_children() is the high-level
- * abstraction and will usually end up calling this function.
- *
- * Returns: a #GList giving the contents of @container
+ * Returns: (element-type GtkWidget) (transfer container): a #GList giving the contents of @container
  */
 GList *
 glade_util_container_get_all_children (GtkContainer *container)
@@ -679,7 +676,7 @@ glade_util_count_placeholders (GladeWidget *parent)
   /* count placeholders */
   if ((children = 
        glade_widget_adaptor_get_children (glade_widget_get_adaptor (parent), 
-					  glade_widget_get_object (parent))) != NULL)
+                                          glade_widget_get_object (parent))) != NULL)
     {
       for (list = children; list && list->data; list = list->next)
         {
@@ -777,10 +774,10 @@ glade_util_find_iter_by_widget (GtkTreeModel *model,
 }
 
 /**
- * glade_util_purify_list:
- * @list: A #GList
+ * glade_util_purify_list: (skip)
+ * @list: (transfer full): A #GList
  *
- * Returns: A newly allocated version of @list with no 
+ * Returns: (transfer full): A newly allocated version of @list with no 
  *          duplicate data entries
  */
 GList *
@@ -798,11 +795,11 @@ glade_util_purify_list (GList * list)
 }
 
 /**
- * glade_util_added_in_list:
+ * glade_util_added_in_list: (skip)
  * @old_list: the old #GList
  * @new_list: the new #GList
  *
- * Returns: A newly allocated #GList of elements that
+ * Returns: (transfer container): A newly allocated #GList of elements that
  *          are in @new but not in @old
  *
  */
@@ -821,11 +818,11 @@ glade_util_added_in_list (GList *old_list, GList *new_list)
 }
 
 /**
- * glade_util_removed_from_list:
+ * glade_util_removed_from_list: (skip)
  * @old_list: the old #GList
  * @new_list: the new #GList
  *
- * Returns: A newly allocated #GList of elements that
+ * Returns: (transfer container): A newly allocated #GList of elements that
  *          are in @old no longer in @new
  *
  */
@@ -851,54 +848,19 @@ glade_util_removed_from_list (GList *old_list, GList *new_list)
  * Returns: an absolute path to the specified file or directory
  *          that contains no ".." or "." components (this does
  *          not call readlink like realpath() does).
- *
- * Note: on some systems; I think its possible that we dont have
- *       permission to execute in the directory in which the glade
- *       file resides; I decided finally to do it this way anyway
- *       since libc's realpath() does exactly the same.
  */
 gchar *
 glade_util_canonical_path (const gchar *path)
 {
-  gchar *orig_dir, *dirname, *basename, *direct_dir, *direct_name = NULL;
+  GFile *file;
+  gchar *direct_name;
 
   g_return_val_if_fail (path != NULL, NULL);
 
-  basename = g_path_get_basename (path);
-
-  if ((orig_dir = g_get_current_dir ()) != NULL)
-    {
-      if ((dirname = g_path_get_dirname (path)) != NULL)
-        {
-          if (g_chdir (dirname) == 0)
-            {
-              if ((direct_dir = g_get_current_dir ()) != NULL)
-		{
-		  direct_name = g_build_filename (direct_dir, basename, NULL);
-		  g_free (direct_dir);
-		}
-              else
-                g_warning ("g_path");
-
-              if (g_chdir (orig_dir) != 0)
-                g_warning ("Unable to chdir back to %s directory (%s)",
-                           orig_dir, g_strerror (errno));
-
-            }
-          else
-            g_warning ("Unable to chdir to %s directory (%s)",
-                       dirname, g_strerror (errno));
-
-          g_free (dirname);
-        }
-      else
-        g_warning ("Unable to get directory component of %s\n", path);
-      g_free (orig_dir);
-    }
-
-  if (basename)
-    g_free (basename);
+  file = g_file_new_for_path (path);
+  direct_name = g_file_get_path (file);
 
+  g_object_unref (file);
   return direct_name;
 }
 
@@ -914,6 +876,31 @@ try_load_library (const gchar *library_path, const gchar *library_name)
         g_warning ("Failed to load %s: %s", path, g_module_error ());
     }
 
+#ifdef PLATFORM_OSX
+  /* Handle .dylib's on OSX */
+  if (!module)
+    {
+      gchar *osx_path;
+
+      /* Remove possible trailing .so */
+      if (g_str_has_suffix (path, ".so"))
+        {
+          gchar *tmp = g_strndup (path, strlen(path) - 3);
+          g_free (path);
+          path = tmp;
+        }
+
+      osx_path = g_strconcat (path, ".dylib", NULL);
+      if (!library_path || g_file_test (osx_path, G_FILE_TEST_EXISTS))
+        {
+          if (!(module = g_module_open (osx_path, G_MODULE_BIND_LAZY)))
+            g_warning ("Failed to load %s: %s", osx_path, g_module_error ());
+        }
+
+      g_free (osx_path);
+    }
+#endif
+
   g_free (path);
 
   return module;
@@ -1026,7 +1013,7 @@ glade_util_have_devhelp (void)
       if (g_spawn_command_line_sync ("devhelp --version",
                                      &ptr, NULL, &ret, &error))
         {
-          /* If we have a successfull return code.. parse the output.
+          /* If we have a successful return code.. parse the output.
            */
           if (ret == 0)
             {
@@ -1053,6 +1040,8 @@ glade_util_have_devhelp (void)
             }
           else
             g_warning ("devhelp had bad return code: '%d'", ret);
+
+          g_free (ptr);
         }
       else
         {
@@ -1072,7 +1061,7 @@ glade_util_have_devhelp (void)
  *
  * Creates an image displaying the devhelp icon.
  *
- * Returns: a #GtkImage
+ * Returns: (transfer full): a #GtkImage
  */
 GtkWidget *
 glade_util_get_devhelp_icon (GtkIconSize size)
@@ -1153,6 +1142,12 @@ glade_util_search_devhelp (const gchar *book,
     g_free (search_comm);
 }
 
+/**
+ * glade_util_get_placeholder_from_pointer:
+ * @container: a #GtkContainer
+ *
+ * Returns: (transfer none): a #GtkWidget
+ */
 GtkWidget *
 glade_util_get_placeholder_from_pointer (GtkContainer *container)
 {
@@ -1300,7 +1295,7 @@ glade_util_icon_name_to_filename (const gchar *value)
 
   sscanf (value, "glade-generated-%s", filename);
 
-  /* XXX: Filenames without an extention will evidently
+  /* XXX: Filenames without an extension will evidently
    * break here
    */
   if ((p = strrchr (filename, '-')) != NULL)
@@ -1437,11 +1432,11 @@ glade_utils_flags_string_from_value_displayable (GType flags_type, gint value)
 }
 
 
-/* A hash table of generically created property classes for
+/* A hash table of generically created property definitions for
  * fundamental types, so we can easily use glade's conversion
  * system without using properties (only GTypes)
  */
-static GHashTable *generic_property_classes = NULL;
+static GHashTable *generic_property_definitions = NULL;
 
 
 static gboolean
@@ -1457,20 +1452,20 @@ utils_gtype_hash (gconstpointer v)
 }
 
 
-static GladePropertyClass *
-pclass_from_gtype (GType type)
+static GladePropertyDef *
+pdef_from_gtype (GType type)
 {
-  GladePropertyClass *property_class = NULL;
+  GladePropertyDef *property_def = NULL;
   GParamSpec *pspec = NULL;
 
-  if (!generic_property_classes)
-    generic_property_classes =
+  if (!generic_property_definitions)
+    generic_property_definitions =
         g_hash_table_new_full (utils_gtype_hash, utils_gtype_equal, g_free,
-                               (GDestroyNotify) glade_property_class_free);
+                               (GDestroyNotify) glade_property_def_free);
 
-  property_class = g_hash_table_lookup (generic_property_classes, &type);
+  property_def = g_hash_table_lookup (generic_property_definitions, &type);
 
-  if (!property_class)
+  if (!property_def)
     {
       /* Support enum and flag types, and a hardcoded list of fundamental types */
       if (type == G_TYPE_CHAR)
@@ -1538,16 +1533,16 @@ pclass_from_gtype (GType type)
 
       if (pspec)
         {
-          if ((property_class =
-               glade_property_class_new_from_spec_full (NULL, pspec,
+          if ((property_def =
+               glade_property_def_new_from_spec_full (NULL, pspec,
                                                         FALSE)) != NULL)
             {
               /* XXX If we ever free the hash table, property classes wont touch
                * the allocated pspecs, so they would theoretically be leaked.
                */
-              g_hash_table_insert (generic_property_classes,
+              g_hash_table_insert (generic_property_definitions,
                                    g_memdup (&type, sizeof (GType)),
-                                   property_class);
+                                   property_def);
             }
           else
             g_warning ("Unable to create property class for type %s",
@@ -1557,7 +1552,7 @@ pclass_from_gtype (GType type)
         g_warning ("No generic conversion support for type %s",
                    g_type_name (type));
     }
-  return property_class;
+  return property_def;
 }
 
 /**
@@ -1565,8 +1560,6 @@ pclass_from_gtype (GType type)
  * @type: a #GType to convert with
  * @string: the string to convert
  * @project: the #GladeProject to look for formats of object names when needed
- * @widget: if the value is a gobject, this #GladeWidget will be used to look
- *          for an object in the same widget tree.
  *
  * Allocates and sets a #GValue of type @type
  * set to @string (using glade conversion routines) 
@@ -1578,13 +1571,13 @@ glade_utils_value_from_string (GType type,
                                const gchar *string,
                                GladeProject *project)
 {
-  GladePropertyClass *pclass;
+  GladePropertyDef *pdef;
 
   g_return_val_if_fail (type != G_TYPE_INVALID, NULL);
   g_return_val_if_fail (string != NULL, NULL);
 
-  if ((pclass = pclass_from_gtype (type)) != NULL)
-    return glade_property_class_make_gvalue_from_string (pclass, string, project);
+  if ((pdef = pdef_from_gtype (type)) != NULL)
+    return glade_property_def_make_gvalue_from_string (pdef, string, project);
 
   return NULL;
 }
@@ -1592,49 +1585,71 @@ glade_utils_value_from_string (GType type,
 /**
  * glade_utils_boolean_from_string:
  * @string: the string to convert
- * @value: return location
+ * @value: (out) (optional): return location
  *
  * Parse a boolean value
  *
- * Returns: True if there was an error on the conversion.
+ * Returns: %TRUE if there was an error on the conversion, %FALSE otherwise.
  */
 gboolean
 glade_utils_boolean_from_string (const gchar *string, gboolean *value)
 {
-  if (string)
+  if (string[0] == '\0')
     {
-      const gchar *c = string;
+      if (value)
+        *value = FALSE;
 
-      /* Skip white spaces */
-      while (g_ascii_isspace (*c))
-        c++;
-
-      /* We only need the first char */
-      switch (*c)
+      return TRUE;
+    }
+  else if (string[1] == '\0')
+    {
+      gchar c = string[0];
+      if (c == '1' ||
+          c == 'y' || c == 't' ||
+          c == 'Y' || c == 'T')
         {
-          case '1':
-          case 't':
-          case 'T':
-          case 'y':
-          case 'Y':
-            if (value)
-              *value = TRUE;
-            return FALSE;
-          break;
+          if (value)
+            *value = TRUE;
+        }
+      else if (c == '0' ||
+               c == 'n' || c == 'f' ||
+               c == 'N' || c == 'F')
+        {
+          if (value)
+            *value = FALSE;
+        }
+      else
+        {
+          if (value)
+            *value = FALSE;
 
-          case '0':
-          case 'f':
-          case 'F':
-          case 'n':
-          case 'N':
-            if (value)
-              *value = FALSE;
-            return FALSE;
-          break;
+          return TRUE;
+        }
+    }
+  else
+    {
+      if (g_ascii_strcasecmp (string, "true") == 0 ||
+          g_ascii_strcasecmp (string, "yes") == 0)
+        {
+          if (value)
+            *value = TRUE;
+        }
+      else if (g_ascii_strcasecmp (string, "false") == 0 ||
+               g_ascii_strcasecmp (string, "no") == 0)
+        {
+          if (value)
+            *value = FALSE;
+        }
+      else
+        {
+          if (value)
+            *value = FALSE;
+
+          return TRUE;
         }
     }
 
-  return TRUE;
+  return FALSE;
 }
 
 /**
@@ -1649,12 +1664,12 @@ glade_utils_boolean_from_string (const gchar *string, gboolean *value)
 gchar *
 glade_utils_string_from_value (const GValue *value)
 {
-  GladePropertyClass *pclass;
+  GladePropertyDef *pdef;
 
   g_return_val_if_fail (value != NULL, NULL);
 
-  if ((pclass = pclass_from_gtype (G_VALUE_TYPE (value))) != NULL)
-    return glade_property_class_make_string_from_gvalue (pclass, value);
+  if ((pdef = pdef_from_gtype (G_VALUE_TYPE (value))) != NULL)
+    return glade_property_def_make_string_from_gvalue (pdef, value);
 
   return NULL;
 }
@@ -1663,12 +1678,12 @@ glade_utils_string_from_value (const GValue *value)
 /**
  * glade_utils_liststore_from_enum_type:
  * @enum_type: A #GType
- * @include_empty: wheather to prepend an "Unset" slot
+ * @include_empty: whether to prepend an "Unset" slot
  *
  * Creates a liststore suitable for comboboxes and such to 
  * chose from a variety of types.
  *
- * Returns: A new #GtkListStore
+ * Returns: (transfer full): A new #GtkListStore
  */
 GtkListStore *
 glade_utils_liststore_from_enum_type (GType enum_type, gboolean include_empty)
@@ -1710,8 +1725,8 @@ glade_utils_liststore_from_enum_type (GType enum_type, gboolean include_empty)
 /**
  * glade_utils_hijack_key_press:
  * @win: a #GtkWindow
- * event: the GdkEventKey 
- * user_data: unused
+ * @event: the #GdkEventKey
+ * @user_data: unused
  *
  * This function is meant to be attached to key-press-event of a toplevel,
  * it simply allows the window contents to treat key events /before/ 
@@ -1886,6 +1901,8 @@ draw_pointer (cairo_t *cr)
  *
  * Render an icon representing the pointer mode.
  * Best view with sizes bigger than GTK_ICON_SIZE_LARGE_TOOLBAR.
+ *
+ * Returns: (transfer full): the rendered #GdkPixbuf
  */ 
 GdkPixbuf *
 glade_utils_pointer_mode_render_icon (GladePointerMode mode, GtkIconSize size)
@@ -2025,10 +2042,10 @@ glade_utils_pointer_mode_render_icon (GladePointerMode mode, GtkIconSize size)
  */
 void
 glade_utils_get_pointer (GtkWidget *widget,
-			 GdkWindow *window,
-			 GdkDevice *device,
-			 gint      *x,
-			 gint      *y)
+                         GdkWindow *window,
+                         GdkDevice *device,
+                         gint      *x,
+                         gint      *y)
 {
   gint device_x = 0, device_y = 0;
   gint final_x = 0, final_y = 0;
@@ -2059,7 +2076,7 @@ glade_utils_get_pointer (GtkWidget *widget,
       gtk_widget_translate_coordinates (event_widget,
                                         widget,
                                         device_x, device_y,
-					&final_x, &final_y);
+                                        &final_x, &final_y);
     }
   else
     {
@@ -2080,8 +2097,8 @@ glade_utils_get_pointer (GtkWidget *widget,
  */
 static gint
 abort_scroll_events (GtkWidget *widget,
-		     GdkEvent  *event,
-		     gpointer   user_data)
+                     GdkEvent  *event,
+                     gpointer   user_data)
 {
   GtkWidget *parent = gtk_widget_get_parent (widget);
 
@@ -2104,7 +2121,7 @@ glade_util_remove_scroll_events (GtkWidget *widget)
   gtk_widget_set_events (widget, events);
 
   g_signal_connect (G_OBJECT (widget), "scroll-event",
-		    G_CALLBACK (abort_scroll_events), NULL);
+                    G_CALLBACK (abort_scroll_events), NULL);
 }
 
 /**
