@@ -31,24 +31,24 @@
 #include "glade-box-editor.h"
 #include "glade-gtk.h"
 
-static gboolean glade_gtk_box_configure_child (GladeFixed * fixed,
-					       GladeWidget * child,
-					       GdkRectangle * rect,
-					       GtkWidget * box);
+static gboolean glade_gtk_box_configure_child (GladeFixed   *fixed,
+                                               GladeWidget  *child,
+                                               GdkRectangle *rect,
+                                               GtkWidget    *box);
 
-static gboolean glade_gtk_box_configure_begin (GladeFixed * fixed,
-					       GladeWidget * child,
-					       GtkWidget * box);
+static gboolean glade_gtk_box_configure_begin (GladeFixed  *fixed,
+                                               GladeWidget *child,
+                                               GtkWidget   *box);
 
 
-static gboolean glade_gtk_box_configure_end (GladeFixed * fixed,
-					     GladeWidget * child,
-					     GtkWidget * box);
+static gboolean glade_gtk_box_configure_end (GladeFixed  *fixed,
+                                             GladeWidget *child,
+                                             GtkWidget   *box);
 
 
 GladeEditable *
-glade_gtk_box_create_editable (GladeWidgetAdaptor * adaptor,
-			       GladeEditorPageType type)
+glade_gtk_box_create_editable (GladeWidgetAdaptor *adaptor,
+                               GladeEditorPageType type)
 {
   if (type == GLADE_PAGE_GENERAL)
     return (GladeEditable *) glade_box_editor_new ();
@@ -57,7 +57,7 @@ glade_gtk_box_create_editable (GladeWidgetAdaptor * adaptor,
 }
 
 static void
-glade_gtk_box_parse_finished (GladeProject * project, GladeWidget *gbox)
+glade_gtk_box_parse_finished (GladeProject *project, GladeWidget *gbox)
 {
   GObject *box = glade_widget_get_object (gbox);
 
@@ -66,8 +66,9 @@ glade_gtk_box_parse_finished (GladeProject * project, GladeWidget *gbox)
 }
 
 void
-glade_gtk_box_post_create (GladeWidgetAdaptor * adaptor,
-                           GObject * container, GladeCreateReason reason)
+glade_gtk_box_post_create (GladeWidgetAdaptor *adaptor,
+                           GObject            *container,
+                           GladeCreateReason   reason)
 {
   GladeWidget *gwidget = glade_widget_get_from_gobject (container);
   GladeProject *project = glade_widget_get_project (gwidget);
@@ -94,13 +95,11 @@ glade_gtk_box_post_create (GladeWidgetAdaptor * adaptor,
 }
 
 static gint
-sort_box_children (GtkWidget * widget_a, GtkWidget * widget_b, GtkWidget *box)
+sort_box_children (GtkWidget *widget_a, GtkWidget *widget_b, GtkWidget *box)
 {
   GladeWidget *gwidget_a, *gwidget_b;
   gint position_a, position_b;
-
-  gwidget_a = glade_widget_get_from_gobject (widget_a);
-  gwidget_b = glade_widget_get_from_gobject (widget_b);
+  GtkWidget *center;
 
   /* Indirect children might be internal children, sort internal children before any other children */
   if (box != gtk_widget_get_parent (widget_a))
@@ -108,30 +107,36 @@ sort_box_children (GtkWidget * widget_a, GtkWidget * widget_b, GtkWidget *box)
   if (box != gtk_widget_get_parent (widget_b))
     return 1;
 
-  if (gtk_box_get_center_widget (GTK_BOX (box)) == widget_a)
-    return -1;
-  if (gtk_box_get_center_widget (GTK_BOX (box)) == widget_b)
+  center = gtk_box_get_center_widget (GTK_BOX (box));
+  if (center == widget_a)
     return -1;
+  if (center == widget_b)
+    return 1;
 
-  /* XXX Sometimes the packing "position" property doesnt exist here, why ?
-   */
-  if (gwidget_a)
-    glade_widget_pack_property_get (gwidget_a, "position", &position_a);
-  else
-    gtk_container_child_get (GTK_CONTAINER (box),
-                             widget_a, "position", &position_a, NULL);
+  if ((gwidget_a = glade_widget_get_from_gobject (widget_a)) &&
+      (gwidget_b = glade_widget_get_from_gobject (widget_b)))
+    {
+      glade_widget_pack_property_get (gwidget_a, "position", &position_a);
+      glade_widget_pack_property_get (gwidget_b, "position", &position_b);
 
-  if (gwidget_b)
-    glade_widget_pack_property_get (gwidget_b, "position", &position_b);
+      /* If position is the same, try to give an stable order */
+      if (position_a == position_b)
+        return g_strcmp0 (glade_widget_get_name (gwidget_a),
+                          glade_widget_get_name (gwidget_b));
+    }
   else
-    gtk_container_child_get (GTK_CONTAINER (box),
-                             widget_b, "position", &position_b, NULL);
+    {
+      gtk_container_child_get (GTK_CONTAINER (box),
+                               widget_a, "position", &position_a, NULL);
+      gtk_container_child_get (GTK_CONTAINER (box),
+                               widget_b, "position", &position_b, NULL);
+    }
+
   return position_a - position_b;
 }
 
 GList *
-glade_gtk_box_get_children (GladeWidgetAdaptor * adaptor,
-                            GObject * container)
+glade_gtk_box_get_children (GladeWidgetAdaptor *adaptor, GObject *container)
 {
   GList *children;
 
@@ -141,10 +146,11 @@ glade_gtk_box_get_children (GladeWidgetAdaptor * adaptor,
 }
 
 void
-glade_gtk_box_set_child_property (GladeWidgetAdaptor * adaptor,
-                                  GObject * container,
-                                  GObject * child,
-                                  const gchar * property_name, GValue * value)
+glade_gtk_box_set_child_property (GladeWidgetAdaptor *adaptor,
+                                  GObject            *container,
+                                  GObject            *child,
+                                  const gchar        *property_name,
+                                  GValue             *value)
 {
   GladeWidget *gbox, *gchild, *gchild_iter;
   GList *children, *list;
@@ -254,8 +260,10 @@ glade_gtk_box_get_num_children (GObject *box)
 }
 
 void
-glade_gtk_box_get_property (GladeWidgetAdaptor * adaptor,
-                            GObject * object, const gchar * id, GValue * value)
+glade_gtk_box_get_property (GladeWidgetAdaptor *adaptor,
+                            GObject            *object,
+                            const gchar        *id,
+                            GValue             *value)
 {
   if (!strcmp (id, "use-center-child"))
     {
@@ -273,7 +281,7 @@ glade_gtk_box_get_property (GladeWidgetAdaptor * adaptor,
 }
 
 static gint
-glade_gtk_box_get_first_blank (GtkBox * box)
+glade_gtk_box_get_first_blank (GtkBox *box)
 {
   GList *child, *children;
   GladeWidget *gwidget;
@@ -295,9 +303,9 @@ glade_gtk_box_get_first_blank (GtkBox * box)
           GladeProperty *property =
               glade_widget_get_pack_property (gwidget, "position");
 
-	  /* property can be NULL here when project is closing */
-	  if (property)
-	    gwidget_position = g_value_get_int (glade_property_inline_value (property));
+          /* property can be NULL here when project is closing */
+          if (property)
+            gwidget_position = g_value_get_int (glade_property_inline_value (property));
 
           if (gwidget_position > position)
             break;
@@ -310,7 +318,7 @@ glade_gtk_box_get_first_blank (GtkBox * box)
 }
 
 static void
-glade_gtk_box_set_size (GObject * object, const GValue * value)
+glade_gtk_box_set_size (GObject *object, const GValue *value)
 {
   GtkBox *box;
   GList *child, *children;
@@ -370,9 +378,10 @@ glade_gtk_box_set_size (GObject * object, const GValue * value)
 }
 
 void
-glade_gtk_box_set_property (GladeWidgetAdaptor * adaptor,
-                            GObject * object,
-                            const gchar * id, const GValue * value)
+glade_gtk_box_set_property (GladeWidgetAdaptor *adaptor,
+                            GObject            *object,
+                            const gchar        *id,
+                            const GValue       *value)
 {
   if (!strcmp (id, "use-center-child"))
     {
@@ -426,9 +435,10 @@ glade_gtk_box_verify_size (GObject *object, const GValue *value)
 
 
 gboolean
-glade_gtk_box_verify_property (GladeWidgetAdaptor * adaptor,
-                               GObject * object,
-                               const gchar * id, const GValue * value)
+glade_gtk_box_verify_property (GladeWidgetAdaptor *adaptor,
+                               GObject            *object,
+                               const gchar        *id,
+                               const GValue       *value)
 {
   if (!strcmp (id, "size"))
     return glade_gtk_box_verify_size (object, value);
@@ -441,7 +451,7 @@ glade_gtk_box_verify_property (GladeWidgetAdaptor * adaptor,
 
 
 static void
-fix_response_id_on_child (GladeWidget * gbox, GObject * child, gboolean add)
+fix_response_id_on_child (GladeWidget *gbox, GObject *child, gboolean add)
 {
   GladeWidget *gchild;
   const gchar *internal_name;
@@ -453,17 +463,18 @@ fix_response_id_on_child (GladeWidget * gbox, GObject * child, gboolean add)
     {
       if (add && (internal_name = glade_widget_get_internal (gbox)) &&
           !strcmp (internal_name, "action_area"))
-	glade_widget_property_set_sensitive (gchild, "response-id", TRUE,
-					     NULL);
+        glade_widget_property_set_sensitive (gchild, "response-id", TRUE,
+                                             NULL);
       else
-	glade_widget_property_set_sensitive (gchild, "response-id", FALSE,
-					     RESPID_INSENSITIVE_MSG);
+        glade_widget_property_set_sensitive (gchild, "response-id", FALSE,
+                                             RESPID_INSENSITIVE_MSG);
     }
 }
 
 void
-glade_gtk_box_add_child (GladeWidgetAdaptor * adaptor,
-                         GObject * object, GObject * child)
+glade_gtk_box_add_child (GladeWidgetAdaptor *adaptor,
+                         GObject            *object,
+                         GObject            *child)
 {
   GladeWidget *gbox, *gchild;
   gint num_children;
@@ -510,7 +521,7 @@ glade_gtk_box_add_child (GladeWidgetAdaptor * adaptor,
 
   gchild = glade_widget_get_from_gobject (child);
 
-  /* The "Remove Slot" operation only makes sence on placeholders,
+  /* The "Remove Slot" operation only makes sense on placeholders,
    * otherwise its a "Delete" operation on the child widget.
    */
   if (gchild)
@@ -527,8 +538,9 @@ glade_gtk_box_add_child (GladeWidgetAdaptor * adaptor,
 }
 
 void
-glade_gtk_box_remove_child (GladeWidgetAdaptor * adaptor,
-                            GObject * object, GObject * child)
+glade_gtk_box_remove_child (GladeWidgetAdaptor *adaptor,
+                            GObject            *object,
+                            GObject            *child)
 {
   GladeWidget *gbox;
   gint size;
@@ -563,9 +575,10 @@ glade_gtk_box_remove_child (GladeWidgetAdaptor * adaptor,
 
 
 void
-glade_gtk_box_replace_child (GladeWidgetAdaptor * adaptor,
-                             GObject * container,
-                             GObject * current, GObject * new_widget)
+glade_gtk_box_replace_child (GladeWidgetAdaptor *adaptor,
+                             GObject            *container,
+                             GObject            *current,
+                             GObject            *new_widget)
 {
   GladeWidget *gchild;
   GladeWidget *gbox;
@@ -590,7 +603,7 @@ glade_gtk_box_replace_child (GladeWidgetAdaptor * adaptor,
   gbox = glade_widget_get_from_gobject (container);
 
   if ((gchild = glade_widget_get_from_gobject (new_widget)) != NULL)
-    /* The "Remove Slot" operation only makes sence on placeholders,
+    /* The "Remove Slot" operation only makes sense on placeholders,
      * otherwise its a "Delete" operation on the child widget.
      */
     glade_widget_set_pack_action_visible (gchild, "remove_slot", FALSE);
@@ -642,9 +655,10 @@ typedef struct
 static GList *glade_gtk_box_original_positions = NULL;
 
 static gboolean
-glade_gtk_box_configure_child (GladeFixed * fixed,
-                               GladeWidget * child,
-                               GdkRectangle * rect, GtkWidget * box)
+glade_gtk_box_configure_child (GladeFixed   *fixed,
+                               GladeWidget  *child,
+                               GdkRectangle *rect,
+                               GtkWidget    *box)
 {
   GList *list, *children;
   GtkWidget *bchild;
@@ -744,8 +758,9 @@ glade_gtk_box_configure_child (GladeFixed * fixed,
 }
 
 static gboolean
-glade_gtk_box_configure_begin (GladeFixed * fixed,
-                               GladeWidget * child, GtkWidget * box)
+glade_gtk_box_configure_begin (GladeFixed  *fixed,
+                               GladeWidget *child,
+                               GtkWidget   *box)
 {
   GList *list, *children;
   GtkWidget *bchild;
@@ -797,7 +812,7 @@ glade_gtk_box_configure_end (GladeFixed * fixed,
 
           if (bchild == gbchild->widget)
             {
-              GCSetPropData *prop_data = g_new0 (GCSetPropData, 1);
+              GladeCommandSetPropData *prop_data = g_new0 (GladeCommandSetPropData, 1);
               prop_data->property =
                   glade_widget_get_pack_property (gchild, "position");
 
