@@ -38,21 +38,21 @@
  * glade property through the glade-command api.
  */
 static void
-glade_gtk_font_button_refresh_font_name (GtkFontButton * button,
-                                         GladeWidget * gbutton)
+glade_gtk_font_button_refresh_font_name (GtkFontButton *button,
+                                         GladeWidget   *gbutton)
 {
   GladeProperty *property;
 
   if ((property = glade_widget_get_property (gbutton, "font-name")) != NULL)
     glade_command_set_property (property,
-                                gtk_font_button_get_font_name (button));
+                                gtk_font_chooser_get_font (GTK_FONT_CHOOSER (button)));
 }
 
 
 /* ----------------------------- GtkColorButton ------------------------------ */
 static void
-glade_gtk_color_button_refresh_color (GtkColorButton * button,
-                                      GladeWidget * gbutton)
+glade_gtk_color_button_refresh_color (GtkColorButton *button,
+                                      GladeWidget    *gbutton)
 {
   GladeProperty *property;
   GdkRGBA rgba = { 0, };
@@ -62,28 +62,29 @@ glade_gtk_color_button_refresh_color (GtkColorButton * button,
   if ((property = glade_widget_get_property (gbutton, "color")) != NULL)
     {
       if (glade_property_get_enabled (property))
-	{
-	  GdkColor color = { 0, };
+        {
+          GdkColor color = { 0, };
 
-	  color.red   = (gint16) (rgba.red * 65535);
-	  color.green = (gint16) (rgba.green * 65535);
-	  color.blue  = (gint16) (rgba.blue * 65535);
+          color.red   = (gint16) (rgba.red * 65535);
+          color.green = (gint16) (rgba.green * 65535);
+          color.blue  = (gint16) (rgba.blue * 65535);
 
-	  glade_command_set_property (property, &color);
-	}
+          glade_command_set_property (property, &color);
+        }
     }
 
   if ((property = glade_widget_get_property (gbutton, "rgba")) != NULL)
     {
       if (glade_property_get_enabled (property))
-	glade_command_set_property (property, &rgba);
+        glade_command_set_property (property, &rgba);
     }
 }
 
 void
-glade_gtk_color_button_set_property (GladeWidgetAdaptor * adaptor,
-                                     GObject * object,
-                                     const gchar * id, const GValue * value)
+glade_gtk_color_button_set_property (GladeWidgetAdaptor *adaptor,
+                                     GObject            *object,
+                                     const gchar        *id,
+                                     const GValue       *value)
 {
   GladeProperty *property;
   GladeWidget *gwidget = glade_widget_get_from_gobject (object);
@@ -91,25 +92,25 @@ glade_gtk_color_button_set_property (GladeWidgetAdaptor * adaptor,
   if (!strcmp (id, "color"))
     {
       if ((property = glade_widget_get_property (gwidget, "color")) != NULL &&
-	  glade_property_get_enabled (property) && g_value_get_boxed (value))
-	{
-	  GdkColor *color = g_value_get_boxed (value);
-	  GdkRGBA copy;
+          glade_property_get_enabled (property) && g_value_get_boxed (value))
+        {
+          GdkColor *color = g_value_get_boxed (value);
+          GdkRGBA copy;
 
-	  copy.red   = color->red   / 65535.0;
-	  copy.green = color->green / 65535.0;
-	  copy.blue  = color->blue  / 65535.0;
-	  copy.alpha = 1.0;
+          copy.red   = color->red   / 65535.0;
+          copy.green = color->green / 65535.0;
+          copy.blue  = color->blue  / 65535.0;
+          copy.alpha = 1.0;
 
-	  gtk_color_chooser_set_rgba (GTK_COLOR_CHOOSER (object), &copy);
-	}
+          gtk_color_chooser_set_rgba (GTK_COLOR_CHOOSER (object), &copy);
+        }
     }
   else if (!strcmp (id, "rgba"))
     {
       if ((property = glade_widget_get_property (gwidget, "rgba")) != NULL &&
-	  glade_property_get_enabled (property) && g_value_get_boxed (value))
-	gtk_color_chooser_set_rgba (GTK_COLOR_CHOOSER (object),
-				    (GdkRGBA *) g_value_get_boxed (value));
+          glade_property_get_enabled (property) && g_value_get_boxed (value))
+        gtk_color_chooser_set_rgba (GTK_COLOR_CHOOSER (object),
+                                    (GdkRGBA *) g_value_get_boxed (value));
     }
   else
     GWA_GET_CLASS (GTK_TYPE_BUTTON)->set_property (adaptor, object, id, value);
@@ -117,7 +118,7 @@ glade_gtk_color_button_set_property (GladeWidgetAdaptor * adaptor,
 
 /* ----------------------------- GtkButton ------------------------------ */
 GladeEditable *
-glade_gtk_button_create_editable (GladeWidgetAdaptor * adaptor,
+glade_gtk_button_create_editable (GladeWidgetAdaptor *adaptor,
                                   GladeEditorPageType type)
 {
   if (type == GLADE_PAGE_GENERAL)
@@ -125,11 +126,11 @@ glade_gtk_button_create_editable (GladeWidgetAdaptor * adaptor,
       GType type = glade_widget_adaptor_get_object_type (adaptor);
 
       if (g_type_is_a (type, GTK_TYPE_FONT_BUTTON))
-	return (GladeEditable *) glade_font_button_editor_new ();
+        return (GladeEditable *) glade_font_button_editor_new ();
       else if (g_type_is_a (type, GTK_TYPE_SCALE_BUTTON))
-	return (GladeEditable *) glade_scale_button_editor_new ();
+        return (GladeEditable *) glade_scale_button_editor_new ();
       else if (!g_type_is_a (type, GTK_TYPE_LOCK_BUTTON))
-	return (GladeEditable *) glade_button_editor_new ();
+        return (GladeEditable *) glade_button_editor_new ();
     }
 
   return GWA_GET_CLASS (GTK_TYPE_CONTAINER)->create_editable (adaptor, type);
@@ -151,8 +152,9 @@ glade_gtk_button_update_stock (GladeWidget *widget)
 }
 
 void
-glade_gtk_button_post_create (GladeWidgetAdaptor * adaptor,
-                              GObject * button, GladeCreateReason reason)
+glade_gtk_button_post_create (GladeWidgetAdaptor *adaptor,
+                              GObject            *button,
+                              GladeCreateReason   reason)
 {
   GladeWidget *gbutton = glade_widget_get_from_gobject (button);
 
@@ -186,15 +188,16 @@ glade_gtk_button_post_create (GladeWidgetAdaptor * adaptor,
 static inline gboolean
 glade_gtk_lock_button_is_own_property (GladeProperty *property)
 {
-  GladePropertyClass *klass = glade_property_get_class (property);
-  GParamSpec *spec = glade_property_class_get_pspec (klass);
+  GladePropertyDef *def = glade_property_get_def (property);
+  GParamSpec *spec = glade_property_def_get_pspec (def);
   return (spec->owner_type == GTK_TYPE_LOCK_BUTTON);
 }
 
 void
-glade_gtk_button_set_property (GladeWidgetAdaptor * adaptor,
-                               GObject * object,
-                               const gchar * id, const GValue * value)
+glade_gtk_button_set_property (GladeWidgetAdaptor *adaptor,
+                               GObject            *object,
+                               const gchar        *id,
+                               const GValue       *value)
 {
   GladeWidget *widget = glade_widget_get_from_gobject (object);
   GladeProperty *property = glade_widget_get_property (widget, id);
@@ -235,7 +238,7 @@ glade_gtk_button_set_property (GladeWidgetAdaptor * adaptor,
                                                         id, value);
       glade_gtk_sync_use_appearance (widget);
     }
-  else if (GPC_VERSION_CHECK (glade_property_get_class (property), gtk_major_version, gtk_minor_version + 1))
+  else if (GLADE_PROPERTY_DEF_VERSION_CHECK (glade_property_get_def (property), gtk_major_version, gtk_minor_version + 1))
     GWA_GET_CLASS (GTK_TYPE_CONTAINER)->set_property (adaptor, object, id, value);
 
   /* GtkLockButton hides itself after setting a property so we need to make sure
@@ -246,13 +249,14 @@ glade_gtk_button_set_property (GladeWidgetAdaptor * adaptor,
 }
 
 void
-glade_gtk_button_read_widget (GladeWidgetAdaptor * adaptor,
-                              GladeWidget * widget, GladeXmlNode * node)
+glade_gtk_button_read_widget (GladeWidgetAdaptor *adaptor,
+                              GladeWidget        *widget,
+                              GladeXmlNode       *node)
 {
   GObject *object;
 
   if (!(glade_xml_node_verify_silent (node, GLADE_XML_TAG_WIDGET) ||
-	glade_xml_node_verify_silent (node, GLADE_XML_TAG_TEMPLATE)))
+        glade_xml_node_verify_silent (node, GLADE_XML_TAG_TEMPLATE)))
     return;
 
   /* First chain up and read in all the normal properties.. */
@@ -260,7 +264,7 @@ glade_gtk_button_read_widget (GladeWidgetAdaptor * adaptor,
 
   glade_gtk_button_update_stock (widget);
 
-  /* Fold "font-name" property into the "font" propery */
+  /* Fold "font-name" property into the "font" property */
   object = glade_widget_get_object (widget);
   if (GTK_IS_FONT_BUTTON (object))
     {
@@ -269,17 +273,18 @@ glade_gtk_button_read_widget (GladeWidgetAdaptor * adaptor,
       glade_widget_property_get (widget, "font-name", &font_prop_value);
 
       if (font_prop_value != NULL)
-	{
-	  glade_widget_property_set (widget, "font", font_prop_value);
-	  glade_widget_property_set (widget, "font-name", NULL);
-	}
+        {
+          glade_widget_property_set (widget, "font", font_prop_value);
+          glade_widget_property_set (widget, "font-name", NULL);
+        }
     }
 }
 
 void
-glade_gtk_button_write_widget (GladeWidgetAdaptor * adaptor,
-                               GladeWidget * widget,
-                               GladeXmlContext * context, GladeXmlNode * node)
+glade_gtk_button_write_widget (GladeWidgetAdaptor *adaptor,
+                               GladeWidget        *widget,
+                               GladeXmlContext    *context,
+                               GladeXmlNode       *node)
 {
   GladeProperty *prop;
   gboolean use_stock;
@@ -287,7 +292,7 @@ glade_gtk_button_write_widget (GladeWidgetAdaptor * adaptor,
   GObject *object;
 
   if (!(glade_xml_node_verify_silent (node, GLADE_XML_TAG_WIDGET) ||
-	glade_xml_node_verify_silent (node, GLADE_XML_TAG_TEMPLATE)))
+        glade_xml_node_verify_silent (node, GLADE_XML_TAG_TEMPLATE)))
     return;
 
   object = glade_widget_get_object (widget);
@@ -321,19 +326,19 @@ glade_gtk_button_write_widget (GladeWidgetAdaptor * adaptor,
 }
 
 GladeEditorProperty *
-glade_gtk_button_create_eprop (GladeWidgetAdaptor * adaptor,
-				       GladePropertyClass * klass, 
-				       gboolean use_command)
+glade_gtk_button_create_eprop (GladeWidgetAdaptor *adaptor,
+                               GladePropertyDef   *def, 
+                               gboolean            use_command)
 {
   GladeEditorProperty *eprop;
 
-  if (strcmp (glade_property_class_id(klass), "response-id")==0)
+  if (strcmp (glade_property_def_id(def), "response-id")==0)
     {
-      eprop = glade_eprop_enum_int_new (klass, GTK_TYPE_RESPONSE_TYPE, use_command);
+      eprop = glade_eprop_enum_int_new (def, GTK_TYPE_RESPONSE_TYPE, use_command);
     }
   else
     eprop = GWA_GET_CLASS
-        (GTK_TYPE_WIDGET)->create_eprop (adaptor, klass, use_command);
+        (GTK_TYPE_WIDGET)->create_eprop (adaptor, def, use_command);
 
   return eprop;
 }
