@@ -28,8 +28,8 @@
 #include "glade-scrolled-window-editor.h"
 
 GladeEditable *
-glade_gtk_scrolled_window_create_editable (GladeWidgetAdaptor * adaptor,
-					   GladeEditorPageType type)
+glade_gtk_scrolled_window_create_editable (GladeWidgetAdaptor *adaptor,
+                                           GladeEditorPageType type)
 {
   if (type == GLADE_PAGE_GENERAL)
     {
@@ -40,9 +40,10 @@ glade_gtk_scrolled_window_create_editable (GladeWidgetAdaptor * adaptor,
 }
 
 void
-glade_gtk_scrolled_window_set_property (GladeWidgetAdaptor * adaptor,
-					GObject * object,
-					const gchar * id, const GValue * value)
+glade_gtk_scrolled_window_set_property (GladeWidgetAdaptor *adaptor,
+                                        GObject            *object,
+                                        const gchar        *id,
+                                        const GValue       *value)
 {
   GladeWidget *widget = glade_widget_get_from_gobject (object);
   GladeProperty *property = glade_widget_get_property (widget, id);
@@ -50,12 +51,12 @@ glade_gtk_scrolled_window_set_property (GladeWidgetAdaptor * adaptor,
   if (strcmp (id, "window-placement-set") == 0)
     {
       if (g_value_get_boolean (value))
-	glade_widget_property_set_sensitive (widget, "window-placement", TRUE, NULL);
+        glade_widget_property_set_sensitive (widget, "window-placement", TRUE, NULL);
       else
-	glade_widget_property_set_sensitive (widget, "window-placement", FALSE,
-					     _("This property is disabled"));
+        glade_widget_property_set_sensitive (widget, "window-placement", FALSE,
+                                             _("This property is disabled"));
     }
-  else if (GPC_VERSION_CHECK (glade_property_get_class (property), gtk_major_version, gtk_minor_version + 1))
+  else if (GLADE_PROPERTY_DEF_VERSION_CHECK (glade_property_get_def (property), gtk_major_version, gtk_minor_version + 1))
     GWA_GET_CLASS (GTK_TYPE_CONTAINER)->set_property (adaptor, object, id, value);
 }
 
@@ -71,4 +72,4 @@ glade_gtk_scrolled_window_add_child_verify (GladeWidgetAdaptor *adaptor,
   return !glade_util_check_and_warn_scrollable (gcontainer,
                                                 glade_widget_get_adaptor (gchild),
                                                 glade_app_get_window ());
-}
\ No newline at end of file
+}
