@@ -75,8 +75,8 @@ static const gchar *atk_relations_list[] = {
 
 
 void
-glade_gtk_widget_destroy_object (GladeWidgetAdaptor * adaptor,
-				 GObject *object)
+glade_gtk_widget_destroy_object (GladeWidgetAdaptor *adaptor,
+                                 GObject            *object)
 {
   gtk_widget_destroy (GTK_WIDGET (object));
 
@@ -84,10 +84,10 @@ glade_gtk_widget_destroy_object (GladeWidgetAdaptor * adaptor,
 }
 
 static void
-glade_gtk_parse_atk_relation (GladeProperty * property, GladeXmlNode * node)
+glade_gtk_parse_atk_relation (GladeProperty *property, GladeXmlNode *node)
 {
   GladeXmlNode *prop;
-  GladePropertyClass *pclass;
+  GladePropertyDef *pdef;
   gchar *type, *target, *id, *tmp;
   gchar *string = NULL;
 
@@ -110,17 +110,17 @@ glade_gtk_parse_atk_relation (GladeProperty * property, GladeXmlNode * node)
           continue;
         }
 
-      id     = glade_util_read_prop_name (type);
-      pclass = glade_property_get_class (property);
+      id   = glade_util_read_prop_name (type);
+      pdef = glade_property_get_def (property);
 
-      if (!strcmp (id, glade_property_class_id (pclass)))
+      if (!strcmp (id, glade_property_def_id (pdef)))
         {
           if (string == NULL)
             string = g_strdup (target);
           else
             {
               tmp = g_strdup_printf ("%s%s%s", string,
-                                     GPC_OBJECT_DELIMITER, target);
+                                     GLADE_PROPERTY_DEF_OBJECT_DELIMITER, target);
               string = (g_free (string), tmp);
             }
 
@@ -139,18 +139,18 @@ glade_gtk_parse_atk_relation (GladeProperty * property, GladeXmlNode * node)
   if (string)
     {
       g_object_set_data_full (G_OBJECT (property), "glade-loaded-object",
-			      /* 'string' here is already allocated on the heap */
+                              /* 'string' here is already allocated on the heap */
                               string, g_free);
     }
 }
 
 static void
-glade_gtk_parse_atk_props (GladeWidget * widget, GladeXmlNode * node)
+glade_gtk_parse_atk_props (GladeWidget *widget, GladeXmlNode *node)
 {
   GladeXmlNode *prop;
   GladeProperty *property;
   GValue *gvalue;
-  gchar *value, *name, *id, *comment;
+  gchar *value, *name, *id, *context, *comment;
   gint translatable;
   gboolean is_action;
 
@@ -206,8 +206,8 @@ glade_gtk_parse_atk_props (GladeWidget * widget, GladeXmlNode * node)
             }
 
           /* Set the parsed value on the property ... */
-          gvalue = glade_property_class_make_gvalue_from_string
-	    (glade_property_get_class (property), value, glade_widget_get_project (widget));
+          gvalue = glade_property_def_make_gvalue_from_string
+            (glade_property_get_def (property), value, glade_widget_get_project (widget));
           glade_property_set_value (property, gvalue);
           g_value_unset (gvalue);
           g_free (gvalue);
@@ -215,12 +215,15 @@ glade_gtk_parse_atk_props (GladeWidget * widget, GladeXmlNode * node)
           /* Deal with i18n... ... XXX Do i18n context !!! */
           translatable = glade_xml_get_property_boolean
               (prop, GLADE_TAG_TRANSLATABLE, FALSE);
+          context = glade_xml_get_property_string (prop, GLADE_TAG_CONTEXT);
           comment = glade_xml_get_property_string (prop, GLADE_TAG_COMMENT);
 
           glade_property_i18n_set_translatable (property, translatable);
+          glade_property_i18n_set_context (property, context);
           glade_property_i18n_set_comment (property, comment);
 
           g_free (comment);
+          g_free (context);
           g_free (value);
         }
 
@@ -229,7 +232,7 @@ glade_gtk_parse_atk_props (GladeWidget * widget, GladeXmlNode * node)
 }
 
 static void
-glade_gtk_parse_atk_props_gtkbuilder (GladeWidget * widget, GladeXmlNode * node)
+glade_gtk_parse_atk_props_gtkbuilder (GladeWidget *widget, GladeXmlNode *node)
 {
   GladeXmlNode *child, *object_node;
   gchar *internal;
@@ -257,7 +260,7 @@ glade_gtk_parse_atk_props_gtkbuilder (GladeWidget * widget, GladeXmlNode * node)
 }
 
 static void
-glade_gtk_widget_read_atk_props (GladeWidget * widget, GladeXmlNode * node)
+glade_gtk_widget_read_atk_props (GladeWidget *widget, GladeXmlNode *node)
 {
   GladeXmlNode *atk_node;
   GladeProperty *property;
@@ -283,7 +286,7 @@ glade_gtk_widget_read_atk_props (GladeWidget * widget, GladeXmlNode * node)
 }
 
 static void
-glade_gtk_widget_read_style_classes (GladeWidget * widget, GladeXmlNode * node)
+glade_gtk_widget_read_style_classes (GladeWidget *widget, GladeXmlNode *node)
 {
   GladeXmlNode *style_node;
   GladeXmlNode *class_node;
@@ -292,19 +295,19 @@ glade_gtk_widget_read_style_classes (GladeWidget * widget, GladeXmlNode * node)
   if ((style_node = glade_xml_search_child (node, GLADE_TAG_STYLE)) != NULL)
     {
       for (class_node = glade_xml_node_get_children (style_node);
-	   class_node; class_node = glade_xml_node_next (class_node))
-	{
-	  gchar *name;
+           class_node; class_node = glade_xml_node_next (class_node))
+        {
+          gchar *name;
 
-	  if (!glade_xml_node_verify (class_node, GLADE_TAG_CLASS))
-	    continue;
+          if (!glade_xml_node_verify (class_node, GLADE_TAG_CLASS))
+            continue;
 
-	  name = glade_xml_get_property_string (class_node, GLADE_TAG_NAME);
+          name = glade_xml_get_property_string (class_node, GLADE_TAG_NAME);
 
-	  string_list = glade_string_list_append (string_list, name, NULL, NULL, FALSE, NULL);
+          string_list = glade_string_list_append (string_list, name, NULL, NULL, FALSE, NULL);
 
-	  g_free (name);
-	}
+          g_free (name);
+        }
 
       glade_widget_property_set (widget, "glade-style-classes", string_list);
       glade_string_list_free (string_list);
@@ -312,13 +315,14 @@ glade_gtk_widget_read_style_classes (GladeWidget * widget, GladeXmlNode * node)
 }
 
 void
-glade_gtk_widget_read_widget (GladeWidgetAdaptor * adaptor,
-                              GladeWidget * widget, GladeXmlNode * node)
+glade_gtk_widget_read_widget (GladeWidgetAdaptor *adaptor,
+                              GladeWidget        *widget,
+                              GladeXmlNode       *node)
 {
   const gchar *tooltip_markup = NULL;
 
   if (!(glade_xml_node_verify_silent (node, GLADE_XML_TAG_WIDGET) ||
-	glade_xml_node_verify_silent (node, GLADE_XML_TAG_TEMPLATE)))
+        glade_xml_node_verify_silent (node, GLADE_XML_TAG_TEMPLATE)))
     return;
 
   /* First chain up and read in all the normal properties.. */
@@ -340,21 +344,22 @@ glade_gtk_widget_read_widget (GladeWidgetAdaptor * adaptor,
 }
 
 static void
-glade_gtk_widget_write_atk_property (GladeProperty * property,
-                                     GladeXmlContext * context,
-                                     GladeXmlNode * node)
+glade_gtk_widget_write_atk_property (GladeProperty   *property,
+                                     GladeXmlContext *context,
+                                     GladeXmlNode    *node)
 {
   gchar *value = glade_property_make_string (property);
 
   if (value && value[0])
     {
-      GladePropertyClass *pclass = glade_property_get_class (property);
+      GladePropertyDef *pdef = glade_property_get_def (property);
       GladeXmlNode *prop_node = glade_xml_node_new (context, GLADE_TAG_A11Y_PROPERTY);
+      const gchar *comment, *context;
 
       glade_xml_node_append_child (node, prop_node);
 
       glade_xml_node_set_property_string (prop_node,
-                                          GLADE_TAG_NAME, glade_property_class_id (pclass));
+                                          GLADE_TAG_NAME, glade_property_def_id (pdef));
 
       glade_xml_set_content (prop_node, value);
 
@@ -363,24 +368,26 @@ glade_gtk_widget_write_atk_property (GladeProperty * property,
                                             GLADE_TAG_TRANSLATABLE,
                                             GLADE_XML_TAG_I18N_TRUE);
 
-      if (glade_property_i18n_get_comment (property))
+      comment = glade_property_i18n_get_comment (property);
+      if (comment)
         glade_xml_node_set_property_string (prop_node,
                                             GLADE_TAG_COMMENT,
-                                            glade_property_i18n_get_comment (property));
+                                            comment);
 
-      if (glade_property_i18n_get_context (property))
+      context = glade_property_i18n_get_context (property);
+      if (context)
         glade_xml_node_set_property_string (prop_node,
                                             GLADE_TAG_CONTEXT,
-                                            glade_property_i18n_get_context (property));
+                                            context);
     }
 
   g_free (value);
 }
 
 static void
-glade_gtk_widget_write_atk_properties (GladeWidget * widget,
-                                       GladeXmlContext * context,
-                                       GladeXmlNode * node)
+glade_gtk_widget_write_atk_properties (GladeWidget     *widget,
+                                       GladeXmlContext *context,
+                                       GladeXmlNode    *node)
 {
   GladeXmlNode *child_node, *object_node;
   GladeProperty *name_prop, *desc_prop, *role_prop;
@@ -431,31 +438,31 @@ glade_gtk_widget_write_atk_properties (GladeWidget * widget,
 }
 
 static void
-glade_gtk_widget_write_atk_relation (GladeProperty * property,
-                                     GladeXmlContext * context,
-                                     GladeXmlNode * node)
+glade_gtk_widget_write_atk_relation (GladeProperty   *property,
+                                     GladeXmlContext *context,
+                                     GladeXmlNode    *node)
 {
   GladeXmlNode *prop_node;
-  GladePropertyClass *pclass;
+  GladePropertyDef *pdef;
   gchar *value, **split;
   gint i;
 
   if ((value = glade_widget_adaptor_string_from_value
-       (glade_property_class_get_adaptor (glade_property_get_class (property)),
-        glade_property_get_class (property), glade_property_inline_value (property))) != NULL)
+       (glade_property_def_get_adaptor (glade_property_get_def (property)),
+        glade_property_get_def (property), glade_property_inline_value (property))) != NULL)
     {
-      if ((split = g_strsplit (value, GPC_OBJECT_DELIMITER, 0)) != NULL)
+      if ((split = g_strsplit (value, GLADE_PROPERTY_DEF_OBJECT_DELIMITER, 0)) != NULL)
         {
           for (i = 0; split[i] != NULL; i++)
             {
-	      pclass = glade_property_get_class (property);
+              pdef = glade_property_get_def (property);
 
               prop_node = glade_xml_node_new (context, GLADE_TAG_A11Y_RELATION);
               glade_xml_node_append_child (node, prop_node);
 
               glade_xml_node_set_property_string (prop_node,
                                                   GLADE_TAG_A11Y_TYPE,
-                                                  glade_property_class_id (pclass));
+                                                  glade_property_def_id (pdef));
               glade_xml_node_set_property_string (prop_node,
                                                   GLADE_TAG_A11Y_TARGET,
                                                   split[i]);
@@ -466,9 +473,9 @@ glade_gtk_widget_write_atk_relation (GladeProperty * property,
 }
 
 static void
-glade_gtk_widget_write_atk_relations (GladeWidget * widget,
-                                      GladeXmlContext * context,
-                                      GladeXmlNode * node)
+glade_gtk_widget_write_atk_relations (GladeWidget     *widget,
+                                      GladeXmlContext *context,
+                                      GladeXmlNode    *node)
 {
   GladeProperty *property;
   gint i;
@@ -485,21 +492,21 @@ glade_gtk_widget_write_atk_relations (GladeWidget * widget,
 }
 
 static void
-glade_gtk_widget_write_atk_action (GladeProperty * property,
-                                   GladeXmlContext * context,
-                                   GladeXmlNode * node)
+glade_gtk_widget_write_atk_action (GladeProperty   *property,
+                                   GladeXmlContext *context,
+                                   GladeXmlNode    *node)
 {
   gchar *value = glade_property_make_string (property);
 
   if (value && value[0])
     {
-      GladePropertyClass *pclass = glade_property_get_class (property);
+      GladePropertyDef *pdef = glade_property_get_def (property);
       GladeXmlNode *prop_node = glade_xml_node_new (context, GLADE_TAG_A11Y_ACTION);
       glade_xml_node_append_child (node, prop_node);
 
       glade_xml_node_set_property_string (prop_node,
                                           GLADE_TAG_A11Y_ACTION_NAME,
-                                          &glade_property_class_id (pclass)[4]);
+                                          &glade_property_def_id (pdef)[4]);
       glade_xml_node_set_property_string (prop_node,
                                           GLADE_TAG_A11Y_DESC, value);
     }
@@ -508,9 +515,9 @@ glade_gtk_widget_write_atk_action (GladeProperty * property,
 }
 
 static void
-glade_gtk_widget_write_atk_actions (GladeWidget * widget,
-                                    GladeXmlContext * context,
-                                    GladeXmlNode * node)
+glade_gtk_widget_write_atk_actions (GladeWidget     *widget,
+                                    GladeXmlContext *context,
+                                    GladeXmlNode    *node)
 {
   GladeProperty *property;
 
@@ -525,9 +532,9 @@ glade_gtk_widget_write_atk_actions (GladeWidget * widget,
 }
 
 static void
-glade_gtk_widget_write_atk_props (GladeWidget * widget,
-                                  GladeXmlContext * context,
-                                  GladeXmlNode * node)
+glade_gtk_widget_write_atk_props (GladeWidget     *widget,
+                                  GladeXmlContext *context,
+                                  GladeXmlNode    *node)
 {
   GladeXmlNode *atk_node;
 
@@ -546,9 +553,9 @@ glade_gtk_widget_write_atk_props (GladeWidget * widget,
 
 
 static void
-glade_gtk_widget_write_style_classes (GladeWidget * widget,
-				      GladeXmlContext * context,
-				      GladeXmlNode * node)
+glade_gtk_widget_write_style_classes (GladeWidget     *widget,
+                                      GladeXmlContext *context,
+                                      GladeXmlNode    *node)
 {
   GladeXmlNode *class_node, *style_node;
   GList        *string_list = NULL, *l;
@@ -567,8 +574,8 @@ glade_gtk_widget_write_style_classes (GladeWidget * widget,
       glade_xml_node_append_child (style_node, class_node);
 
       glade_xml_node_set_property_string (class_node,
-					  GLADE_TAG_NAME,
-					  string->string);
+                                          GLADE_TAG_NAME,
+                                          string->string);
     }
 
   if (!glade_xml_node_get_children (style_node))
@@ -578,14 +585,15 @@ glade_gtk_widget_write_style_classes (GladeWidget * widget,
 }
 
 void
-glade_gtk_widget_write_widget (GladeWidgetAdaptor * adaptor,
-                               GladeWidget * widget,
-                               GladeXmlContext * context, GladeXmlNode * node)
+glade_gtk_widget_write_widget (GladeWidgetAdaptor *adaptor,
+                               GladeWidget        *widget,
+                               GladeXmlContext    *context,
+                               GladeXmlNode       *node)
 {
   GladeProperty *prop;
 
   if (!(glade_xml_node_verify_silent (node, GLADE_XML_TAG_WIDGET) ||
-	glade_xml_node_verify_silent (node, GLADE_XML_TAG_TEMPLATE)))
+        glade_xml_node_verify_silent (node, GLADE_XML_TAG_TEMPLATE)))
     return;
 
   /* Make sure use-action-appearance and related-action properties are
@@ -603,9 +611,10 @@ glade_gtk_widget_write_widget (GladeWidgetAdaptor * adaptor,
 }
 
 void
-glade_gtk_widget_write_widget_after (GladeWidgetAdaptor * adaptor,
-				     GladeWidget * widget,
-				     GladeXmlContext * context, GladeXmlNode * node)
+glade_gtk_widget_write_widget_after (GladeWidgetAdaptor *adaptor,
+                                     GladeWidget        *widget,
+                                     GladeXmlContext    *context,
+                                     GladeXmlNode       *node)
 {
   /* The ATK properties are actually children */
   glade_gtk_widget_write_atk_props (widget, context, node);
@@ -619,31 +628,32 @@ glade_gtk_widget_write_widget_after (GladeWidgetAdaptor * adaptor,
 }
 
 GladeEditorProperty *
-glade_gtk_widget_create_eprop (GladeWidgetAdaptor * adaptor,
-                               GladePropertyClass * klass, gboolean use_command)
+glade_gtk_widget_create_eprop (GladeWidgetAdaptor *adaptor,
+                               GladePropertyDef   *def,
+                               gboolean            use_command)
 {
   GladeEditorProperty *eprop;
   GParamSpec          *pspec;
 
-  pspec = glade_property_class_get_pspec (klass);
+  pspec = glade_property_def_get_pspec (def);
 
   /* chain up.. */
   if (pspec->value_type == GLADE_TYPE_ACCEL_GLIST)
     eprop = g_object_new (GLADE_TYPE_EPROP_ACCEL,
-                          "property-class", klass,
+                          "property-def", def,
                           "use-command", use_command, NULL);
   else if (pspec->value_type == GLADE_TYPE_STRING_LIST)
-    eprop = glade_eprop_string_list_new (klass, use_command, FALSE, FALSE);
+    eprop = glade_eprop_string_list_new (def, use_command, FALSE, FALSE);
   else
     eprop = GWA_GET_CLASS
-        (G_TYPE_OBJECT)->create_eprop (adaptor, klass, use_command);
+        (G_TYPE_OBJECT)->create_eprop (adaptor, def, use_command);
 
   return eprop;
 }
 
 GladeEditable *
-glade_gtk_widget_create_editable (GladeWidgetAdaptor * adaptor,
-				  GladeEditorPageType type)
+glade_gtk_widget_create_editable (GladeWidgetAdaptor *adaptor,
+                                  GladeEditorPageType type)
 {
   GladeEditable *editable;
 
@@ -657,13 +667,13 @@ glade_gtk_widget_create_editable (GladeWidgetAdaptor * adaptor,
 }
 
 gchar *
-glade_gtk_widget_string_from_value (GladeWidgetAdaptor * adaptor,
-                                    GladePropertyClass * klass,
-                                    const GValue * value)
+glade_gtk_widget_string_from_value (GladeWidgetAdaptor *adaptor,
+                                    GladePropertyDef   *def,
+                                    const GValue       *value)
 {
   GParamSpec          *pspec;
 
-  pspec = glade_property_class_get_pspec (klass);
+  pspec = glade_property_def_get_pspec (def);
 
   if (pspec->value_type == GLADE_TYPE_ACCEL_GLIST)
     return glade_accels_make_string (g_value_get_boxed (value));
@@ -675,18 +685,19 @@ glade_gtk_widget_string_from_value (GladeWidgetAdaptor * adaptor,
     }
   else
     return GWA_GET_CLASS
-        (G_TYPE_OBJECT)->string_from_value (adaptor, klass, value);
+        (G_TYPE_OBJECT)->string_from_value (adaptor, def, value);
 }
 
 static void
-widget_parent_changed (GtkWidget * widget,
-                       GParamSpec * pspec, GladeWidgetAdaptor * adaptor)
+widget_parent_changed (GtkWidget          *widget,
+                       GParamSpec         *pspec,
+                       GladeWidgetAdaptor *adaptor)
 {
   GladeWidget *gwidget = glade_widget_get_from_gobject (widget);
   GladeWidget *parent;
 
   /* this could get called for a stale instance of an object
-   * being rebuilt for a contruct-only property. */
+   * being rebuilt for a construct-only property. */
   if (!gwidget)
     return;
 
@@ -699,8 +710,9 @@ widget_parent_changed (GtkWidget * widget,
 }
 
 void
-glade_gtk_widget_deep_post_create (GladeWidgetAdaptor * adaptor,
-                                   GObject * widget, GladeCreateReason reason)
+glade_gtk_widget_deep_post_create (GladeWidgetAdaptor *adaptor,
+                                   GObject            *widget,
+                                   GladeCreateReason   reason)
 {
   GladeWidget *gwidget = glade_widget_get_from_gobject (widget);
 
@@ -724,9 +736,10 @@ glade_gtk_widget_deep_post_create (GladeWidgetAdaptor * adaptor,
 }
 
 void
-glade_gtk_widget_set_property (GladeWidgetAdaptor * adaptor,
-                               GObject * object,
-                               const gchar * id, const GValue * value)
+glade_gtk_widget_set_property (GladeWidgetAdaptor *adaptor,
+                               GObject            *object,
+                               const gchar        *id,
+                               const GValue       *value)
 {
   /* FIXME: is this still needed with the new gtk+ tooltips? */
   if (!strcmp (id, "tooltip"))
@@ -748,16 +761,16 @@ glade_gtk_widget_set_property (GladeWidgetAdaptor * adaptor,
        */
       styles = g_object_get_data (object, "glade-style-classes");
       for (l = styles; l; l = g_list_next (l))
-	{
-	  GladeString *style = l->data;
+        {
+          GladeString *style = l->data;
           gtk_style_context_remove_class (context, style->string);
-	}
+        }
 
       for (l = g_value_get_boxed (value); l; l = g_list_next (l))
-	{
-	  GladeString *style = l->data;
-	  gtk_style_context_add_class (context, style->string);
-	}
+        {
+          GladeString *style = l->data;
+          gtk_style_context_add_class (context, style->string);
+        }
 
       /* Save the list here so we can use it later on to remove them from the style context */
       g_object_set_data_full (object, "glade-style-classes",
@@ -783,17 +796,17 @@ glade_gtk_widget_get_property (GladeWidgetAdaptor * adaptor,
 
 
 static GList *
-create_command_property_list (GladeWidget * gnew, GList * saved_props)
+create_command_property_list (GladeWidget *gnew, GList *saved_props)
 {
   GList *l, *command_properties = NULL;
 
   for (l = saved_props; l; l = l->next)
     {
       GladeProperty *property = l->data;
-      GladePropertyClass *pclass = glade_property_get_class (property);
+      GladePropertyDef *pdef = glade_property_get_def (property);
       GladeProperty *orig_prop =
-	glade_widget_get_pack_property (gnew, glade_property_class_id (pclass));
-      GCSetPropData *pdata = g_new0 (GCSetPropData, 1);
+        glade_widget_get_pack_property (gnew, glade_property_def_id (pdef));
+      GladeCommandSetPropData *pdata = g_new0 (GladeCommandSetPropData, 1);
 
       pdata->property = orig_prop;
       pdata->old_value = g_new0 (GValue, 1);
@@ -809,8 +822,9 @@ create_command_property_list (GladeWidget * gnew, GList * saved_props)
 
 
 void
-glade_gtk_widget_action_activate (GladeWidgetAdaptor * adaptor,
-                                  GObject * object, const gchar * action_path)
+glade_gtk_widget_action_activate (GladeWidgetAdaptor *adaptor,
+                                  GObject            *object, 
+                                  const gchar        *action_path)
 {
   GladeWidget *gwidget = glade_widget_get_from_gobject (object), *gparent;
   GList this_widget = { 0, }, that_widget = { 0,};
@@ -858,7 +872,7 @@ glade_gtk_widget_action_activate (GladeWidgetAdaptor * adaptor,
       /* If the parent had a parentless widget reference, undoably add the child
        * as the new parentless widget reference here */
       if (property)
-	glade_command_set_property (property, glade_widget_get_object (gwidget));
+        glade_command_set_property (property, glade_widget_get_object (gwidget));
 
       glade_command_pop_group ();
     }
@@ -895,22 +909,22 @@ glade_gtk_widget_action_activate (GladeWidgetAdaptor * adaptor,
           GladeWidgetAdaptor *adaptor =
             glade_widget_adaptor_get_by_type (new_type);
           GList *saved_props, *prop_cmds;
-	  GladeWidget *gnew_parent;
+          GladeWidget *gnew_parent;
           GladeProperty *property;
 
           glade_command_push_group (_("Adding parent %s for %s"),
                                     glade_widget_adaptor_get_title (adaptor), 
-				    glade_widget_get_name (gwidget));
+                                    glade_widget_get_name (gwidget));
 
           /* Record packing properties */
           saved_props =
-	    glade_widget_dup_properties (gwidget, glade_widget_get_packing_properties (gwidget),
-					 FALSE, FALSE, FALSE);
+            glade_widget_dup_properties (gwidget, glade_widget_get_packing_properties (gwidget),
+                                         FALSE, FALSE, FALSE);
 
-	  property = glade_widget_get_parentless_widget_ref (gwidget);
+          property = glade_widget_get_parentless_widget_ref (gwidget);
 
-	  /* Remove "this" widget, If the parent we're removing is a parentless 
-	   * widget reference, the reference will be implicitly broken by the 'cut' command */
+          /* Remove "this" widget, If the parent we're removing is a parentless 
+           * widget reference, the reference will be implicitly broken by the 'cut' command */
           this_widget.data = gwidget;
           glade_command_delete (&this_widget);
 
@@ -918,10 +932,10 @@ glade_gtk_widget_action_activate (GladeWidgetAdaptor * adaptor,
           if ((gnew_parent =
                glade_command_create (adaptor, gparent, NULL, project)) != NULL)
             {
-	      /* Now we created the new parent, if gwidget had a parentless widget reference...
-	       * set that reference to the new parent instead */
-	      if (property)
-		glade_command_set_property (property, glade_widget_get_object (gnew_parent));
+              /* Now we created the new parent, if gwidget had a parentless widget reference...
+               * set that reference to the new parent instead */
+              if (property)
+                glade_command_set_property (property, glade_widget_get_object (gnew_parent));
 
               /* Remove the alignment that we added in the frame's post_create... */
               if (new_type == GTK_TYPE_FRAME)
@@ -942,7 +956,7 @@ glade_gtk_widget_action_activate (GladeWidgetAdaptor * adaptor,
               /* Apply the properties in an undoable way */
               if (prop_cmds)
                 glade_command_set_properties_list 
-		  (glade_widget_get_project (gparent), prop_cmds);
+                  (glade_widget_get_project (gparent), prop_cmds);
 
               /* Add "this" widget to the new parent */
               glade_command_add (&this_widget, gnew_parent, NULL, project, FALSE);
@@ -950,19 +964,19 @@ glade_gtk_widget_action_activate (GladeWidgetAdaptor * adaptor,
               glade_command_pop_group ();
             }
           else
-	    {
+            {
               glade_command_pop_group ();
 
               /* Undo delete command
-               * FIXME: this will leave the "Adding parent..." comand in the
+               * FIXME: this will leave the "Adding parent..." command in the
                * redo list, which I think its better than leaving it in the
                * undo list by using glade_command_add() to add the widget back
                * to the original parent.
                * Ideally we need a way to remove a redo item from the project or
                * simply do not let the user cancel a widget creation!
                */
-	      glade_project_undo (project);
-	    }
+              glade_project_undo (project);
+            }
 
           g_list_foreach (saved_props, (GFunc) g_object_unref, NULL);
           g_list_free (saved_props);
@@ -979,7 +993,7 @@ glade_gtk_widget_action_activate (GladeWidgetAdaptor * adaptor,
   else if (strcmp (action_path, "read_documentation") == 0)
     {
       glade_app_search_docs (glade_widget_adaptor_get_book (adaptor),
-                             glade_widget_adaptor_get_name (adaptor),
+                             glade_widget_adaptor_get_display_name (adaptor),
                              NULL);
     }
   else
@@ -988,7 +1002,7 @@ glade_gtk_widget_action_activate (GladeWidgetAdaptor * adaptor,
 }
 
 static GList *
-list_sizegroups (GladeWidget * gwidget)
+list_sizegroups (GladeWidget *gwidget)
 {
   GladeProject *project = glade_widget_get_project (gwidget);
   GList *groups = NULL;
@@ -1004,7 +1018,7 @@ list_sizegroups (GladeWidget * gwidget)
 }
 
 static void
-glade_gtk_widget_add2group_cb (GtkMenuItem * item, GladeWidget * gwidget)
+glade_gtk_widget_add2group_cb (GtkMenuItem *item, GladeWidget *gwidget)
 {
   GladeWidget *group =
       g_object_get_data (G_OBJECT (item), "glade-group-widget");
@@ -1021,20 +1035,20 @@ glade_gtk_widget_add2group_cb (GtkMenuItem * item, GladeWidget * gwidget)
     {
       size_group_name = glade_widget_get_name (group);
       if (g_str_has_prefix (size_group_name, GLADE_UNNAMED_PREFIX))
-	size_group_name = _("(unnamed)");
+        size_group_name = _("(unnamed)");
     }
 
   /* Ensure the widget has a name if it's going to be referred to by a size group */
   current_name = glade_widget_get_name (gwidget);
   if (g_str_has_prefix (current_name, GLADE_UNNAMED_PREFIX))
     widget_name = glade_project_new_widget_name (glade_widget_get_project (gwidget), NULL,
-						 glade_widget_adaptor_get_generic_name (glade_widget_get_adaptor (gwidget)));
+                                                 glade_widget_adaptor_get_generic_name (glade_widget_get_adaptor (gwidget)));
   else
     widget_name = g_strdup (current_name);
 
   if (group)
     glade_command_push_group (_("Adding %s to Size Group %s"),
-			      widget_name,
+                              widget_name,
                               size_group_name);
   else
     glade_command_push_group (_("Adding %s to a new Size Group"),
@@ -1063,8 +1077,9 @@ glade_gtk_widget_add2group_cb (GtkMenuItem * item, GladeWidget * gwidget)
 
 
 GtkWidget *
-glade_gtk_widget_action_submenu (GladeWidgetAdaptor * adaptor,
-                                 GObject * object, const gchar * action_path)
+glade_gtk_widget_action_submenu (GladeWidgetAdaptor *adaptor,
+                                 GObject            *object,
+                                 const gchar        *action_path)
 {
   GladeWidget *gwidget = glade_widget_get_from_gobject (object);
   GList *groups, *list;
@@ -1082,11 +1097,11 @@ glade_gtk_widget_action_submenu (GladeWidgetAdaptor * adaptor,
             {
               group = list->data;
 
-	      size_group_name = glade_widget_get_name (group);
-	      if (g_str_has_prefix (size_group_name, GLADE_UNNAMED_PREFIX))
-		size_group_name = _("(unnamed)");
+              size_group_name = glade_widget_get_name (group);
+              if (g_str_has_prefix (size_group_name, GLADE_UNNAMED_PREFIX))
+                size_group_name = _("(unnamed)");
 
-	      item = gtk_menu_item_new_with_label (size_group_name);
+              item = gtk_menu_item_new_with_label (size_group_name);
 
               g_object_set_data (G_OBJECT (item), "glade-group-widget", group);
               g_signal_connect (G_OBJECT (item), "activate",
