@@ -62,7 +62,7 @@ enum
 static GParamSpec *properties[N_PROPERTIES];
 static guint http_signals[LAST_SIGNAL] = { 0 };
 
-G_DEFINE_TYPE (GladeHTTP, glade_http, G_TYPE_OBJECT);
+G_DEFINE_TYPE_WITH_PRIVATE (GladeHTTP, glade_http, G_TYPE_OBJECT);
 
 static void
 glade_http_emit_request_done (GladeHTTP *http, gchar *response)
@@ -144,7 +144,7 @@ on_read_ready (GObject *source, GAsyncResult *res, gpointer data)
     {
       g_string_append_len (priv->response, priv->response_buffer, bytes_read);
 
-      /* NOTE: We do not need to parse content-lenght because we do not support
+      /* NOTE: We do not need to parse content-length because we do not support
        * multiples HTTP requests in the same connection.
        */
       if (priv->cancellable)
@@ -179,7 +179,7 @@ on_write_ready (GObject *source, GAsyncResult *res, gpointer data)
 
   if (error == NULL && priv->data->len != count)
     error = g_error_new (G_IO_ERROR, G_IO_ERROR_FAILED, 
-                         "Error sending data data to %s", 
+                         "Error sending data to %s", 
                          priv->host);
 
   if (error)
@@ -224,7 +224,7 @@ glade_http_init (GladeHTTP *http)
 {
   GladeHTTPPrivate *priv;
   
-  priv = http->priv = G_TYPE_INSTANCE_GET_PRIVATE (http, GLADE_TYPE_HTTP, GladeHTTPPrivate);
+  priv = http->priv = glade_http_get_instance_private (http);
 
   priv->data = g_string_new ("");
   priv->response = g_string_new ("");
@@ -316,8 +316,6 @@ glade_http_class_init (GladeHTTPClass *klass)
 {
   GObjectClass *object_class = G_OBJECT_CLASS (klass);
 
-  g_type_class_add_private (klass, sizeof (GladeHTTPPrivate));
-
   object_class->finalize = glade_http_finalize;
   object_class->set_property = glade_http_set_property;
   object_class->get_property = glade_http_get_property;
@@ -334,7 +332,7 @@ glade_http_class_init (GladeHTTPClass *klass)
 
   properties[PROP_TLS] =
     g_param_spec_boolean ("tls", "TLS",
-                          "Wheter to use tls encryption or not",
+                          "Whether to use tls encryption or not",
                           FALSE, G_PARAM_READWRITE);
 
   /* Install all properties */
@@ -377,7 +375,7 @@ glade_http_get_host (GladeHTTP *http)
 gint
 glade_http_get_port (GladeHTTP *http)
 {
-  g_return_val_if_fail (GLADE_IS_HTTP (http), NULL);
+  g_return_val_if_fail (GLADE_IS_HTTP (http), 0);
   return http->priv->port;
 }
 
