@@ -31,7 +31,7 @@
 /* translators: Email subject sent to the user after completing the survey */
 #define MAIL_SUBJECT _("Glade User Survey")
 /* translators: Email body sent to the user after completing the survey */
-#define MAIL_BODY _("Thank you for taking Glade Users survey, we appreciate it!\n\nTo validate this email address open the folowing link\n\nhttps://people.gnome.org/~jpu/glade/registration.php?email=$email&validation_token=$new_validation_token\n\nIn case you want to change or update the survey, your current update token is:\n$new_token\n\nCheers\n\n	The Glade team\n")
+#define MAIL_BODY _("Thank you for taking Glade Users survey, we appreciate it!\n\nTo validate this email address open the following link\n\nhttps://people.gnome.org/~jpu/glade/registration.php?email=$email&validation_token=$new_validation_token\n\nIn case you want to change or update the survey, your current update token is:\n$new_token\n\nCheers\n\n	The Glade team\n")
 
 /* translators: Email subject sent to the user after updating the survey */
 #define UPDATE_MAIL_SUBJECT _("Glade User Survey (update)")
@@ -552,13 +552,6 @@ on_registration_dialog_response (GtkDialog *dialog, gint response_id)
   g_string_free (post, TRUE);
 }
 
-static void
-on_privacy_button_clicked (GtkButton *button, GtkScrolledWindow *swindow)
-{
-  GtkAdjustment *adj = gtk_scrolled_window_get_vadjustment (swindow);
-  gtk_adjustment_set_value (adj, gtk_adjustment_get_upper (adj));
-}
-
 static void
 toggle_button_set_visible_on_toggle (GtkToggleButton *button, GtkWidget *widget)
 {
@@ -571,55 +564,38 @@ toggle_button_set_sensitive_on_toggle (GtkToggleButton *button, GtkWidget *widge
   gtk_widget_set_sensitive (widget, gtk_toggle_button_get_active (button));
 }
 
-static void 
-glade_registration_set_css_provider_forall (GtkWidget *widget, gpointer data)
-{
-  gtk_style_context_add_provider (gtk_widget_get_style_context (widget),
-                                  GTK_STYLE_PROVIDER (data),
-                                  GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
-  
-  if (GTK_IS_CONTAINER (widget))
-    gtk_container_forall (GTK_CONTAINER (widget), glade_registration_set_css_provider_forall, data);
-}
-
 static gboolean
-on_viewport_draw (GtkWidget *widget, cairo_t *cr)
+on_viewport_draw (GtkWidget *viewport, cairo_t *cr, GladeRegistration *widget)
 {
-  GdkWindow *window = gtk_viewport_get_bin_window (GTK_VIEWPORT (widget));
+  GtkStyleContext *context = gtk_widget_get_style_context (viewport);
+  GtkAllocation alloc;
+  gdouble scale;
+  GdkRGBA c;
 
-  if (gtk_cairo_should_draw_window (cr, window))
-    { 
-      GtkAllocation alloc;
-      gdouble scale;
+  gtk_style_context_get_color (context, gtk_style_context_get_state (context), &c);
 
-      gtk_widget_get_allocation (widget, &alloc);
+  gtk_widget_get_allocation (viewport, &alloc);
       
-      scale = MIN (alloc.width/GLADE_LOGO_WIDTH, alloc.height/GLADE_LOGO_HEIGHT) - .1;
+  scale = MIN (alloc.width/GLADE_LOGO_WIDTH, alloc.height/GLADE_LOGO_HEIGHT) - .1;
       
-      cairo_save (cr);
+  cairo_save (cr);
 
-      cairo_set_source_rgba (cr, 0, 0, 0, .04);
-      cairo_scale (cr, scale, scale);
-      cairo_translate (cr, (alloc.width / scale) - GLADE_LOGO_WIDTH*.95,
-                       (alloc.height / scale) - GLADE_LOGO_HEIGHT);
-      cairo_append_path (cr, &glade_logo_path);
-      cairo_fill (cr);
+  cairo_set_source_rgba (cr, c.red, c.green, c.blue, .04);
+  cairo_scale (cr, scale, scale);
+  cairo_translate (cr, (alloc.width / scale) - GLADE_LOGO_WIDTH*.95,
+                   (alloc.height / scale) - GLADE_LOGO_HEIGHT);
+  cairo_append_path (cr, &glade_logo_path);
+  cairo_fill (cr);
 
-      cairo_restore (cr);
-    }
+  cairo_restore (cr);
 
-  gtk_container_propagate_draw (GTK_CONTAINER (widget),
-                                gtk_bin_get_child (GTK_BIN (widget)),
-                                cr);
-  return TRUE;
+  return FALSE;
 }
 
 static void
 glade_registration_init (GladeRegistration *registration)
 {
   GladeRegistrationPrivate *priv = glade_registration_get_instance_private (registration);
-  GtkCssProvider *css_provider;
-  GFile *file;
 
   registration->priv = priv;
 
@@ -635,13 +611,6 @@ glade_registration_init (GladeRegistration *registration)
   
   gtk_widget_init_template (GTK_WIDGET (registration));
 
-  /* Apply Custom CSS */
-  css_provider = gtk_css_provider_new ();
-  file = g_file_new_for_uri ("resource:///org/gnome/glade/glade-registration.css");
-  if (gtk_css_provider_load_from_file (css_provider, file, NULL))
-    glade_registration_set_css_provider_forall (GTK_WIDGET (registration), css_provider);
-  g_object_unref (file);
-
   if (GTK_IS_COMBO_BOX_TEXT (priv->version_other))
     {
       GtkComboBoxText *combo = GTK_COMBO_BOX_TEXT (priv->version_other);
@@ -712,6 +681,7 @@ glade_registration_class_init (GladeRegistrationClass *klass)
 {
   GObjectClass *object_class = G_OBJECT_CLASS (klass);
   GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (klass);
+  GtkCssProvider *css_provider;
 
   gtk_widget_class_set_template_from_resource (widget_class, "/org/gnome/glade/glade-registration.glade");
 
@@ -779,7 +749,6 @@ glade_registration_class_init (GladeRegistrationClass *klass)
   gtk_widget_class_bind_template_child_private (widget_class, GladeRegistration, comments);
   
   gtk_widget_class_bind_template_callback (widget_class, on_registration_dialog_response);
-  gtk_widget_class_bind_template_callback (widget_class, on_privacy_button_clicked);
   gtk_widget_class_bind_template_callback (widget_class, toggle_button_set_visible_on_toggle);
   gtk_widget_class_bind_template_callback (widget_class, toggle_button_set_sensitive_on_toggle);
   gtk_widget_class_bind_template_callback (widget_class, on_viewport_draw);
@@ -803,6 +772,15 @@ glade_registration_class_init (GladeRegistrationClass *klass)
                                                          "Skip registration reminder dialog",
                                                          FALSE,
                                                          G_PARAM_READWRITE));
+
+  /* Setup Custom CSS */
+  css_provider = gtk_css_provider_new ();
+  gtk_css_provider_load_from_resource (css_provider, "/org/gnome/glade/glade-registration.css");
+
+  gtk_style_context_add_provider_for_screen (gdk_screen_get_default (),
+                                             GTK_STYLE_PROVIDER (css_provider),
+                                             GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
+ g_object_unref (css_provider);
 }
 
 GtkWidget*
