@@ -30,12 +30,14 @@
 #include "glade-resources.h"
 #include "glade-preferences.h"
 #include "glade-registration.h"
+#include "glade-settings.h"
 #include "glade-intro.h"
 
 #include <gladeui/glade.h>
 #include <gladeui/glade-popup.h>
 #include <gladeui/glade-inspector.h>
 #include <gladeui/glade-adaptor-chooser.h>
+#include <gladeui/gladeui-enum-types.h>
 
 #include <gladeui/glade-project.h>
 
@@ -75,11 +77,13 @@
 #define CONFIG_INTRO_GROUP          "Intro"
 #define CONFIG_INTRO_DONE           "intro-done"
 
-#define GLADE_WINDOW_ACTIVE_VIEW(w) ((GladeDesignView *) gtk_stack_get_visible_child (w->priv->view_stack))
+#define GLADE_WINDOW_ACTIVE_VIEW(w)  ((GladeDesignView *) gtk_stack_get_visible_child (w->priv->view_stack))
+#define GLADE_WINDOW_GET_ACTION(w,a) ((w && ((GladeWindow *)w)->priv->application) ? g_action_map_lookup_action (G_ACTION_MAP (((GladeWindow *)w)->priv->application), a) : NULL)
 
 struct _GladeWindowPrivate
 {
   GladeApp *app;
+  GtkApplication *application;
 
   GtkStack *stack;
   GtkStack *view_stack;
@@ -87,7 +91,7 @@ struct _GladeWindowPrivate
   GtkHeaderBar *headerbar;
   GtkWidget *project_switcher ;
   GtkWindow *about_dialog;
-  GladePreferences *preferences;
+  GladeSettings *settings;
 
   GtkWidget *start_page;
   GtkLabel  *version_label;
@@ -103,8 +107,6 @@ struct _GladeWindowPrivate
   guint statusbar_menu_context_id;      /* The context id of the menu bar */
   guint statusbar_actions_context_id;   /* The context id of actions messages */
 
-  GActionGroup *actions;
-
   GtkRecentManager *recent_manager;
   GtkWidget *recent_menu;
 
@@ -139,26 +141,27 @@ refresh_title (GladeWindow *window)
   if (GLADE_WINDOW_ACTIVE_VIEW (window))
     {
       GladeProject *project = glade_design_view_get_project (GLADE_WINDOW_ACTIVE_VIEW (window));
-      gchar *title, *name = NULL;
+      gchar *title;
       GList *p;
 
       gtk_header_bar_set_custom_title (window->priv->headerbar, NULL);
 
-      name = glade_project_get_name (project);
-
+      title = glade_project_get_name (project);
       if (glade_project_get_modified (project))
-        name = g_strdup_printf ("*%s", name);
-      else
-        name = g_strdup (name);
+        {
+          gchar *old_title = g_steal_pointer (&title);
+          title = g_strdup_printf ("*%s", old_title);
+          g_free (old_title);
+        }
 
       if (glade_project_get_readonly (project) != FALSE)
-        title = g_strdup_printf ("%s %s", name, READONLY_INDICATOR);
-      else
-        title = g_strdup_printf ("%s", name);
+        {
+          gchar *old_title = g_steal_pointer (&title);
+          title = g_strdup_printf ("%s %s", old_title, READONLY_INDICATOR);
+        }
 
       gtk_header_bar_set_title (window->priv->headerbar, title);
       g_free (title);
-      g_free (name);
 
       if ((p = glade_app_get_projects ()) && g_list_next (p))
         gtk_header_bar_set_custom_title (window->priv->headerbar, window->priv->project_switcher);
@@ -219,13 +222,13 @@ update_default_path (GladeWindow *window, const gchar *filename)
 static void
 activate_action (GtkToolButton *toolbutton, GladeWidgetAction *action)
 {
-  GladeWidget   *widget;
-  GWActionClass *aclass = glade_widget_action_get_class (action);
+  GladeWidget          *widget;
+  GladeWidgetActionDef *adef = glade_widget_action_get_def (action);
 
   if ((widget = g_object_get_data (G_OBJECT (toolbutton), "glade-widget")))
     glade_widget_adaptor_action_activate (glade_widget_get_adaptor (widget),
                                           glade_widget_get_object (widget), 
-                                          aclass->path);
+                                          adef->path);
 }
 
 static void
@@ -274,10 +277,10 @@ add_actions (GladeWindow *window, GladeWidget *widget, GList *actions)
 
   for (l = actions; l; l = g_list_next (l))
     {
-      GladeWidgetAction *action = l->data;
-      GWActionClass     *aclass = glade_widget_action_get_class (action);
+      GladeWidgetAction    *action = l->data;
+      GladeWidgetActionDef *adef   = glade_widget_action_get_def (action);
 
-      if (!aclass->important || !glade_widget_action_get_visible (action))
+      if (!adef->important || !glade_widget_action_get_visible (action))
         continue;
 
       if (glade_widget_action_get_children (action))
@@ -286,12 +289,12 @@ add_actions (GladeWindow *window, GladeWidget *widget, GList *actions)
           continue;
         }
 
-      item = gtk_tool_button_new (NULL, aclass->label);
+      item = gtk_tool_button_new (NULL, adef->label);
       gtk_tool_button_set_icon_name (GTK_TOOL_BUTTON (item),
-                                     (aclass->stock) ? aclass->stock : "system-run");
+                                     (adef->stock) ? adef->stock : "system-run");
 
-      if (aclass->label)
-        gtk_widget_set_tooltip_text (GTK_WIDGET (item), aclass->label);
+      if (adef->label)
+        gtk_widget_set_tooltip_text (GTK_WIDGET (item), adef->label);
 
       g_object_set_data (G_OBJECT (item), "glade-widget", widget);
 
@@ -405,11 +408,13 @@ project_targets_changed_cb (GladeProject *project, GladeWindow *window)
   refresh_stack_title_for_project (window, project);
 }
 
-static void
+static inline void
 actions_set_enabled (GladeWindow *window, const gchar *name, gboolean enabled)
 {
-  GAction *action = g_action_map_lookup_action (G_ACTION_MAP (window->priv->actions), name);
-  g_simple_action_set_enabled (G_SIMPLE_ACTION (action), enabled);
+  GAction *action;
+
+  if ((action = GLADE_WINDOW_GET_ACTION (window, name)))
+    g_simple_action_set_enabled (G_SIMPLE_ACTION (action), enabled);
 }
 
 static void
@@ -505,10 +510,10 @@ project_queue_autosave (GladeWindow *window, GladeProject *project)
 {
   if (glade_project_get_path (project) != NULL &&
       glade_project_get_modified (project) &&
-      glade_preferences_autosave (window->priv->preferences))
+      glade_settings_autosave (window->priv->settings))
     {
       guint autosave_id =
-        g_timeout_add_seconds (glade_preferences_autosave_seconds (window->priv->preferences),
+        g_timeout_add_seconds (glade_settings_autosave_seconds (window->priv->settings),
                                autosave_project, project);
 
       g_object_set_data_full (G_OBJECT (project), "glade-autosave-id",
@@ -758,10 +763,10 @@ static gboolean
 do_save (GladeWindow *window, GladeProject *project, const gchar *path)
 {
   GError *error = NULL;
-  GladeVerifyFlags verify_flags = 0;
+  GladeVerifyFlags verify_flags = glade_settings_get_verify_flags (window->priv->settings);
   gchar *display_path = g_strdup (path);
 
-  if (glade_preferences_backup (window->priv->preferences) &&
+  if (glade_settings_backup (window->priv->settings) &&
       !glade_project_backup (project, path, NULL))
     {
       if (!glade_util_ui_message (GTK_WIDGET (window),
@@ -773,13 +778,6 @@ do_save (GladeWindow *window, GladeProject *project, const gchar *path)
         }
     }
 
-  if (glade_preferences_warn_versioning (window->priv->preferences))
-    verify_flags |= GLADE_VERIFY_VERSIONS;
-  if (glade_preferences_warn_deprecations (window->priv->preferences))
-    verify_flags |= GLADE_VERIFY_DEPRECATIONS;
-  if (glade_preferences_warn_unrecognized (window->priv->preferences))
-    verify_flags |= GLADE_VERIFY_UNRECOGNIZED;
-
   if (!glade_project_save_verify (project, path, verify_flags, &error))
     {
       if (error)
@@ -1473,7 +1471,14 @@ on_preferences_action_activate (GSimpleAction *action,
                                 gpointer       data)
 {
   GladeWindow *window = data;
-  gtk_widget_show (GTK_WIDGET (window->priv->preferences));
+  GladeWindowPrivate *priv = window->priv;
+  GtkWidget *preferences = glade_preferences_new (priv->settings);
+
+  gtk_window_set_transient_for (GTK_WINDOW (preferences), GTK_WINDOW (window));
+  gtk_widget_show (preferences);
+
+  gtk_dialog_run (GTK_DIALOG (preferences));
+  gtk_widget_destroy (preferences);
 }
 
 static void
@@ -1540,7 +1545,9 @@ drag_data_received (GtkWidget *widget,
 static gboolean
 delete_event (GtkWindow *w, GdkEvent *event, GladeWindow *window)
 {
-  g_action_group_activate_action (window->priv->actions, "quit", NULL);
+  GladeWindowPrivate *priv = window->priv;
+
+  g_action_group_activate_action (G_ACTION_GROUP (priv->application), "quit", NULL);
 
   /* return TRUE to stop other handlers */
   return TRUE;
@@ -1919,7 +1926,7 @@ glade_window_config_save (GladeWindow * window)
   save_paned_position (config, window->priv->center_paned, "center_pane");
   save_paned_position (config, window->priv->left_paned, "left_pane");
 
-  glade_preferences_save (window->priv->preferences, config);
+  glade_settings_save (window->priv->settings, config);
 
   glade_app_config_save ();
 }
@@ -2080,31 +2087,20 @@ on_quit_action_activate (GSimpleAction *action,
 
   g_list_free (projects);
 
-  gtk_main_quit ();
+  g_application_quit (G_APPLICATION (window->priv->application));
 }
 
 static void
-on_pointer_select_action_activate (GSimpleAction *action, GVariant *p, gpointer data)
+on_pointer_mode_action_activate (GSimpleAction *simple,
+                                 GVariant      *parameter,
+                                 gpointer       data)
 {
-  glade_project_set_pointer_mode (get_active_project (data), GLADE_POINTER_SELECT);
-}
+  GladePointerMode mode;
 
-static void
-on_pointer_align_edit_action_activate (GSimpleAction *action, GVariant *p, gpointer data)
-{
-  glade_project_set_pointer_mode (get_active_project (data), GLADE_POINTER_ALIGN_EDIT);
-}
-
-static void
-on_pointer_drag_resize_action_activate (GSimpleAction *action, GVariant *p, gpointer data)
-{
-  glade_project_set_pointer_mode (get_active_project (data), GLADE_POINTER_DRAG_RESIZE);
-}
-
-static void
-on_pointer_margin_edit_action_activate (GSimpleAction *action, GVariant *p, gpointer data)
-{
-  glade_project_set_pointer_mode (get_active_project (data), GLADE_POINTER_MARGIN_EDIT);
+  mode = glade_utils_enum_value_from_string (GLADE_TYPE_POINTER_MODE,
+                                             g_variant_get_string (parameter,
+                                                                   NULL));
+  glade_project_set_pointer_mode (get_active_project (data), mode);
 }
 
 static void
@@ -2124,15 +2120,8 @@ glade_window_init (GladeWindow *window)
 
   priv->default_path = NULL;
 
-  /* Init preferences first, this has to be done before anything initializes
-   * the real GladeApp, so that catalog paths are loaded correctly before we
-   * continue.
-   *
-   * This should be fixed so that dynamic addition of catalogs at runtime
-   * is supported.
-   */
-  priv->preferences = (GladePreferences *)glade_preferences_new ();
-  glade_preferences_load (window->priv->preferences, glade_app_get_config ());
+  priv->settings = glade_settings_new ();
+  glade_settings_load (priv->settings, glade_app_get_config ());
 
   /* We need this for the icons to be available */
   glade_init ();
@@ -2148,10 +2137,9 @@ glade_window_init (GladeWindow *window)
 static void
 glade_window_action_handler (GladeWindow *window, const gchar *name)
 {
-  GladeWindowPrivate *priv = window->priv;
   GAction *action;
 
-  if ((action = g_action_map_lookup_action (G_ACTION_MAP (priv->actions), name)))
+  if ((action = GLADE_WINDOW_GET_ACTION (window, name)))
     g_action_activate (action, NULL);
 }
 
@@ -2221,16 +2209,17 @@ on_intro_show_node (GladeIntro  *intro,
   if (!g_strcmp0 (node, "new-project"))
     {
       /* Create two new project to make the project switcher visible */
-      g_action_group_activate_action (window->priv->actions, "new", NULL);
-      g_action_group_activate_action (window->priv->actions, "new", NULL);
+      g_action_group_activate_action (G_ACTION_GROUP (priv->application), "new", NULL);
+      g_action_group_activate_action (G_ACTION_GROUP (priv->application), "new", NULL);
     }
   else if (!g_strcmp0 (node, "add-project"))
     {
-      GAction *new_action = g_action_map_lookup_action (G_ACTION_MAP (priv->actions), "new");
+      GAction *new_action;
 
-      g_signal_connect (new_action, "activate",
-                        G_CALLBACK (on_user_new_action_activate),
-                        window);
+      if ((new_action = GLADE_WINDOW_GET_ACTION (window, "new")))
+        g_signal_connect (new_action, "activate",
+                          G_CALLBACK (on_user_new_action_activate),
+                          window);
     }
   else if (!g_strcmp0 (node, "add-window"))
     {
@@ -2347,7 +2336,7 @@ glade_window_populate_intro (GladeWindow *window)
 }
 
 static void
-glade_window_constructed (GObject *object)
+on_application_notify (GObject *gobject, GParamSpec *pspec)
 {
   static GActionEntry actions[] = {
     { "open",         on_open_action_activate, NULL, NULL, NULL },
@@ -2371,12 +2360,25 @@ glade_window_constructed (GObject *object)
     { "delete",       on_delete_action_activate, NULL, NULL, NULL },
     { "previous",     on_previous_action_activate, NULL, NULL, NULL },
     { "next",         on_next_action_activate, NULL, NULL, NULL },
-    /* Pointer mode actions */
-    { "select",       on_pointer_select_action_activate, NULL, NULL, NULL },
-    { "drag_resize",  on_pointer_drag_resize_action_activate, NULL, NULL, NULL },
-    { "margin_edit",  on_pointer_margin_edit_action_activate, NULL, NULL, NULL },
-    { "align_edit",   on_pointer_align_edit_action_activate, NULL, NULL, NULL },
+    { "pointer-mode", on_pointer_mode_action_activate, "s", NULL, NULL },
   };
+  GladeWindowPrivate * priv = GLADE_WINDOW (gobject)->priv;
+
+  priv->application = gtk_window_get_application (GTK_WINDOW (gobject));
+
+  g_action_map_add_action_entries (G_ACTION_MAP (priv->application),
+                                   actions,
+                                   G_N_ELEMENTS (actions),
+                                   gobject);
+  gtk_widget_insert_action_group (GTK_WIDGET (gobject), "app",
+                                  G_ACTION_GROUP (priv->application));
+
+  project_actions_set_enabled (GLADE_WINDOW (gobject), FALSE);
+}
+
+static void
+glade_window_constructed (GObject *object)
+{
   GladeWindow *window = GLADE_WINDOW (object);
   GladeWindowPrivate *priv = window->priv;
   gchar *version;
@@ -2384,6 +2386,8 @@ glade_window_constructed (GObject *object)
   /* Chain up... */
   G_OBJECT_CLASS (glade_window_parent_class)->constructed (object);
 
+  g_signal_connect (object, "notify::application", G_CALLBACK (on_application_notify), NULL);
+
   /* Init Glade version */
   version = g_strdup_printf ("%d.%d.%d", GLADE_MAJOR_VERSION, GLADE_MINOR_VERSION, GLADE_MICRO_VERSION);
   gtk_label_set_text (priv->version_label, version);
@@ -2392,11 +2396,6 @@ glade_window_constructed (GObject *object)
   /* recent files */
   priv->recent_manager = gtk_recent_manager_get_default ();
 
-  /* Setup Actions */
-  priv->actions = (GActionGroup *) g_simple_action_group_new ();
-  g_action_map_add_action_entries (G_ACTION_MAP (priv->actions), actions, G_N_ELEMENTS (actions), window);
-  gtk_widget_insert_action_group (GTK_WIDGET (window), "app", priv->actions);
-
   /* status bar */
   priv->statusbar_context_id = gtk_statusbar_get_context_id (GTK_STATUSBAR (priv->statusbar), "general");
   priv->statusbar_menu_context_id = gtk_statusbar_get_context_id (GTK_STATUSBAR (priv->statusbar), "menu");
@@ -2436,7 +2435,6 @@ glade_window_constructed (GObject *object)
   glade_window_populate_intro (window);
 
   refresh_title (window);
-  project_actions_set_enabled (window, FALSE);
 }
 
 #define DEFINE_ACTION_SIGNAL(klass, name, handler,...) \
